@@ -21,8 +21,8 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include "ui_skgtipofdayboardwidget.h"
 #include "skgboardwidget.h"
+#include "ui_skgtipofdayboardwidget.h"
 
 /**
  * This file is a plugin for tip of day
@@ -50,7 +50,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGTipOfDayBoardWidget)
 
-    Ui::skgtipofdayboardwidget ui;
+    Ui::skgtipofdayboardwidget ui{};
 };
 
 #endif  // SKGTIPOFDAYBOARDWIDGET_H
