@@ -23,18 +23,18 @@
 
 #include <kicondialog.h>
 
+#include <qevent.h>
 #include <qheaderview.h>
 #include <qmenu.h>
-#include <qevent.h>
 
 #include "skgbookmark_settings.h"
-#include "skgtraces.h"
 #include "skgdocument.h"
-#include "skgobjectmodelbase.h"
-#include "skgmainpanel.h"
-#include "skgsortfilterproxymodel.h"
-#include "skgnodeobject.h"
 #include "skginterfaceplugin.h"
+#include "skgmainpanel.h"
+#include "skgnodeobject.h"
+#include "skgobjectmodelbase.h"
+#include "skgsortfilterproxymodel.h"
+#include "skgtraces.h"
 #include "skgtransactionmng.h"
 
 bool SKGBookmarkPluginDockWidget::m_middleClick = false;
@@ -44,7 +44,7 @@ SKGBookmarkPluginDockWidget::SKGBookmarkPluginDockWidget(QWidget* iParent, SKGDo
       m_actAddBookmarkGroup(nullptr), m_actSetAutostart(nullptr), m_actUnsetAutostart(nullptr), m_modelview(nullptr)
 {
     SKGTRACEINFUNC(1);
-    if (!iDocument) {
+    if (iDocument == nullptr) {
         return;
     }
 
@@ -111,7 +111,7 @@ QWidget* SKGBookmarkPluginDockWidget::mainWidget()
 
 void SKGBookmarkPluginDockWidget::initMenu()
 {
-    if (!m_mainMenu) {
+    if (m_mainMenu == nullptr) {
         // Build contextual menu
         m_mainMenu = new QMenu(ui.kBookmarksList);
         QAction* actExpandAll = m_mainMenu->addAction(SKGServices::fromTheme(QStringLiteral("format-indent-more")), i18nc("Noun, user action", "Expand all"));
@@ -217,11 +217,11 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
 
     int setForcusOn = 0;
     int nbTab = SKGMainPanel::getMainPanel()->countPages();
-    if (nbTab) {
+    if (nbTab != 0) {
         setForcusOn = nbTab - 1;
 
         SKGTabPage* cPage = SKGMainPanel::getMainPanel()->currentPage();
-        if (m_middleClick || (cPage && cPage->isPin())) {
+        if (m_middleClick || ((cPage != nullptr) && cPage->isPin())) {
             setForcusOn = nbTab;
         } else {
             setForcusOn = SKGMainPanel::getMainPanel()->currentPageIndex();
@@ -235,12 +235,12 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
         if (data.count() > 2) {
             // This bookmark has information ==> we open it
             SKGTabPage* page = SKGMainPanel::getMainPanel()->openPage(SKGMainPanel::getMainPanel()->getPluginByName(data[0]), tabNumberForNextOpen, data[2], selectedNode.getName(), SKGServices::intToString(selectedNode.getID()), i == nodes.count() - 1);
-            if (page) {
+            if (page != nullptr) {
                 if (skgbookmark_settings::pinhomebookmarks()) {
                     page->setPin(iPin);
                 }
                 SKGTabWidget* tab = SKGMainPanel::getMainPanel()->getTabWidget();
-                if (tab) {
+                if (tab != nullptr) {
                     tab->setTabIcon(tab->indexOf(page), selectedNode.getIcon());
                 }
                 selectedNode.opened = true;
@@ -263,16 +263,16 @@ void SKGBookmarkPluginDockWidget::openBookmark(const SKGNodeObject& iNode, bool
 
 void SKGBookmarkPluginDockWidget::onBeforeOpenBookmark()
 {
-    m_middleClick = QApplication::keyboardModifiers() & Qt::ControlModifier || QApplication::mouseButtons() & Qt::MidButton;
+    m_middleClick = (QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u || (QApplication::mouseButtons() & Qt::MidButton) != 0u;
 }
 
 void SKGBookmarkPluginDockWidget::onOpenBookmark(const QModelIndex& index)
 {
     SKGTRACEINFUNC(1);
     if (!(QApplication::mouseButtons() & Qt::RightButton)) {
-        QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
-        SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
-        if (model) {
+        auto* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
+        auto* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+        if (model != nullptr) {
             SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
             if (!node.isFolder()) {
                 openBookmark(node);
@@ -285,9 +285,9 @@ void SKGBookmarkPluginDockWidget::onOpenBookmarkFolder(const QModelIndex& index)
 {
     SKGTRACEINFUNC(1);
     if (!(QApplication::mouseButtons() & Qt::RightButton)) {
-        QSortFilterProxyModel* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
-        SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
-        if (model) {
+        auto* proxyModel = qobject_cast<QSortFilterProxyModel*>(ui.kBookmarksList->model());
+        auto* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+        if (model != nullptr) {
             SKGNodeObject node(model->getObject(proxyModel->mapToSource(index)));
             if (node.isFolder()) {
                 openBookmark(node);
@@ -418,7 +418,7 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
 
     // Get current page
     oCreatedNode = SKGNodeObject();
-    if (iPage) {
+    if (iPage != nullptr) {
         // Get current selection name
         QString name;
         SKGNodeObject parentNode = iParentNode;
@@ -438,7 +438,7 @@ SKGError SKGBookmarkPluginDockWidget::createNodeFromPage(SKGTabPage* iPage, cons
         QString defaultName = iPage->objectName();
         QString defaultIcon;
         SKGInterfacePlugin* plugin = SKGMainPanel::getMainPanel()->getPluginByName(defaultName);
-        if (plugin) {
+        if (plugin != nullptr) {
             defaultName = plugin->title();
             defaultIcon = plugin->icon();
         }
@@ -468,10 +468,10 @@ void SKGBookmarkPluginDockWidget::onRenameBookmark()
     SKGTRACEINFUNC(1);
 
     QItemSelectionModel* selModel = ui.kBookmarksList->selectionModel();
-    QSortFilterProxyModel* proxyModel = qobject_cast< QSortFilterProxyModel* >(ui.kBookmarksList->model());
-    if (proxyModel && selModel) {
-        SKGObjectModelBase* model = static_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
-        if (model) {
+    auto* proxyModel = qobject_cast< QSortFilterProxyModel* >(ui.kBookmarksList->model());
+    if ((proxyModel != nullptr) && (selModel != nullptr)) {
+        auto* model = qobject_cast<SKGObjectModelBase*>(proxyModel->sourceModel());
+        if (model != nullptr) {
             QModelIndexList indexes = selModel->selectedRows();
             if (indexes.count() == 1) {
                 ui.kBookmarksList->edit(indexes.at(0));
@@ -535,22 +535,22 @@ void SKGBookmarkPluginDockWidget::onBookmarkEditorChanged()
     // Enable bookmark buttons
     int nbSelectedObjects = getNbSelectedObjects();
     bool testAdd = getDocument()->getMainDatabase() != nullptr && nbSelectedObjects <= 1;
-    if (m_actAddBookmarkGroup) {
+    if (m_actAddBookmarkGroup != nullptr) {
         m_actAddBookmarkGroup->setEnabled(testAdd);
     }
-    if (m_actAddBookmark) {
+    if (m_actAddBookmark != nullptr) {
         m_actAddBookmark->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentPageIndex() >= 0);
     }
-    if (m_actAddBookmarks) {
+    if (m_actAddBookmarks != nullptr) {
         m_actAddBookmarks->setEnabled(testAdd && SKGMainPanel::getMainPanel()->currentPageIndex() >= 0);
     }
-    if (m_actDelete) {
+    if (m_actDelete != nullptr) {
         m_actDelete->setEnabled(nbSelectedObjects > 0);
     }
-    if (m_actRename) {
+    if (m_actRename != nullptr) {
         m_actRename->setEnabled(nbSelectedObjects == 1);
     }
-    if (m_actChangeIcon) {
+    if (m_actChangeIcon != nullptr) {
         m_actChangeIcon->setEnabled(nbSelectedObjects == 1);
     }
 }
@@ -563,17 +563,17 @@ void SKGBookmarkPluginDockWidget::refresh()
     int nbSelectedObjects = bookmarks.count();
     if (nbSelectedObjects == 1) {
         SKGNodeObject node(bookmarks.at(0));
-        if (m_actSetAutostart) {
+        if (m_actSetAutostart != nullptr) {
             m_actSetAutostart->setEnabled(node.getAttribute(QStringLiteral("t_autostart")) != QStringLiteral("Y"));
         }
-        if (m_actUnsetAutostart) {
+        if (m_actUnsetAutostart != nullptr) {
             m_actUnsetAutostart->setEnabled(node.getAttribute(QStringLiteral("t_autostart")) == QStringLiteral("Y"));
         }
     } else {
-        if (m_actSetAutostart) {
+        if (m_actSetAutostart != nullptr) {
             m_actSetAutostart->setEnabled(nbSelectedObjects > 1);
         }
-        if (m_actUnsetAutostart) {
+        if (m_actUnsetAutostart != nullptr) {
             m_actUnsetAutostart->setEnabled(nbSelectedObjects > 1);
         }
     }
@@ -586,7 +586,7 @@ void SKGBookmarkPluginDockWidget::onPageChanged()
     // Set current selection of dock
     QString id;
     SKGTabPage* cPage = SKGMainPanel::getMainPanel()->currentPage();
-    if (cPage) {
+    if (cPage != nullptr) {
         id = cPage->getBookmarkID();
     }
     ui.kBookmarksList->selectObject(id % "-node");
@@ -594,7 +594,7 @@ void SKGBookmarkPluginDockWidget::onPageChanged()
 
 void SKGBookmarkPluginDockWidget::resizeEvent(QResizeEvent* iEvent)
 {
-    if (iEvent) {
+    if (iEvent != nullptr) {
         QSize newSize = iEvent->size();
 
         // Compute icon size
