@@ -25,16 +25,13 @@
 #include <qstringlist.h>
 #include <qtimer.h>
 
-#include "ui_skgdashboardpluginwidget_base.h"
 #include "skgtabpage.h"
+#include "ui_skgdashboardpluginwidget_base.h"
 
 class QMenu;
 class SKGInterfacePlugin;
 class SKGFlowLayout;
 class SKGBoardWidget;
-namespace
-{
-}
 
 /**
  * A dashboard
@@ -111,10 +108,10 @@ Q_SIGNALS:
     /**
      * When an applet id added
      */
-    void appletAdded(const QString&);
+    void appletAdded(const QString& /*_t1*/);
 
 private Q_SLOTS:
-    void showHeaderMenu(const QPoint iPos);
+    void showHeaderMenu(QPoint iPos);
     void onAddWidget();
     void onRemoveWidget();
     void onMoveWidget(int iMove);
@@ -126,7 +123,7 @@ private:
     void moveItem(int iFrom, int iTo);
     static SKGBoardWidget* parentBoardWidget(QWidget* iWidget);
 
-    Ui::skgdashboardplugin_base ui;
+    Ui::skgdashboardplugin_base ui{};
     SKGFlowLayout* m_flowLayout;
 
     QStringList m_items;
