@@ -22,20 +22,20 @@
 #include "skgdebugpluginwidget.h"
 
 #include <qdom.h>
-#include <qscriptengine.h>
 #include <qjsengine.h>
+#include <qscriptengine.h>
 
-#include "skgmainpanel.h"
 #include "skgdocument.h"
-#include "skgtransactionmng.h"
+#include "skgmainpanel.h"
 #include "skgservices.h"
 #include "skgtraces.h"
+#include "skgtransactionmng.h"
 
 SKGDebugPluginWidget::SKGDebugPluginWidget(QWidget* iParent, SKGDocument* iDocument)
     : SKGTabPage(iParent, iDocument)
 {
     SKGTRACEINFUNC(10);
-    if (!iDocument) {
+    if (iDocument == nullptr) {
         return;
     }
 
