@@ -55,7 +55,9 @@ SKGFilePlugin::SKGFilePlugin(QWidget* iWidget, QObject* iParent, const QVariantL
     SKGTRACEINFUNC(10);
 
     // Set save on close mode
-    SKGMainPanel::getMainPanel()->setSaveOnClose(skgfile_settings::saveonclose());
+    if (SKGMainPanel::getMainPanel() != nullptr) {
+        SKGMainPanel::getMainPanel()->setSaveOnClose(skgfile_settings::saveonclose());
+    }
 }
 
 SKGFilePlugin::~SKGFilePlugin()
@@ -111,59 +113,61 @@ QStringList SKGFilePlugin::processArguments(const QStringList& iArgument)
 {
     SKGTRACEINFUNC(10);
     QStringList output = iArgument;
-    int nbArg = iArgument.count();
-    int openMode = 1;  // 0=no open, 1=open last opened if settings set, 2=new document
-    if (nbArg != 0) {
-        openMode = 2;
-        QString filename = iArgument.at(nbArg - 1);
-        QString extension = QFileInfo(filename).suffix().toUpper();
-        auto inputFile = QFileInfo(filename);
-        if (!inputFile.isAbsolute()) {
-            filename = QFileInfo(QDir::currentPath(), filename).absoluteFilePath();
-        }
-
-        QString extensionDocument = m_currentDocument->getFileExtension().toUpper();
-        if (QFile(filename).exists() && extension == extensionDocument) {
-            if (SKGMainPanel::getMainPanel() != nullptr) {
-                QSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
-                if (splashScreen != nullptr) {
-                    splashScreen->showMessage(i18nc("Splash screen message", "Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
-                }
+    if (m_currentDocument->getCurrentFileName().isEmpty()) {
+        int nbArg = iArgument.count();
+        int openMode = 1;  // 0=no open, 1=open last opened if settings set, 2=new document
+        if (nbArg != 0) {
+            openMode = 2;
+            QString filename = iArgument.at(nbArg - 1);
+            QString extension = QFileInfo(filename).suffix().toUpper();
+            auto inputFile = QFileInfo(filename);
+            if (!inputFile.isAbsolute()) {
+                filename = QFileInfo(QDir::currentPath(), filename).absoluteFilePath();
             }
-            Q_EMIT loadFile(QUrl::fromLocalFile(filename));
-            output.pop_back();
-            openMode = 0;
-        }
-    }
 
-    if (openMode != 0) {
-        // Read Setting
-        bool openlastfile = skgfile_settings::openlastfile();
-        if (openMode == 1 && openlastfile) {
-            QString lastOpenedFile = skgfile_settings::lastfilepath();
-            if (!lastOpenedFile.isEmpty() && QFile(lastOpenedFile).exists()) {
+            QString extensionDocument = m_currentDocument->getFileExtension().toUpper();
+            if (QFile(filename).exists() && extension == extensionDocument) {
                 if (SKGMainPanel::getMainPanel() != nullptr) {
                     QSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
                     if (splashScreen != nullptr) {
-                        splashScreen->showMessage(i18nc("Splash screen message",  "Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
+                        splashScreen->showMessage(i18nc("Splash screen message", "Opening file %1...", filename), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
                     }
                 }
-                Q_EMIT loadFile(QUrl::fromLocalFile(lastOpenedFile));
+                Q_EMIT loadFile(QUrl::fromLocalFile(filename));
+                output.pop_back();
+                openMode = 0;
+            }
+        }
+
+        if (openMode != 0) {
+            // Read Setting
+            bool openlastfile = skgfile_settings::openlastfile();
+            if (openMode == 1 && openlastfile) {
+                QString lastOpenedFile = skgfile_settings::lastfilepath();
+                if (!lastOpenedFile.isEmpty() && QFile(lastOpenedFile).exists()) {
+                    if (SKGMainPanel::getMainPanel() != nullptr) {
+                        QSplashScreen* splashScreen = SKGMainPanel::getMainPanel()->splashScreen();
+                        if (splashScreen != nullptr) {
+                            splashScreen->showMessage(i18nc("Splash screen message",  "Opening file %1...", lastOpenedFile), Qt::AlignLeft, QColor(221, 130, 8));    // krazy:exclude=qmethods
+                        }
+                    }
+                    Q_EMIT loadFile(QUrl::fromLocalFile(lastOpenedFile));
+                } else {
+                    openMode = 2;
+                }
             } else {
                 openMode = 2;
             }
-        } else {
-            openMode = 2;
+
+            if (openMode == 2 && m_currentDocument->getMainDatabase() == nullptr) {
+                onNew();
+            }
         }
 
-        if (openMode == 2 && m_currentDocument->getMainDatabase() == nullptr) {
-            onNew();
-        }
+        // To be sure that the document has the right parameters
+        savePreferences();
     }
 
-    // To be sure that the document has the right parameters
-    savePreferences();
-
     return output;
 }
 
@@ -211,7 +215,9 @@ SKGError SKGFilePlugin::savePreferences() const
         m_currentDocument->setBackupParameters(prefix, suffix);
 
         // Set save on close mode
-        SKGMainPanel::getMainPanel()->setSaveOnClose(skgfile_settings::saveonclose());
+        if (SKGMainPanel::getMainPanel()) {
+            SKGMainPanel::getMainPanel()->setSaveOnClose(skgfile_settings::saveonclose());
+        }
     }
     return err;
 }
