@@ -154,7 +154,7 @@ private:
 
     SKGDocument* m_currentDocument;
 
-    Ui::skgfileplugin_pref ui;
+    Ui::skgfileplugin_pref ui{};
 };
 
 #endif  // SKGFILEPLUGIN_H
