@@ -45,10 +45,9 @@ public:
     /**
      * Called to initialise the plugin
      * @param iDocument the main document
-     * @param iArgument the arguments
      * @return true if the plugin is compatible with the document
      */
-    bool setupActions(SKGDocument* iDocument, const QStringList& iArgument) override;
+    bool setupActions(SKGDocument* iDocument) override;
 
     /**
      * The title of the plugin.
