@@ -23,17 +23,17 @@
 
 #include <grantlee/util.h>
 
-#include "skgtraces.h"
 #include "skgdocument.h"
 #include "skgmainpanel.h"
+#include "skgtraces.h"
 
 #include <KFormat>
 
 QVariant SKGDocumentTableFilter::doFilter(const QVariant& input, const QVariant& argument, bool autoescape) const
 {
     Q_UNUSED(autoescape);
-    SKGDocument* doc = qobject_cast< SKGDocument* >(input.value<QObject*>());
-    if (doc && argument.isValid()) {
+    auto* doc = qobject_cast< SKGDocument* >(input.value<QObject*>());
+    if ((doc != nullptr) && argument.isValid()) {
         SKGObjectBase::SKGListSKGObjectBase objects;
         QString table = Grantlee::getSafeString(argument);
         QString wc;
@@ -58,8 +58,8 @@ bool SKGDocumentTableFilter::isSafe() const
 QVariant SKGDocumentQueryFilter::doFilter(const QVariant& input, const QVariant& argument, bool autoescape) const
 {
     Q_UNUSED(autoescape);
-    SKGDocument* doc = qobject_cast< SKGDocument* >(input.value<QObject*>());
-    if (doc && argument.isValid()) {
+    auto* doc = qobject_cast< SKGDocument* >(input.value<QObject*>());
+    if ((doc != nullptr) && argument.isValid()) {
         QString sql = Grantlee::getSafeString(argument);
         SKGStringListList result;
         doc->executeSelectSqliteOrder(sql, result);
@@ -78,8 +78,8 @@ bool SKGDocumentQueryFilter::isSafe() const
 QVariant SKGDocumentDisplayFilter::doFilter(const QVariant& input, const QVariant& argument, bool autoescape) const
 {
     Q_UNUSED(autoescape);
-    SKGDocument* doc = qobject_cast< SKGDocument* >(input.value<QObject*>());
-    if (doc) {
+    auto* doc = qobject_cast< SKGDocument* >(input.value<QObject*>());
+    if (doc != nullptr) {
         return doc->getDisplay(Grantlee::getSafeString(argument));
     }
 
@@ -97,10 +97,10 @@ QVariant SKGPercentFilter::doFilter(const QVariant& input, const QVariant& argum
     Q_UNUSED(argument);
     SKGMainPanel* mainPanel = SKGMainPanel::getMainPanel();
     SKGDocument* doc = nullptr;
-    if (mainPanel) {
+    if (mainPanel != nullptr) {
         doc = mainPanel->getDocument();
     }
-    if (doc) {
+    if (doc != nullptr) {
         QString s = Grantlee::getSafeString(input);
         return QVariant(doc->formatPercentage(SKGServices::stringToDouble(s)));
     }
@@ -132,8 +132,8 @@ QVariant SKGDumpFilter::doFilter(const QVariant& input, const QVariant& argument
     Q_UNUSED(argument);
 
     if (input.isValid()) {
-        QObject* obj = input.value<QObject*>();
-        if (obj) {
+        auto* obj = input.value<QObject*>();
+        if (obj != nullptr) {
             const QMetaObject* metaObject = obj->metaObject();
             QString table = QStringLiteral("<table class=\"table table-striped table-condensed \">");
             int nb = metaObject->propertyCount();
@@ -143,7 +143,8 @@ QVariant SKGDumpFilter::doFilter(const QVariant& input, const QVariant& argument
             }
             table += QStringLiteral("</table>");
             return QVariant(table);
-        } else if (input.canConvert<SKGObjectBase>()) {
+        }
+        if (input.canConvert<SKGObjectBase>()) {
             SKGObjectBase objectBase = input.value<SKGObjectBase>();
             SKGQStringQStringMap att = objectBase.getAttributes();
             QStringList keys = att.keys();
@@ -154,7 +155,8 @@ QVariant SKGDumpFilter::doFilter(const QVariant& input, const QVariant& argument
             }
             table += QStringLiteral("</table>");
             return QVariant(table);
-        } else if (input.canConvert(QVariant::List)) {
+        }
+        if (input.canConvert(QVariant::List)) {
             QVariantList l = input.toList();
             int nb = l.count();
             QString table = QStringLiteral("<table class=\"table table-striped table-condensed \">");
@@ -164,14 +166,15 @@ QVariant SKGDumpFilter::doFilter(const QVariant& input, const QVariant& argument
             }
             table += QStringLiteral("</table>");
             return QVariant(table);
-        } else if (input.canConvert<SKGObjectBase::SKGListSKGObjectBase>()) {
+        }
+        if (input.canConvert<SKGObjectBase::SKGListSKGObjectBase>()) {
             SKGObjectBase::SKGListSKGObjectBase l = input.value<SKGObjectBase::SKGListSKGObjectBase>();
             int nb = l.count();
             QString table;
-            if (nb) {
+            if (nb != 0) {
                 table = QStringLiteral("<table class=\"table table-striped table-condensed \"><tr><th>#</th>");
                 for (int i = 0; i < nb; ++i) {
-                    SKGObjectBase objectBase = l.at(i);
+                    const SKGObjectBase& objectBase = l.at(i);
                     SKGQStringQStringMap att = objectBase.getAttributes();
                     QStringList keys = att.keys();
                     QString line = QStringLiteral("<tr><td>") % SKGServices::intToString(i) % "</td>";
@@ -192,9 +195,8 @@ QVariant SKGDumpFilter::doFilter(const QVariant& input, const QVariant& argument
                 table += QStringLiteral("</table>");
             }
             return QVariant(table);
-        } else {
-            return QVariant(input.toString());
         }
+        return QVariant(input.toString());
     }
 
     return QVariant();
@@ -211,10 +213,10 @@ QVariant SKGMoneyFilter::doFilter(const QVariant& input, const QVariant& argumen
     QString arg = Grantlee::getSafeString(argument);
     SKGMainPanel* mainPanel = SKGMainPanel::getMainPanel();
     SKGDocument* doc = nullptr;
-    if (mainPanel) {
+    if (mainPanel != nullptr) {
         doc = mainPanel->getDocument();
     }
-    if (doc) {
+    if (doc != nullptr) {
         QStringList args = SKGServices::splitCSVLine(arg);
         SKGServices::SKGUnitInfo unit = doc->getUnit(args.contains(QStringLiteral("2")) ? QStringLiteral("secondary") : QStringLiteral("primary"));
         if (args.contains(QStringLiteral("nodecimal"))) {
