@@ -21,8 +21,8 @@
  *
  * @author Stephane MANKOWSKI
  */
-#include <qobject.h>
 #include <grantlee/filter.h>
+#include <qobject.h>
 
 /**
  * The grantlee's filter to get items of a document table
@@ -35,7 +35,7 @@ public:
     /**
      * Default constructor
      */
-    SKGDocumentTableFilter() {};
+    SKGDocumentTableFilter() = default;
 
     /**
      * Do the filtering
@@ -64,7 +64,7 @@ public:
     /**
      * Default constructor
      */
-    SKGDocumentQueryFilter() {};
+    SKGDocumentQueryFilter() = default;
 
     /**
      * Do the filtering
@@ -93,7 +93,7 @@ public:
     /**
      * Default constructor
      */
-    SKGDocumentDisplayFilter() {};
+    SKGDocumentDisplayFilter() = default;
 
     /**
      * Do the filtering
@@ -122,7 +122,7 @@ public:
     /**
      * Default constructor
      */
-    SKGPercentFilter() {};
+    SKGPercentFilter() = default;
 
     /**
      * Do the filtering
@@ -151,7 +151,7 @@ public:
     /**
      * Default constructor
      */
-    SKGFileSizeFilter() {};
+    SKGFileSizeFilter() = default;
 
     /**
      * Do the filtering
@@ -180,7 +180,7 @@ public:
     /**
      * Default constructor
      */
-    SKGDumpFilter() {};
+    SKGDumpFilter() = default;
 
     /**
      * Do the filtering
@@ -209,7 +209,7 @@ public:
     /**
      * Default constructor
      */
-    SKGMoneyFilter() {};
+    SKGMoneyFilter() = default;
 
     /**
      * Do the filtering
@@ -238,7 +238,7 @@ public:
     /**
      * Default constructor
      */
-    SKGUrlEncodeFilter() {};
+    SKGUrlEncodeFilter() = default;
 
     /**
      * Do the filtering
@@ -267,7 +267,7 @@ public:
     /**
      * Default constructor
      */
-    SKGReplaceFilter() {};
+    SKGReplaceFilter() = default;
 
     /**
      * Do the filtering
