@@ -95,28 +95,27 @@ bool SKGMonthlyPlugin::setupActions(SKGDocument* iDocument)
 QStringList SKGMonthlyPlugin::processArguments(const QStringList& iArgument)
 {
     // Initialise the main page
-
-    delete m_mainPage;
-
+    if (m_mainPage == nullptr) {
 #ifdef SKG_WEBENGINE
-    {
-        SKGTRACEIN(10, "SKGMonthlyPlugin::setupActions-Init SKGWebView");
-        m_mainPage = new SKGWebView(SKGMainPanel::getMainPanel(), 0, false);
+        {
+            SKGTRACEIN(10, "SKGMonthlyPlugin::setupActions-Init SKGWebView");
+            m_mainPage = new SKGWebView(SKGMainPanel::getMainPanel(), 0, false);
+            SKGMainPanel::getMainPanel()->setMainWidget(m_mainPage);
+            refreshMainPage();
+            connect(m_currentBankDocument, &SKGDocument::transactionSuccessfullyEnded, this, &SKGMonthlyPlugin::refreshMainPage);
+            qApp->processEvents(QEventLoop::AllEvents, 500);
+        }
+#else
+        m_mainPage = new QWebView();
+        m_mainPage->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
+        connect(m_mainPage, &QWebView::linkClicked, this, [ = ](const QUrl & val) {
+            SKGMainPanel::getMainPanel()->openPage(val);
+        });
         SKGMainPanel::getMainPanel()->setMainWidget(m_mainPage);
         refreshMainPage();
         connect(m_currentBankDocument, &SKGDocument::transactionSuccessfullyEnded, this, &SKGMonthlyPlugin::refreshMainPage);
-        qApp->processEvents(QEventLoop::AllEvents, 500);
-    }
-#else
-    m_mainPage = new QWebView();
-    m_mainPage->page()->setLinkDelegationPolicy(QWebPage::DelegateAllLinks);
-    connect(m_mainPage, &QWebView::linkClicked, this, [ = ](const QUrl & val) {
-        SKGMainPanel::getMainPanel()->openPage(val);
-    });
-    SKGMainPanel::getMainPanel()->setMainWidget(m_mainPage);
-    refreshMainPage();
-    connect(m_currentBankDocument, &SKGDocument::transactionSuccessfullyEnded, this, &SKGMonthlyPlugin::refreshMainPage);
 #endif
+    }
     return iArgument;
 }
 
