@@ -21,36 +21,36 @@
  */
 #include "skgmonthlypluginwidget.h"
 
+#include <kaboutdata.h>
 #include <kns3/downloaddialog.h>
 #include <kns3/uploaddialog.h>
 #include <kzip.h>
-#include <kaboutdata.h>
 
-#include <qmenu.h>
-#include <qdom.h>
-#include <qtextstream.h>
-#include <qfile.h>
-#include <qdir.h>
 #include <qdesktopservices.h>
+#include <qdir.h>
+#include <qdom.h>
+#include <qfile.h>
+#include <qmenu.h>
+#include <qtextstream.h>
 #ifdef SKG_WEBENGINE
 #include <qwebenginepage.h>
 #else
 #include <qwebframe.h>
 #endif
-#include <qstandardpaths.h>
 #include <qdiriterator.h>
+#include <qstandardpaths.h>
 #include <qvalidator.h>
 
 #include "skgmainpanel.h"
-#include "skgtraces.h"
 #include "skgreport.h"
+#include "skgtraces.h"
 #include "skgtransactionmng.h"
 
 SKGMonthlyPluginWidget::SKGMonthlyPluginWidget(QWidget* iParent, SKGDocument* iDocument)
     : SKGTabPage(iParent, iDocument), m_upload(nullptr)
 {
     SKGTRACEINFUNC(1);
-    if (!iDocument) {
+    if (iDocument == nullptr) {
         return;
     }
 
@@ -326,7 +326,7 @@ void SKGMonthlyPluginWidget::onPutNewHotStuff()
         QString preview2 = QDir::tempPath() % "/" % templat % "_preview2.png";
         QString preview3 = QDir::tempPath() % "/" % templat % "_preview3.png";
 #ifdef SKG_WEBENGINE
-//TODO QWebEngine
+        // TODO(SMI): QWebEngine
 #else
         bool previous = ui.kWebView->blockSignals(true);
         QWebFrame* frame = ui.kWebView->page()->mainFrame();
@@ -372,13 +372,13 @@ QString SKGMonthlyPluginWidget::getReport()
     // Get period
     if (!getPeriod().isEmpty()) {
         SKGReport* rep = getDocument()->getReport();
-        if (rep) {
+        if (rep != nullptr) {
             rep->setPeriod(getPeriod());
 
             // Enrich with tips of the day
             rep->setTipsOfDay(SKGMainPanel::getMainPanel()->getTipsOfDay());
 
-            err = rep->getReportFromTemplate(rep, ui.kTemplate->itemData(ui.kTemplate->currentIndex()).toString(), html);
+            err = SKGReport::getReportFromTemplate(rep, ui.kTemplate->itemData(ui.kTemplate->currentIndex()).toString(), html);
 
             delete rep;
         }
