@@ -21,24 +21,24 @@
  */
 #include "skgprintplugin.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kactioncollection.h>
 #include <kpluginfactory.h>
+#include <kstandardaction.h>
 
-#include <qtextbrowser.h>
-#include <qprintdialog.h>
-#include <qprintpreviewdialog.h>
-#include <qpainter.h>
-#include <qpicture.h>
 #include <qbuffer.h>
-#include <qsavefile.h>
 #include <qdesktopservices.h>
 #include <qdir.h>
+#include <qpainter.h>
+#include <qpicture.h>
+#include <qprintdialog.h>
+#include <qprintpreviewdialog.h>
+#include <qsavefile.h>
+#include <qtextbrowser.h>
 
+#include "skgmainpanel.h"
 #include "skgprint_settings.h"
 #include "skgtraces.h"
-#include "skgmainpanel.h"
 #include "skgtreeview.h"
 
 /**
@@ -106,7 +106,7 @@ void SKGPrintPlugin::onPrint()
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
 
-    if (SKGMainPanel::getMainPanel()) {
+    if (SKGMainPanel::getMainPanel() != nullptr) {
         QPointer<QPrintDialog> dialog = new QPrintDialog(&m_printer, SKGMainPanel::getMainPanel());
         dialog->setOption(QAbstractPrintDialog::PrintCurrentPage, true);
         dialog->setMinMax(1, SKGMainPanel::getMainPanel()->getTabWidget()->count());
@@ -122,7 +122,7 @@ void SKGPrintPlugin::onPrintPreview()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    //TODO QWebEngine does not work
+    // TODO(SMI): QWebEngine does not work
     QPointer<QPrintPreviewDialog> dialog = new QPrintPreviewDialog(SKGMainPanel::getMainPanel());
     connect(dialog.data(), &QPrintPreviewDialog::paintRequested, this, &SKGPrintPlugin::print);
     dialog->exec();
@@ -149,7 +149,7 @@ SKGError SKGPrintPlugin::getHtml(QPrinter* iPrinter, QString& oHtml) const
 {
     SKGError err;
     _SKGTRACEINFUNCRC(10, err);
-    if (SKGMainPanel::getMainPanel() && iPrinter) {
+    if ((SKGMainPanel::getMainPanel() != nullptr) && (iPrinter != nullptr)) {
         QString html;
 
         // Get printer options
@@ -194,8 +194,8 @@ SKGError SKGPrintPlugin::getHtml(QPrinter* iPrinter, QString& oHtml) const
                     // Yes, get the widget
                     // Copy pages
                     for (int p = 1; !err && p <= pageCopies; ++p) {
-                        SKGTabPage* page = static_cast<SKGTabPage*>(tabs->widget(pageToTreat - 1));
-                        if (page) {
+                        auto* page = qobject_cast<SKGTabPage*>(tabs->widget(pageToTreat - 1));
+                        if (page != nullptr) {
                             // Add page break if needed
                             if (!html.isEmpty()) {
                                 html = html % "<div style=\"page-break-after:always\"></div>";
@@ -206,7 +206,7 @@ SKGError SKGPrintPlugin::getHtml(QPrinter* iPrinter, QString& oHtml) const
                             int nbw = widgets.count();
                             for (int j = 0; !err && j < nbw; ++j) {
                                 QWidget* w = widgets.at(j);
-                                if (w) {
+                                if (w != nullptr) {
                                     // Add widget
                                     /*SKGTreeView* tw = qobject_cast< SKGTreeView* >(w);
                                     if (tw) {
@@ -222,7 +222,7 @@ SKGError SKGPrintPlugin::getHtml(QPrinter* iPrinter, QString& oHtml) const
                                     auto q = qobject_cast< QWebView* >(w);
 #endif
 
-                                    if (q) {
+                                    if (q != nullptr) {
 #ifdef SKG_WEBENGINE
                                         q->page()->toHtml([&](const QString & result) {
                                             html = html % result;
@@ -271,14 +271,14 @@ SKGError SKGPrintPlugin::getHtml(QPrinter* iPrinter, QString& oHtml) const
 void SKGPrintPlugin::print(QPrinter* iPrinter)
 {
     SKGTRACEINFUNC(10);
-    if (SKGMainPanel::getMainPanel() && iPrinter) {
+    if ((SKGMainPanel::getMainPanel() != nullptr) && (iPrinter != nullptr)) {
         QString html;
         SKGError err = getHtml(iPrinter, html);
 
         // Print
         m_toPrint.setFixedSize(QSize(iPrinter->width(), iPrinter->height()));
 #ifdef SKG_WEBENGINE
-        // TODO QWebEngine - doesn't work - bad quality printing
+        // TODO(SMI): QWebEngine - doesn't work - bad quality printing
         disconnect(&m_toPrint);
         connect(&m_toPrint, &QWebEngineView::loadFinished, &m_toPrint, [ = ]() {
             m_toPrint.page()->print(iPrinter, [](bool) {});
