@@ -25,8 +25,8 @@
 #ifdef SKG_WEBENGINE
 #include <qwebengineview.h>
 #else
-#include <qwebview.h>
 #include <qwebframe.h>
+#include <qwebview.h>
 #endif
 
 #include "skginterfaceplugin.h"
@@ -83,7 +83,6 @@ public:
     int getOrder() const override;
 
 private Q_SLOTS:
-    SKGError getHtml(QPrinter* iPrinter, QString& oHtml) const;
     void onPrint();
     void onPrintPreview();
     void onPrintHtml();
@@ -92,6 +91,8 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGPrintPlugin)
 
+    SKGError getHtml(QPrinter* iPrinter, QString& oHtml) const;
+
     SKGDocument* m_currentDocument;
     QPrinter m_printer;
 #ifdef SKG_WEBENGINE
@@ -100,7 +101,7 @@ private:
     QWebView m_toPrint;
 #endif
 
-    Ui::skgprintplugin_pref ui;
+    Ui::skgprintplugin_pref ui{};
 };
 
 #endif  // SKGPRINTPLUGIN_H
