@@ -23,18 +23,18 @@
 
 #include <qwidget.h>
 
+#include <kaboutdata.h>
 #include <kactioncollection.h>
+#include <kpluginfactory.h>
 #include <kstandardaction.h>
 #include <ktoolbarpopupaction.h>
-#include <kaboutdata.h>
-#include <kpluginfactory.h>
 
-#include "skgtraces.h"
 #include "skgerror.h"
 #include "skgmainpanel.h"
-#include "skgundoredoplugindockwidget.h"
 #include "skgservices.h"
+#include "skgtraces.h"
 #include "skgundoredo_settings.h"
+#include "skgundoredoplugindockwidget.h"
 
 /**
  * This plugin factory.
@@ -131,15 +131,15 @@ void SKGUndoRedoPlugin::refresh()
         m_dockWidget->setWidget(w);
     }
 
-    if (m_currentDocument) {
+    if (m_currentDocument != nullptr) {
         bool undoPossible = (m_currentDocument->getNbTransaction(SKGDocument::UNDO) > 0);
-        if (m_undoSaveAction) {
+        if (m_undoSaveAction != nullptr) {
             m_undoSaveAction->setEnabled(undoPossible);
         }
-        if (m_undoAction) {
+        if (m_undoAction != nullptr) {
             m_undoAction->setEnabled(undoPossible);
         }
-        if (m_redoAction) {
+        if (m_redoAction != nullptr) {
             m_redoAction->setEnabled(m_currentDocument->getNbTransaction(SKGDocument::REDO) > 0);
         }
 
@@ -150,7 +150,7 @@ void SKGUndoRedoPlugin::refresh()
         if (name.isEmpty()) {
             message = QLatin1String("");
         }
-        if (m_undoAction) {
+        if (m_undoAction != nullptr) {
             m_undoAction->setStatusTip(message);
         }
 
@@ -159,7 +159,7 @@ void SKGUndoRedoPlugin::refresh()
         if (name.isEmpty()) {
             message = QLatin1String("");
         }
-        if (m_redoAction) {
+        if (m_redoAction != nullptr) {
             m_redoAction->setStatusTip(message);
         }
     }
@@ -170,7 +170,7 @@ QWidget* SKGUndoRedoPlugin::getPreferenceWidget()
 {
     SKGTRACEINFUNC(10);
     // Read Setting
-    if (m_currentDocument) {
+    if (m_currentDocument != nullptr) {
         KSharedConfigPtr config = KSharedConfig::openConfig();
         KConfigGroup pref = config->group("skg_undoredo");
         pref.writeEntry("maxNumberOfUndo", SKGServices::stringToInt(m_currentDocument->getParameter(QStringLiteral("SKG_UNDO_MAX_DEPTH"))));
@@ -191,7 +191,7 @@ KConfigSkeleton* SKGUndoRedoPlugin::getPreferenceSkeleton()
 SKGError SKGUndoRedoPlugin::savePreferences() const
 {
     SKGError err;
-    if (m_currentDocument) {
+    if (m_currentDocument != nullptr) {
         // Read Setting
         QString max = SKGServices::intToString(skgundoredo_settings::maxNumberOfUndo());
         QString clean = (skgundoredo_settings::cleanHistoryOnSave() ? QStringLiteral("Y") : QStringLiteral("N"));
@@ -263,7 +263,7 @@ SKGAdviceList SKGUndoRedoPlugin::advice(const QStringList& iIgnoredAdvice)
 SKGError SKGUndoRedoPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
     SKGError err;
-    if (m_currentDocument && iAdviceIdentifier == QStringLiteral("skgundoredoplugin_too_big")) {
+    if ((m_currentDocument != nullptr) && iAdviceIdentifier == QStringLiteral("skgundoredoplugin_too_big")) {
         SKGMainPanel::getMainPanel()->optionsPreferences(this->objectName());
         return err;
     }
@@ -274,7 +274,7 @@ void SKGUndoRedoPlugin::onClearHistory()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    if (m_currentDocument && SKGMainPanel::getMainPanel()) {
+    if ((m_currentDocument != nullptr) && (SKGMainPanel::getMainPanel() != nullptr)) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         err = m_currentDocument->removeAllTransactions();
         QApplication::restoreOverrideCursor();
@@ -294,7 +294,7 @@ void SKGUndoRedoPlugin::onUndoSave()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    if (m_currentDocument && SKGMainPanel::getMainPanel()) {
+    if ((m_currentDocument != nullptr) && (SKGMainPanel::getMainPanel() != nullptr)) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
         err = m_currentDocument->undoRedoTransaction(SKGDocument::UNDOLASTSAVE);
         QApplication::restoreOverrideCursor();
@@ -314,9 +314,9 @@ void SKGUndoRedoPlugin::onUndo()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    if (m_currentDocument && SKGMainPanel::getMainPanel()) {
+    if ((m_currentDocument != nullptr) && (SKGMainPanel::getMainPanel() != nullptr)) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        int pos = static_cast<QAction*>(sender())->data().toInt();
+        int pos = qobject_cast<QAction*>(sender())->data().toInt();
         for (int i = 1 ; !err && i <= pos; ++i) {
             err = m_currentDocument->undoRedoTransaction(SKGDocument::UNDO);
         }
@@ -335,7 +335,7 @@ void SKGUndoRedoPlugin::onUndo()
 
 void SKGUndoRedoPlugin::onShowUndoMenu()
 {
-    if (m_undoMenu && m_currentDocument) {
+    if ((m_undoMenu != nullptr) && (m_currentDocument != nullptr)) {
         m_undoMenu->clear();
         SKGStringListList listTmp;
         m_currentDocument->executeSelectSqliteOrder(
@@ -344,7 +344,7 @@ void SKGUndoRedoPlugin::onShowUndoMenu()
         int nb = listTmp.count();
         for (int i = 1; i < nb; ++i) {
             QAction* act = m_undoMenu->addAction(listTmp.at(i).at(1) == QStringLiteral("Y") ?  SKGServices::fromTheme(QStringLiteral("document-revert")) : SKGServices::fromTheme(QStringLiteral("edit-undo")), listTmp.at(i).at(0));
-            if (act) {
+            if (act != nullptr) {
                 act->setData(i);
                 connect(act, &QAction::triggered, this, &SKGUndoRedoPlugin::onUndo);
             }
@@ -356,9 +356,9 @@ void SKGUndoRedoPlugin::onRedo()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    if (m_currentDocument && SKGMainPanel::getMainPanel()) {
+    if ((m_currentDocument != nullptr) && (SKGMainPanel::getMainPanel() != nullptr)) {
         QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-        int pos = static_cast<QAction*>(sender())->data().toInt();
+        int pos = qobject_cast<QAction*>(sender())->data().toInt();
         for (int i = 1 ; !err && i <= pos; ++i) {
             err = m_currentDocument->undoRedoTransaction(SKGDocument::REDO);
         }
@@ -377,7 +377,7 @@ void SKGUndoRedoPlugin::onRedo()
 
 void SKGUndoRedoPlugin::onShowRedoMenu()
 {
-    if (m_redoMenu && m_currentDocument) {
+    if ((m_redoMenu != nullptr) && (m_currentDocument != nullptr)) {
         m_redoMenu->clear();
         SKGStringListList listTmp;
         m_currentDocument->executeSelectSqliteOrder(
@@ -386,7 +386,7 @@ void SKGUndoRedoPlugin::onShowRedoMenu()
         int nb = listTmp.count();
         for (int i = 1; i < nb; ++i) {
             QAction* act = m_redoMenu->addAction(SKGServices::fromTheme(QStringLiteral("edit-redo")), listTmp.at(i).at(0));
-            if (act) {
+            if (act != nullptr) {
                 act->setData(i);
                 connect(act, &QAction::triggered, this, &SKGUndoRedoPlugin::onRedo);
             }
