@@ -24,14 +24,14 @@
 
 #include <kpluginfactory.h>
 
+#include <qcryptographichash.h>
 #include <qfile.h>
 #include <qmath.h>
-#include <qcryptographichash.h>
 
-#include "skgtraces.h"
-#include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
+#include "skgservices.h"
+#include "skgtraces.h"
 
 /**
  * This plugin factory.
@@ -51,7 +51,7 @@ SKGImportPluginAFB120::~SKGImportPluginAFB120()
 bool SKGImportPluginAFB120::isImportPossible()
 {
     SKGTRACEINFUNC(10);
-    return (!m_importer ? true : m_importer->getFileNameExtension() == QStringLiteral("AFB120") || m_importer->getFileNameExtension() == QStringLiteral("CFO"));
+    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("AFB120") || m_importer->getFileNameExtension() == QStringLiteral("CFO"));
 }
 
 double SKGImportPluginAFB120::toAmount(const QString& iAmount, int iNbDecimal)
@@ -71,7 +71,7 @@ double SKGImportPluginAFB120::toAmount(const QString& iAmount, int iNbDecimal)
 
 SKGError SKGImportPluginAFB120::importFile()
 {
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
@@ -117,7 +117,7 @@ SKGError SKGImportPluginAFB120::importFile()
                 IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb))
                 for (int i = 0; i < nb && !err; ++i) {
                     // Read line
-                    QString line = lines.at(i);
+                    const QString& line = lines.at(i);
                     if (!line.isEmpty()) {
                         if (line.startsWith(QLatin1String("01"))) {
                             // Previous balance
