@@ -29,10 +29,10 @@
 #include <qfileinfo.h>
 #include <qsavefile.h>
 
-#include "skgtraces.h"
-#include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
+#include "skgservices.h"
+#include "skgtraces.h"
 
 /**
  * This plugin factory.
@@ -284,7 +284,7 @@ SKGError SKGImportPluginCsv::importFile()
     if (m_importParameters.value(QStringLiteral("mode_csv_unit")) == QStringLiteral("Y")) {
         return importCSVUnit();
     }
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
 
@@ -427,7 +427,7 @@ SKGError SKGImportPluginCsv::importFile()
                     QString mappingDesc;
                     int nbMap = m_csvMapping.count();
                     for (int i = 0; i < nbMap; ++i) {
-                        if (i) {
+                        if (i != 0) {
                             mappingDesc += '|';
                         }
                         mappingDesc += m_csvMapping.at(i);
@@ -461,7 +461,7 @@ SKGError SKGImportPluginCsv::importFile()
                             IFOKDO(err, currentOperation.setParentAccount(defAccount))
                         }
 
-                        QString line = lines.at(i);
+                        const QString& line = lines.at(i);
                         QString skg_op_original_amount;
                         QStringList atts = SKGServices::splitCSVLine(line, getCSVSeparator());
                         int nbcol = m_csvMapping.count();
@@ -481,7 +481,7 @@ SKGError SKGImportPluginCsv::importFile()
 
                         QByteArray hash = QCryptographicHash::hash(linecleaned.toUtf8(), QCryptographicHash::Md5);
 
-                        int initialBalance = false;
+                        int initialBalance = 0;
                         int idgroup = 0;
                         int idtransaction = 0;
                         QStringList propertiesAtt;
@@ -500,7 +500,7 @@ SKGError SKGImportPluginCsv::importFile()
                                     err = currentOperation.setDate(d);
                                     IFOKDO(err, currentSubOperation.setDate(d));
                                     if (val == QStringLiteral("0000-00-00")) {
-                                        initialBalance = true;
+                                        initialBalance = 1;
                                     }
                                 } else if (col == QStringLiteral("number")) {
                                     if (!val.isEmpty()) {
@@ -670,7 +670,7 @@ SKGError SKGImportPluginCsv::importFile()
                             }
                         }
 
-                        if (!err && initialBalance) {
+                        if (!err && (initialBalance != 0)) {
                             // Specific values for initial balance
                             err = currentOperation.setStatus(SKGOperationObject::CHECKED);
                             IFOKDO(err, currentOperation.setAttribute(QStringLiteral("d_date"), QStringLiteral("0000-00-00")))
@@ -755,12 +755,12 @@ SKGError SKGImportPluginCsv::importFile()
 bool SKGImportPluginCsv::isExportPossible()
 {
     SKGTRACEINFUNC(10);
-    return (!m_importer ? true : m_importer->getFileNameExtension() == QStringLiteral("CSV"));
+    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("CSV"));
 }
 
 SKGError SKGImportPluginCsv::exportFile()
 {
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
@@ -822,7 +822,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
     SKGError err;
     SKGTRACEINFUNCRC(2, err);
 
-    if (m_importer->getDocument()) {
+    if (m_importer->getDocument() != nullptr) {
         // Begin transaction
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import units"), 3);
         IFOK(err) {
@@ -898,7 +898,7 @@ SKGError SKGImportPluginCsv::importCSVUnit()
                         QString mappingDesc;
                         int nbMap = m_csvMapping.count();
                         for (int i = 0; i < nbMap; ++i) {
-                            if (i) {
+                            if (i != 0) {
                                 mappingDesc += '|';
                             }
                             mappingDesc += m_csvMapping.at(i);
@@ -936,7 +936,7 @@ SKGError SKGImportPluginCsv::importCSVRule()
     SKGError err;
     SKGTRACEINFUNCRC(2, err);
 
-    if (m_importer->getDocument()) {
+    if (m_importer->getDocument() != nullptr) {
         // Begin transaction
         err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import rules"), 3);
         IFOK(err) {
@@ -993,7 +993,7 @@ SKGError SKGImportPluginCsv::importCSVRule()
                         QString mappingDesc;
                         int nbMap = m_csvMapping.count();
                         for (int i = 0; i < nbMap; ++i) {
-                            if (i) {
+                            if (i != 0) {
                                 mappingDesc += '|';
                             }
                             mappingDesc += m_csvMapping.at(i);
