@@ -21,19 +21,19 @@
  */
 #include "skgimportplugingnc.h"
 
-#include <klocalizedstring.h>
 #include <kcompressiondevice.h>
+#include <klocalizedstring.h>
 #include <kpluginfactory.h>
 
-#include <qdom.h>
 #include <cmath>
+#include <qdom.h>
 
-#include "skgtraces.h"
-#include "skgservices.h"
 #include "skgbankincludes.h"
+#include "skgimportexportmanager.h"
 #include "skgobjectbase.h"
 #include "skgpayeeobject.h"
-#include "skgimportexportmanager.h"
+#include "skgservices.h"
+#include "skgtraces.h"
 
 /**
  * This plugin factory.
@@ -53,7 +53,7 @@ SKGImportPluginGnc::~SKGImportPluginGnc()
 bool SKGImportPluginGnc::isImportPossible()
 {
     SKGTRACEINFUNC(10);
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return true;
     }
     QString extension = m_importer->getFileNameExtension();
@@ -62,7 +62,7 @@ bool SKGImportPluginGnc::isImportPossible()
 
 SKGError SKGImportPluginGnc::importFile()
 {
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
@@ -235,7 +235,7 @@ SKGError SKGImportPluginGnc::importFile()
                                         mapIdType[accountId.text()] = 'A';  // Memorize an account
 
                                         QDomNodeList accountUnits = account.elementsByTagName(QStringLiteral("cmdty:id"));
-                                        if (!err && accountUnits.count()) {
+                                        if (!err && (accountUnits.count() != 0)) {
                                             mapIdUnit[accountId.text()] = mapUnitIdUnit[accountUnits.at(0).toElement().text()];
                                         }
                                     } else if (type == QStringLiteral("EQUITY")) {
@@ -547,7 +547,7 @@ SKGError SKGImportPluginGnc::importFile()
                             QDomElement schedulePeriod;
                             QDomElement scheduleDate;
                             QDomNodeList scheduleScheduleList = schedule.elementsByTagName(QStringLiteral("gnc:recurrence"));
-                            if (scheduleScheduleList.count()) {
+                            if (scheduleScheduleList.count() != 0) {
                                 QDomElement scheduleSchedule = scheduleScheduleList.at(0).toElement();
                                 scheduleMult = scheduleSchedule.firstChildElement(QStringLiteral("recurrence:mult"));
                                 schedulePeriod = scheduleSchedule.firstChildElement(QStringLiteral("recurrence:period_type"));
@@ -624,7 +624,7 @@ SKGError SKGImportPluginGnc::importFile()
                                 QDomNodeList priceDateList = price.elementsByTagName(QStringLiteral("ts:date"));
                                 QDomElement priceValue = price.firstChildElement(QStringLiteral("price:value"));
 
-                                if (priceIdList.isEmpty() == false && priceDateList.isEmpty() == false && !priceValue.isNull()) {
+                                if (!priceIdList.isEmpty() && !priceDateList.isEmpty() && !priceValue.isNull()) {
                                     QString unitName = priceIdList.at(0).toElement().text();
                                     QDate unitDate = QDate::fromString(priceDateList.at(0).toElement().text().left(10), QStringLiteral("yyyy-MM-dd"));
 
