@@ -24,13 +24,13 @@
 #include <kpluginfactory.h>
 
 #include <qcryptographichash.h>
-#include <qsavefile.h>
 #include <qfile.h>
+#include <qsavefile.h>
 
-#include "skgtraces.h"
-#include "skgservices.h"
 #include "skgbankincludes.h"
 #include "skgimportexportmanager.h"
+#include "skgservices.h"
+#include "skgtraces.h"
 
 /**
 * Opening balance string
@@ -77,7 +77,7 @@ QString SKGImportPluginIif::getVal(const QStringList& iVals, const QString& iAtt
 
 SKGError SKGImportPluginIif::importFile()
 {
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
 
@@ -323,12 +323,12 @@ SKGError SKGImportPluginIif::importFile()
 bool SKGImportPluginIif::isExportPossible()
 {
     SKGTRACEINFUNC(10);
-    return (!m_importer ? true : m_importer->getFileNameExtension() == QStringLiteral("IIF"));
+    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("IIF"));
 }
 
 SKGError SKGImportPluginIif::exportFile()
 {
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
@@ -349,7 +349,7 @@ SKGError SKGImportPluginIif::exportFile()
         }
     }
 
-    if (listAccountsToExport.count() || listOperationsToExport.count()) {
+    if ((listAccountsToExport.count() != 0) || (listOperationsToExport.count() != 0)) {
         IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and operations have been exported")))
     }
 
@@ -370,7 +370,7 @@ SKGError SKGImportPluginIif::exportFile()
             SKGObjectBase::SKGListSKGObjectBase accounts;
             IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_account_display"), QStringLiteral("1=1 ORDER BY t_name, id"), accounts))
             int nbaccount = accounts.count();
-            if (!err && nbaccount) {
+            if (!err && (nbaccount != 0)) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export accounts"), nbaccount);
                 for (int i = 0; !err && i < nbaccount; ++i) {
                     SKGAccountObject act(accounts.at(i));
@@ -395,7 +395,7 @@ SKGError SKGImportPluginIif::exportFile()
             SKGObjectBase::SKGListSKGObjectBase categories;
             IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_category_display_tmp"), QStringLiteral("1=1 ORDER BY t_fullname, id"), categories))
             int nbcat = categories.count();
-            if (!err && nbcat) {
+            if (!err && (nbcat != 0)) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export categories"), nbcat);
                 for (int i = 0; !err && i < nbcat; ++i) {
                     SKGCategoryObject cat(categories.at(i));
@@ -421,7 +421,7 @@ SKGError SKGImportPluginIif::exportFile()
             SKGObjectBase::SKGListSKGObjectBase payees;
             IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_payee_display"), QStringLiteral("1=1 ORDER BY t_name, id"), payees))
             int nbpayee = payees.count();
-            if (!err && nbpayee) {
+            if (!err && (nbpayee != 0)) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export payees"), nbpayee);
                 for (int i = 0; !err && i < nbpayee; ++i) {
                     SKGPayeeObject payee(payees.at(i));
@@ -443,7 +443,7 @@ SKGError SKGImportPluginIif::exportFile()
             SKGObjectBase::SKGListSKGObjectBase operations;
             IFOKDO(err, m_importer->getDocument()->getObjects(QStringLiteral("v_operation_display"), QStringLiteral("1=1 ORDER BY d_date, id"), operations))
             int nbop = operations.count();
-            if (!err && nbop) {
+            if (!err && (nbop != 0)) {
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export operations"), nbop);
                 for (int i = 0; !err && i < nbop; ++i) {
                     SKGOperationObject op(operations.at(i));
