@@ -266,15 +266,17 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
                 // Yes ==> creation of the schedule
                 SKGRecurrentOperationObject recuObj;
                 IFOKDO(err, operationObj.addRecurrentOperation(recuObj))
-                QDate firstDate = QDate::fromString(recu.attribute(QStringLiteral("startDate")), QStringLiteral("yyyy-MM-dd"));
-                IFOKDO(err, recuObj.setDate(firstDate))
+                IFOKDO(err, recuObj.setDate(operationObj.getDate()))
                 IFOKDO(err, recuObj.autoWriteEnabled(recu.attribute(QStringLiteral("autoEnter")) == QStringLiteral("1")))
                 IFOKDO(err, recuObj.setAutoWriteDays(0))
 
                 int occu = SKGServices::stringToInt(recu.attribute(QStringLiteral("occurenceMultiplier")));
                 QString occuType = recu.attribute(QStringLiteral("occurence"));  // krazy:exclude=spelling
                 SKGRecurrentOperationObject::PeriodUnit period;
-                if (occuType == QStringLiteral("32")) {
+                if (occuType == QStringLiteral("32") ||
+                    occuType == QStringLiteral("1024") ||
+                    occuType == QStringLiteral("256") ||
+                    occuType == QStringLiteral("8192")) {
                     period = SKGRecurrentOperationObject::MONTH;
                 } else if (occuType == QStringLiteral("1")) {
                     period = SKGRecurrentOperationObject::DAY;
@@ -291,7 +293,6 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
                     period = SKGRecurrentOperationObject::YEAR;
                 }
 
-
                 IFOKDO(err, recuObj.setPeriodIncrement(occu))
                 IFOKDO(err, recuObj.setPeriodUnit(period))
 
@@ -303,6 +304,11 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
                     }
                 }
 
+                if (occuType == QStringLiteral("1") && !recu.attribute(QStringLiteral("lastPayment")).isEmpty()) {
+                    // Single schedule already done
+                    IFOKDO(err, recuObj.timeLimit(true))
+                    IFOKDO(err, recuObj.setTimeLimit(0))
+                }
                 IFOKDO(err, recuObj.save(true, false))
             }
         }
@@ -361,7 +367,17 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
             } else {
                 QString accountSubOp = suboperation.attribute(QStringLiteral("account"));
                 if (!accountSubOp.isEmpty()) {
-                    if (!m_mapIdAccount.contains(accountSubOp)) {
+                    if (nbSuboperations == 1) {
+                        SKGUnitObject unit = m_mapIdUnit.value(accountSubOp);
+                        if (unit.getID() != 0) {
+                            IFOKDO(err, operationObj.setUnit(unit))
+                        }
+                    }
+
+                    if (!m_mapIdAccount.contains(accountSubOp) || (nbSuboperations == 2 &&
+                            m_mapIdAccount.value(accountSubOp) == kmymoneyTemporaryAccount &&
+                            suboperationsList.at(0).toElement().attribute(QStringLiteral("action")).isEmpty() &&
+                            suboperationsList.at(1).toElement().attribute(QStringLiteral("action")).isEmpty())) {
                         // Set as initial balance
                         IFOKDO(err, operationObj.setAttribute(QStringLiteral("d_date"), QStringLiteral("0000-00-00")))
                         IFOKDO(err, operationObj.setStatus(SKGOperationObject::CHECKED))
@@ -375,7 +391,7 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
                         IFOKDO(err, suboperationObj.save(true, false))
                     } else {
                         // It is a transfer of account
-                        SKGAccountObject act = m_mapIdAccount.value(suboperation.attribute(QStringLiteral("account")));
+                        SKGAccountObject act = m_mapIdAccount.value(accountSubOp);
 
                         if (parentSet) {
                             // If the parent is already set, it means that is a transfer
@@ -395,7 +411,7 @@ SKGError SKGImportPluginKmy::importTransactions(QDomElement& docElem, SKGAccount
                             IFOKDO(err, operationObj2.setImported(true))
                             IFOKDO(err, operationObj2.setImportID(operationObj.getImportID()))
 
-                            SKGUnitObject unit = m_mapIdUnit.value(suboperation.attribute(QStringLiteral("account")));
+                            SKGUnitObject unit = m_mapIdUnit.value(accountSubOp);
                             if (unit.getID() != 0) {
                                 IFOKDO(err, operationObj2.setUnit(unit))
                             } else {
@@ -596,7 +612,9 @@ SKGError SKGImportPluginKmy::importAccounts(SKGBankObject& bank, SKGAccountObjec
                 }
 
                 m_mapIdAccount[account.attribute(QStringLiteral("id"))] = accountObj;
-            } else if (type != QStringLiteral("16")) {
+            } else if (type == QStringLiteral("16")) {
+                m_mapIdAccount[account.attribute(QStringLiteral("id"))] = kmymoneyTemporaryAccount;
+            } else {
                 // Create category
                 SKGCategoryObject cat = m_mapIdCategory.value(account.attribute(QStringLiteral("id")));
                 if (cat.getID() != 0) {
