@@ -20,19 +20,16 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgimportpluginledger.h"
-#if QT_VERSION < 0x050700
-#include <klocale.h>
-#endif
 
 #include <klocalizedstring.h>
 #include <kpluginfactory.h>
 
 #include <qsavefile.h>
 
-#include "skgtraces.h"
+#include "skgbankincludes.h"
 #include "skgdocumentbank.h"
 #include "skgservices.h"
-#include "skgbankincludes.h"
+#include "skgtraces.h"
 
 /**
  * This plugin factory.
@@ -52,7 +49,7 @@ SKGImportPluginLedger::~SKGImportPluginLedger()
 bool SKGImportPluginLedger::isExportPossible()
 {
     SKGTRACEINFUNC(10);
-    return (!m_importer ? true : m_importer->getFileNameExtension() == QStringLiteral("LEDGER"));
+    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("LEDGER"));
 }
 
 SKGError SKGImportPluginLedger::exportFile()
@@ -85,11 +82,7 @@ SKGError SKGImportPluginLedger::exportFile()
             IFOKDO(err, m_importer->getDocument()->sendMessage(i18nc("An information message",  "Only selected accounts and operations have been exported")))
         }
 
-#if QT_VERSION < 0x050700
-        KLocale en(QStringLiteral("en_EN"));
-#else
         QLocale en(QStringLiteral("en_EN"));
-#endif
         QTextStream stream(&file);
         if (!m_importer->getCodec().isEmpty()) {
             stream.setCodec(m_importer->getCodec().toLatin1().constData());
@@ -105,11 +98,7 @@ SKGError SKGImportPluginLedger::exportFile()
                 err = m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Export step", "Export units"), nb);
                 for (int i = 0; !err && i < nb; ++i) {
                     SKGUnitObject unit(units.at(i));
-#if QT_VERSION < 0x050700
-                    QString qs = en.formatMoney(SKGServices::stringToDouble(unit.getAttribute(QStringLiteral("f_CURRENTAMOUNT"))), punit.Symbol, punit.NbDecimal).trimmed();
-#else
                     QString qs = en.toCurrencyString(SKGServices::stringToDouble(unit.getAttribute(QStringLiteral("f_CURRENTAMOUNT"))), punit.Symbol, punit.NbDecimal);
-#endif
                     stream << "P " << SKGServices::dateToSqlString(QDate::currentDate()).replace('-', '/')
                            << " \"" << unit.getSymbol() << '"'
                            << " " << qs
@@ -156,11 +145,7 @@ SKGError SKGImportPluginLedger::exportFile()
                     if (symbol.contains(QStringLiteral(" "))) {
                         symbol = '"' + symbol + '"';
                     }
-#if QT_VERSION < 0x050700
-                    QString qs = en.formatMoney(SKGServices::stringToDouble(op.getAttribute(QStringLiteral("f_QUANTITY"))), QStringLiteral(" "), nbDec).trimmed();
-#else
                     QString qs = en.toCurrencyString(SKGServices::stringToDouble(op.getAttribute(QStringLiteral("f_QUANTITY"))), QStringLiteral(" "), nbDec);
-#endif
                     if (isCurrency) {
                         qs = symbol + qs;
                     } else {
@@ -193,11 +178,7 @@ SKGError SKGImportPluginLedger::exportFile()
                         if (catString.isEmpty()) {
                             catString = i18nc("Category not defined", "Not defined");
                         }
-#if QT_VERSION < 0x050700
-                        QString qs = en.formatMoney(-sop.getQuantity(), QStringLiteral(" "), nbDec).trimmed();
-#else
                         QString qs = en.toCurrencyString(-sop.getQuantity(), QStringLiteral(" "), nbDec);
-#endif
                         if (isCurrency) {
                             qs = unit.getSymbol() + qs;
                         } else {
