@@ -64,7 +64,7 @@ SKGError SKGImportPluginMmb::importFile()
     SKGTRACEINFUNCRC(2, err);
 
     {
-        QSqlDatabase originalDocument(QSqlDatabase::addDatabase(QStringLiteral("QSQLITE"), QStringLiteral("originalDocument")));
+        QSqlDatabase originalDocument(QSqlDatabase::addDatabase(QStringLiteral("SKGSQLCIPHER"), QStringLiteral("originalDocument")));
         originalDocument.setDatabaseName(m_importer->getLocalFileName());
         if (!originalDocument.open()) {
             // Set error message
@@ -638,6 +638,7 @@ SKGError SKGImportPluginMmb::importFile()
 
             IFOKDO(err, m_importer->getDocument()->executeSqliteOrder(QStringLiteral("ANALYZE")))
         }
+        originalDocument.close();
     }
     QSqlDatabase::removeDatabase(QStringLiteral("originalDocument"));
     return err;
