@@ -26,11 +26,11 @@
 #include <klocalizedstring.h>
 #include <kpluginfactory.h>
 
-#include "skgtraces.h"
-#include "skgservices.h"
 #include "skgbankincludes.h"
-#include "skgobjectbase.h"
 #include "skgimportexportmanager.h"
+#include "skgobjectbase.h"
+#include "skgservices.h"
+#include "skgtraces.h"
 
 /**
  * This plugin factory.
@@ -50,12 +50,12 @@ SKGImportPluginMT940::~SKGImportPluginMT940()
 bool SKGImportPluginMT940::isImportPossible()
 {
     SKGTRACEINFUNC(10);
-    return (!m_importer ? true : m_importer->getFileNameExtension() == QStringLiteral("MT940"));
+    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("MT940"));
 }
 
 SKGError SKGImportPluginMT940::importFile()
 {
-    if (!m_importer) {
+    if (m_importer == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
@@ -103,7 +103,7 @@ SKGError SKGImportPluginMT940::importFile()
                 IFOKDO(err, m_importer->getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import operations"), nb))
                 for (int i = 0; i < nb && !err; ++i) {
                     // Read line
-                    QString line = lines.at(i);
+                    const QString& line = lines.at(i);
                     if (!line.isEmpty()) {
                         if (line.startsWith(QLatin1String(":20:"))) {
                             importActivated = true;
@@ -227,7 +227,7 @@ SKGError SKGImportPluginMT940::importFile()
 
                                 in86 = true;
                             } else if (in86) {
-                                QString val = line;
+                                const QString& val = line;
                                 QString comment = operation.getComment();
                                 comment += (comment.isEmpty() || val.isEmpty() ? "" : " ") % val;
                                 IFOKDO(err, operation.setComment(comment))
