@@ -21,8 +21,8 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include <libofx/libofx.h>
 #include "skgimportplugin.h"
+#include <libofx/libofx.h>
 
 #include <qdatetime.h>
 
@@ -45,25 +45,25 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGImportPluginOfx();
+    ~SKGImportPluginOfx() override;
 
     /**
      * To know if import is possible with this plugin
      */
-    virtual bool isImportPossible() override;
+    bool isImportPossible() override;
 
     /**
      * Import a file
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError importFile() override;
+    SKGError importFile() override;
 
     /**
      * Return the mime type filter
      * @return the mime type filter. Example: "*.csv|CSV file"
      */
-    virtual QString getMimeTypeFilter() const override;
+    QString getMimeTypeFilter() const override;
 
 
 private:
