@@ -687,6 +687,8 @@ SKGError SKGImportPluginQif::importFile()
                                     }
                                 }
                                 if (!err && !val.isEmpty()) {
+                                    auto cat_tag = SKGServices::splitCSVLine(val, '/', false);
+                                    val = cat_tag.at(0);
                                     SKGCategoryObject Category;
                                     val.replace('/', OBJECTSEPARATOR);
                                     val.replace(':', OBJECTSEPARATOR);
@@ -694,6 +696,12 @@ SKGError SKGImportPluginQif::importFile()
                                     val.replace(';', OBJECTSEPARATOR);
                                     err = SKGCategoryObject::createPathCategory(m_importer->getDocument(), val, Category);
                                     IFOKDO(err, currentSubOperation.setCategory(Category))
+
+                                    if (!err && cat_tag.count() > 1) {
+                                        SKGTrackerObject tracker;
+                                        err = SKGTrackerObject::createTracker(m_importer->getDocument(), cat_tag.at(1), tracker);
+                                        IFOKDO(err, currentSubOperation.setTracker(tracker))
+                                    }
                                 }
                             }
                         } else if (op == 'C') {
