@@ -16,15 +16,15 @@
  ***************************************************************************/
 #include "skgaddoperation.h"
 
+#include <qdir.h>
 #include <qicon.h>
 #include <qsavefile.h>
 #include <qstringbuilder.h>
-#include <quuid.h>
-#include <qdir.h>
 #include <qtextstream.h>
+#include <quuid.h>
 
-#include <kmessagebox.h>
 #include <klocalizedstring.h>
+#include <kmessagebox.h>
 
 SKGAddOperation::SKGAddOperation(QObject* iParent, const QVariantList& args)
     : AbstractRunner(iParent, args)
@@ -98,9 +98,9 @@ void SKGAddOperation::run(const Plasma::RunnerContext& iContext, const Plasma::Q
         // Close file
         file.commit();
 
-        KMessageBox::information(NULL, i18nc("Information message", "Operation created"));
+        KMessageBox::information(nullptr, i18nc("Information message", "Operation created"));
     } else {
-        KMessageBox::error(NULL, i18nc("Error message: Could not create a file", "Creation of file %1 failed", fileName));
+        KMessageBox::error(nullptr, i18nc("Error message: Could not create a file", "Creation of file %1 failed", fileName));
     }
 }
 
