@@ -25,12 +25,12 @@
 
 #include <qdom.h>
 
-#include "skgdocumentbank.h"
-#include "skgtraces.h"
-#include "skgservices.h"
 #include "skgaccountobject.h"
-#include "skgunitobject.h"
+#include "skgdocumentbank.h"
 #include "skgmainpanel.h"
+#include "skgservices.h"
+#include "skgtraces.h"
+#include "skgunitobject.h"
 
 SKGAccountBoardWidget::SKGAccountBoardWidget(QWidget* iParent, SKGDocument* iDocument)
     : SKGBoardWidget(iParent, iDocument, i18nc("Title of a dashboard widget", "Accounts")), m_refreshNeeded(true)
@@ -168,17 +168,17 @@ QString SKGAccountBoardWidget::getState()
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
-    root.setAttribute(QStringLiteral("menuFavorite"), m_menuFavorite && m_menuFavorite->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuAssets"), m_menuAssets && m_menuAssets->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuCurrent"), m_menuCurrent && m_menuCurrent->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuCreditCard"), m_menuCreditCard && m_menuCreditCard->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuSaving"), m_menuSaving && m_menuSaving->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuInvestment"), m_menuInvestment && m_menuInvestment->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuWallet"), m_menuWallet && m_menuWallet->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuLoan"), m_menuLoan && m_menuLoan->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuPension"), m_menuPension && m_menuPension->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuOther"), m_menuOther && m_menuOther->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuPastOperations"), m_menuPastOperations && m_menuPastOperations->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuFavorite"), (m_menuFavorite != nullptr) && m_menuFavorite->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuAssets"), (m_menuAssets != nullptr) && m_menuAssets->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuCurrent"), (m_menuCurrent != nullptr) && m_menuCurrent->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuCreditCard"), (m_menuCreditCard != nullptr) && m_menuCreditCard->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuSaving"), (m_menuSaving != nullptr) && m_menuSaving->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuInvestment"), (m_menuInvestment != nullptr) && m_menuInvestment->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuWallet"), (m_menuWallet != nullptr) && m_menuWallet->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuLoan"), (m_menuLoan != nullptr) && m_menuLoan->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuPension"), (m_menuPension != nullptr) && m_menuPension->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuOther"), (m_menuOther != nullptr) && m_menuOther->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuPastOperations"), (m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
 
     return doc.toString();
 }
@@ -191,37 +191,37 @@ void SKGAccountBoardWidget::setState(const QString& iState)
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
 
-    if (m_menuFavorite) {
+    if (m_menuFavorite != nullptr) {
         m_menuFavorite->setChecked(root.attribute(QStringLiteral("menuFavorite")) == QStringLiteral("Y"));
     }
-    if (m_menuAssets) {
+    if (m_menuAssets != nullptr) {
         m_menuAssets->setChecked(root.attribute(QStringLiteral("menuAssets")) != QStringLiteral("N"));
     }
-    if (m_menuCurrent) {
+    if (m_menuCurrent != nullptr) {
         m_menuCurrent->setChecked(root.attribute(QStringLiteral("menuCurrent")) != QStringLiteral("N"));
     }
-    if (m_menuCreditCard) {
+    if (m_menuCreditCard != nullptr) {
         m_menuCreditCard->setChecked(root.attribute(QStringLiteral("menuCreditCard")) != QStringLiteral("N"));
     }
-    if (m_menuSaving) {
+    if (m_menuSaving != nullptr) {
         m_menuSaving->setChecked(root.attribute(QStringLiteral("menuSaving")) != QStringLiteral("N"));
     }
-    if (m_menuInvestment) {
+    if (m_menuInvestment != nullptr) {
         m_menuInvestment->setChecked(root.attribute(QStringLiteral("menuInvestment")) != QStringLiteral("N"));
     }
-    if (m_menuWallet) {
+    if (m_menuWallet != nullptr) {
         m_menuWallet->setChecked(root.attribute(QStringLiteral("menuWallet")) != QStringLiteral("N"));
     }
-    if (m_menuLoan) {
+    if (m_menuLoan != nullptr) {
         m_menuLoan->setChecked(root.attribute(QStringLiteral("menuLoan")) != QStringLiteral("N"));
     }
-    if (m_menuPension) {
+    if (m_menuPension != nullptr) {
         m_menuPension->setChecked(root.attribute(QStringLiteral("menuPension")) != QStringLiteral("N"));
     }
-    if (m_menuOther) {
+    if (m_menuOther != nullptr) {
         m_menuOther->setChecked(root.attribute(QStringLiteral("menuOther")) != QStringLiteral("N"));
     }
-    if (m_menuPastOperations) {
+    if (m_menuPastOperations != nullptr) {
         m_menuPastOperations->setChecked(root.attribute(QStringLiteral("menuPastOperations")) == QStringLiteral("Y"));
     }
 
@@ -248,8 +248,8 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
         }
 
         m_refreshNeeded = false;
-        SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
-        if (doc) {
+        auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+        if (doc != nullptr) {
             SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
             bool exist = false;
             SKGError err = doc->existObjects(QStringLiteral("account"), QLatin1String(""), exist);
@@ -260,52 +260,52 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                 } else {
                     // Build where clause
                     QString wc;
-                    if (m_menuAssets && m_menuAssets->isChecked()) {
+                    if ((m_menuAssets != nullptr) && m_menuAssets->isChecked()) {
                         wc = QStringLiteral("t_type='A'");
                     }
-                    if (m_menuCurrent && m_menuCurrent->isChecked()) {
+                    if ((m_menuCurrent != nullptr) && m_menuCurrent->isChecked()) {
                         if (!wc.isEmpty()) {
                             wc += QStringLiteral(" OR ");
                         }
                         wc += QStringLiteral("t_type='C'");
                     }
-                    if (m_menuCreditCard && m_menuCreditCard->isChecked()) {
+                    if ((m_menuCreditCard != nullptr) && m_menuCreditCard->isChecked()) {
                         if (!wc.isEmpty()) {
                             wc += QStringLiteral(" OR ");
                         }
                         wc += QStringLiteral("t_type='D'");
                     }
-                    if (m_menuSaving && m_menuSaving->isChecked()) {
+                    if ((m_menuSaving != nullptr) && m_menuSaving->isChecked()) {
                         if (!wc.isEmpty()) {
                             wc += QStringLiteral(" OR ");
                         }
                         wc += QStringLiteral("t_type='S'");
                     }
-                    if (m_menuInvestment && m_menuInvestment->isChecked()) {
+                    if ((m_menuInvestment != nullptr) && m_menuInvestment->isChecked()) {
                         if (!wc.isEmpty()) {
                             wc += QStringLiteral(" OR ");
                         }
                         wc += QStringLiteral("t_type='I'");
                     }
-                    if (m_menuWallet && m_menuWallet->isChecked()) {
+                    if ((m_menuWallet != nullptr) && m_menuWallet->isChecked()) {
                         if (!wc.isEmpty()) {
                             wc += QStringLiteral(" OR ");
                         }
                         wc += QStringLiteral("t_type='W'");
                     }
-                    if (m_menuOther && m_menuOther->isChecked()) {
+                    if ((m_menuOther != nullptr) && m_menuOther->isChecked()) {
                         if (!wc.isEmpty()) {
                             wc += QStringLiteral(" OR ");
                         }
                         wc += QStringLiteral("t_type='O'");
                     }
-                    if (m_menuLoan && m_menuLoan->isChecked()) {
+                    if ((m_menuLoan != nullptr) && m_menuLoan->isChecked()) {
                         if (!wc.isEmpty()) {
                             wc += QStringLiteral(" OR ");
                         }
                         wc += QStringLiteral("t_type='L'");
                     }
-                    if (m_menuPension && m_menuPension->isChecked()) {
+                    if ((m_menuPension != nullptr) && m_menuPension->isChecked()) {
                         if (!wc.isEmpty()) {
                             wc += QStringLiteral(" OR ");
                         }
@@ -314,14 +314,14 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
 
                     if (wc.isEmpty()) {
                         wc = QStringLiteral("1=0");
-                    } else if (m_menuFavorite && m_menuFavorite->isChecked()) {
+                    } else if ((m_menuFavorite != nullptr) && m_menuFavorite->isChecked()) {
                         wc = "t_bookmarked='Y' AND (" % wc % ')';
                     }
 
                     // Build display
                     SKGStringListList listTmp;
                     err = doc->executeSelectSqliteOrder(
-                              QStringLiteral("SELECT t_name, t_TYPENLS, t_UNIT, ") % (m_menuPastOperations && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT") % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
+                              QStringLiteral("SELECT t_name, t_TYPENLS, t_UNIT, ") % ((m_menuPastOperations != nullptr) && m_menuPastOperations->isChecked() ? "f_TODAYAMOUNT" : "f_CURRENTAMOUNT") % ", t_close  from v_account_display WHERE (" % wc % ") ORDER BY t_TYPENLS, t_name",
                               listTmp);
                     IFOK(err) {
                         html += QStringLiteral("<html><body><table>");
@@ -330,10 +330,10 @@ void SKGAccountBoardWidget::dataModified(const QString& iTableName, int iIdTrans
                         QString currentType;
                         int nb = listTmp.count();
                         for (int i = 1; i < nb; ++i) {  // Ignore header
-                            QStringList r = listTmp.at(i);
-                            QString name = r.at(0);
-                            QString type = r.at(1);
-                            QString unitAccountSymbol = r.at(2);
+                            const QStringList& r = listTmp.at(i);
+                            const QString& name = r.at(0);
+                            const QString& type = r.at(1);
+                            const QString& unitAccountSymbol = r.at(2);
                             double v1 = SKGServices::stringToDouble(r.at(3));
                             bool closed = (r.at(4) == QStringLiteral("Y"));
 
