@@ -23,30 +23,30 @@
 
 #include <kmessagebox.h>
 
-#include <qdom.h>
-#include <qfile.h>
 #include <qdir.h>
+#include <qdom.h>
 #include <qevent.h>
-#include <qstandardpaths.h>
+#include <qfile.h>
 #include <qfiledialog.h>
+#include <qstandardpaths.h>
 
+#include "skgbankobject.h"
+#include "skgboardwidget.h"
+#include "skgdocumentbank.h"
+#include "skginterfaceplugin.h"
 #include "skgmainpanel.h"
 #include "skgobjectmodel.h"
+#include "skgtablewithgraph.h"
+#include "skgtraces.h"
 #include "skgtransactionmng.h"
 #include "skgunitobject.h"
 #include "skgunitvalueobject.h"
-#include "skgbankobject.h"
-#include "skgdocumentbank.h"
-#include "skgtraces.h"
-#include "skginterfaceplugin.h"
-#include "skgtablewithgraph.h"
-#include "skgboardwidget.h"
 
 SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDocument)
     : SKGTabPage(iParent, iDocument), m_graph(nullptr)
 {
     SKGTRACEINFUNC(10);
-    if (!iDocument) {
+    if (iDocument == nullptr) {
         return;
     }
 
@@ -54,9 +54,9 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
 
     // Add report
     SKGInterfacePlugin* reportPlugin = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Skrooge report plugin"));
-    if (reportPlugin) {
+    if (reportPlugin != nullptr) {
         m_graph = reportPlugin->getDashboardWidget(0);
-        if (m_graph) {
+        if (m_graph != nullptr) {
             // To avoid hidden page when no account exist
             auto w = new QWidget(this);
             auto verticalLayout = new QVBoxLayout(w);
@@ -130,7 +130,7 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
     ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("opened"), i18n("Opened"), QStringLiteral("vcs-normal"), QStringLiteral("t_close='N'"), QLatin1String(""), Qt::META + Qt::Key_O);
     ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("closed"), i18n("Closed"), QStringLiteral("vcs-conflicting"), QStringLiteral("t_close='Y'"), QLatin1String(""), Qt::META + Qt::Key_C);
     ui.kView->getShowWidget()->addGroupedItem(QStringLiteral("highlighted"), i18n("Highlighted only"), QStringLiteral("bookmarks"), QStringLiteral("t_bookmarked='Y'"), QLatin1String(""), Qt::META + Qt::Key_H);
-    if (m_graph) {
+    if (m_graph != nullptr) {
         ui.kView->getShowWidget()->addSeparator();
         ui.kView->getShowWidget()->addItem(QStringLiteral("graph"), i18n("Graph"), QStringLiteral("view-statistics"), QStringLiteral("1=0"), QLatin1String(""), QLatin1String(""), QLatin1String(""), QLatin1String(""), Qt::META + Qt::Key_G);
     }
@@ -151,18 +151,18 @@ SKGBankPluginWidget::SKGBankPluginWidget(QWidget* iParent, SKGDocumentBank* iDoc
 
     // Add NLS values for type of account
     // C=current D=credit card P=passif (for objects) I=Investment O=other
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-checking")), i18nc("Noun, a type of account", "Current"), int(SKGAccountObject::CURRENT));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("skrooge_credit_card")), i18nc("Noun, a type of account", "Credit card"), int(SKGAccountObject::CREDITCARD));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Saving"), int(SKGAccountObject::SAVING));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Investment"), int(SKGAccountObject::INVESTMENT));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Assets"), int(SKGAccountObject::ASSETS));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Loan"), int(SKGAccountObject::LOAN));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Pension"), int(SKGAccountObject::PENSION));
-    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("wallet-closed")), i18nc("Noun, a type of account", "Wallet"), int(SKGAccountObject::WALLET));
-    ui.kAccountCreatorType->addItem(i18nc("Noun, a type of account", "Other"), int(SKGAccountObject::OTHER));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-checking")), i18nc("Noun, a type of account", "Current"), static_cast<int>(SKGAccountObject::CURRENT));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("skrooge_credit_card")), i18nc("Noun, a type of account", "Credit card"), static_cast<int>(SKGAccountObject::CREDITCARD));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Saving"), static_cast<int>(SKGAccountObject::SAVING));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Investment"), static_cast<int>(SKGAccountObject::INVESTMENT));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Assets"), static_cast<int>(SKGAccountObject::ASSETS));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Loan"), static_cast<int>(SKGAccountObject::LOAN));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("view-bank-account-savings")), i18nc("Noun, a type of account", "Pension"), static_cast<int>(SKGAccountObject::PENSION));
+    ui.kAccountCreatorType->addItem(SKGServices::fromTheme(QStringLiteral("wallet-closed")), i18nc("Noun, a type of account", "Wallet"), static_cast<int>(SKGAccountObject::WALLET));
+    ui.kAccountCreatorType->addItem(i18nc("Noun, a type of account", "Other"), static_cast<int>(SKGAccountObject::OTHER));
 
     // Bind account creation view
-    ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_account_display"), QStringLiteral("1=0"), this, QLatin1String(""), false));
+    ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_account_display"), QStringLiteral("1=0"), this, QLatin1String(""), false));
 
     connect(ui.kView->getView(), &SKGTreeView::clickEmptyArea, this, &SKGBankPluginWidget::cleanEditor);
     connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(), &QAction::trigger);
@@ -237,12 +237,12 @@ SKGBankPluginWidget::~SKGBankPluginWidget()
 
 bool SKGBankPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (iEvent && iEvent->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+    if ((iEvent != nullptr) && iEvent->type() == QEvent::KeyPress) {
+        auto* keyEvent = dynamic_cast<QKeyEvent*>(iEvent);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
-            if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAccountCreatorAdd->isEnabled()) {
+            if ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u && ui.kAccountCreatorAdd->isEnabled()) {
                 ui.kAccountCreatorAdd->click();
-            } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kAccountCreatorUpdate->isEnabled()) {
+            } else if ((QApplication::keyboardModifiers() &Qt::ShiftModifier) != 0u && ui.kAccountCreatorUpdate->isEnabled()) {
                 ui.kAccountCreatorUpdate->click();
             }
         }
@@ -314,8 +314,8 @@ void SKGBankPluginWidget::onSelectionChanged()
         if (oUnit.exist()) {
             ui.kUnitEdit->setUnit(oUnit);
         } else {
-            SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
-            if (doc) {
+            auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+            if (doc != nullptr) {
                 SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
                 ui.kUnitEdit->setText(primary.Symbol);
             }
@@ -355,7 +355,7 @@ void SKGBankPluginWidget::onRefreshGraphDelayed()
 void SKGBankPluginWidget::onRefreshGraph()
 {
     SKGTRACEINFUNC(10);
-    if (m_graph) {
+    if (m_graph != nullptr) {
         bool visible = ui.kView->getShowWidget()->getState().contains(QStringLiteral("graph"));
 
         QDomDocument doc(QStringLiteral("SKGML"));
@@ -373,11 +373,11 @@ void SKGBankPluginWidget::onRefreshGraph()
                 if (visible) {
                     SKGObjectBase::SKGListSKGObjectBase objs = ui.kView->getView()->getSelectedObjects();
                     nbSelect = objs.count();
-                    if (nbSelect) {
+                    if (nbSelect != 0) {
                         wc = QStringLiteral("t_ACCOUNT IN (");
                         title = i18nc("Noun, a list of items", "Operations of account ");
                         for (int i = 0; i < nbSelect; ++i) {
-                            if (i) {
+                            if (i != 0) {
                                 wc += ',';
                                 title += ',';
                             }
@@ -393,7 +393,7 @@ void SKGBankPluginWidget::onRefreshGraph()
                 }
                 root2.setAttribute(QStringLiteral("operationWhereClause"), wc);
                 root2.setAttribute(QStringLiteral("title"), title);
-                root2.setAttribute(QStringLiteral("lines"), nbSelect ? QStringLiteral("t_ACCOUNT") : QStringLiteral("#NOTHING#"));
+                root2.setAttribute(QStringLiteral("lines"), nbSelect != 0 ? QStringLiteral("t_ACCOUNT") : QStringLiteral("#NOTHING#"));
             }
             root.setAttribute(QStringLiteral("graph"), doc2.toString());
         }
@@ -412,7 +412,7 @@ void SKGBankPluginWidget::onIconChanged()
     SKGTRACEINFUNC(10);
 
     int c = ui.kAccountCreatorIcon->currentIndex();
-    if (c && c == ui.kAccountCreatorIcon->count() - 1) {
+    if ((c != 0) && c == ui.kAccountCreatorIcon->count() - 1) {
         QString fileName = QFileDialog::getOpenFileName(this,
                            i18nc("Title of panel", "Select a bank icon"),
                            QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/images/logo/"), QStandardPaths::LocateDirectory),
@@ -810,8 +810,8 @@ void SKGBankPluginWidget::dataModified(const QString& iTableName, int iIdTransac
 void SKGBankPluginWidget::refreshInfoZone()
 {
     SKGTRACEINFUNC(10);
-    SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
-    if (doc) {
+    auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+    if (doc != nullptr) {
         ui.kInfo->setText(i18nc("Message", "Computing..."));
         doc->concurrentExecuteSelectSqliteOrder(QStringLiteral("SELECT TOTAL(f_TODAYAMOUNT), TOTAL(f_CURRENTAMOUNT), TOTAL(f_CHECKED), TOTAL(f_COMING_SOON) from v_account_display"), [ = ](const SKGStringListList & iResult) {
             if (iResult.count() == 2 && SKGMainPanel::getMainPanel()->pageIndex(this) != -1) {
@@ -827,7 +827,7 @@ void SKGBankPluginWidget::refreshInfoZone()
                 ui.kInfo->setText(i18nc("Information on an account's status : Balance is the current amount of money on the account, Checked is the amount of money on your last bank's statement, To be Checked is the differences between these two values", "Today balance : %1     Balance : %2     Checked : %3     To be Checked : %4", s1, s2, s3, s4));
 
                 SKGServices::SKGUnitInfo secondaryUnit = doc->getSecondaryUnit();
-                if (!secondaryUnit.Symbol.isEmpty() && secondaryUnit.Value) {
+                if (!secondaryUnit.Symbol.isEmpty() && (secondaryUnit.Value != 0.0)) {
                     s1 = doc->formatMoney(v1, secondaryUnit);
                     s2 = doc->formatMoney(v2, secondaryUnit);
                     s3 = doc->formatMoney(v3, secondaryUnit);
@@ -848,7 +848,7 @@ QList< QWidget* > SKGBankPluginWidget::printableWidgets()
 {
     QList< QWidget* > output;
     output.push_back(mainWidget());
-    if (m_graph && m_graph->isVisible()) {
+    if ((m_graph != nullptr) && m_graph->isVisible()) {
         output.push_back(m_graph);
     }
     return output;
