@@ -24,9 +24,9 @@
 #include <qstringlist.h>
 #include <qtimer.h>
 
-#include "ui_skgbankpluginwidget_base.h"
-#include "skgtabpage.h"
 #include "skgaccountobject.h"
+#include "skgtabpage.h"
+#include "ui_skgbankpluginwidget_base.h"
 
 class SKGBoardWidget;
 class SKGDocumentBank;
@@ -122,7 +122,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGBankPluginWidget)
 
-    Ui::skgbankplugin_base ui;
+    Ui::skgbankplugin_base ui{};
     QTimer m_timer;
     QTimer m_timer2;
     SKGBoardWidget* m_graph;
