@@ -40,10 +40,10 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGBudgetDelegate();
+    ~SKGBudgetDelegate() override;
 
 
-    virtual void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
+    void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 
 
 private:
