@@ -25,20 +25,20 @@
 #include <qevent.h>
 
 #include "skgbudgetdelegate.h"
-#include "skgmainpanel.h"
-#include "skgobjectmodel.h"
 #include "skgbudgetobject.h"
 #include "skgbudgetruleobject.h"
 #include "skgcategoryobject.h"
-#include "skgtransactionmng.h"
-#include "skgtraces.h"
 #include "skgdocument.h"
+#include "skgmainpanel.h"
+#include "skgobjectmodel.h"
+#include "skgtraces.h"
+#include "skgtransactionmng.h"
 
 SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDocument)
     : SKGTabPage(iParent, iDocument), m_objectModel(nullptr)
 {
     SKGTRACEINFUNC(1);
-    if (!iDocument) {
+    if (iDocument == nullptr) {
         return;
     }
 
@@ -98,7 +98,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
                                        QStringLiteral("none"),
                                        QLatin1String(""),
                                        QStringLiteral("all"),
-                                       Qt::META + Qt::Key_3);;
+                                       Qt::META + Qt::Key_3);
     ui.kView->getShowWidget()->addItem(QStringLiteral("currentMonth"), i18nc("Noun, budget items to display", "Current month"), QStringLiteral("view-calendar-week"),
                                        QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now'))"),
                                        QLatin1String(""),
@@ -126,18 +126,18 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
     m_timer.setSingleShot(true);
     connect(&m_timer, &QTimer::timeout, this, &SKGBudgetPluginWidget::refreshInfoZone, Qt::QueuedConnection);
 
-    ui.kConditionCmb->addItem(i18nc("Noun, condition item to a apply a transfer of budget", "All"), int(SKGBudgetRuleObject::ALL));
-    ui.kConditionCmb->addItem(i18nc("Noun, condition item to a apply a transfer of budget", "Negative"), int(SKGBudgetRuleObject::NEGATIVE));
-    ui.kConditionCmb->addItem(i18nc("Noun, condition item to a apply a transfer of budget", "Positive"), int(SKGBudgetRuleObject::POSITIVE));
+    ui.kConditionCmb->addItem(i18nc("Noun, condition item to a apply a transfer of budget", "All"), static_cast<int>(SKGBudgetRuleObject::ALL));
+    ui.kConditionCmb->addItem(i18nc("Noun, condition item to a apply a transfer of budget", "Negative"), static_cast<int>(SKGBudgetRuleObject::NEGATIVE));
+    ui.kConditionCmb->addItem(i18nc("Noun, condition item to a apply a transfer of budget", "Positive"), static_cast<int>(SKGBudgetRuleObject::POSITIVE));
 
-    ui.kModeCmb->addItem(i18nc("Noun, mode item to a apply a transfer of budget", "Next"), int(SKGBudgetRuleObject::NEXT));
-    ui.kModeCmb->addItem(i18nc("Noun, mode item to a apply a transfer of budget", "Current"), int(SKGBudgetRuleObject::CURRENT));
-    ui.kModeCmb->addItem(i18nc("Noun, mode item to a apply a transfer of budget", "Current year"), int(SKGBudgetRuleObject::YEAR));
+    ui.kModeCmb->addItem(i18nc("Noun, mode item to a apply a transfer of budget", "Next"), static_cast<int>(SKGBudgetRuleObject::NEXT));
+    ui.kModeCmb->addItem(i18nc("Noun, mode item to a apply a transfer of budget", "Current"), static_cast<int>(SKGBudgetRuleObject::CURRENT));
+    ui.kModeCmb->addItem(i18nc("Noun, mode item to a apply a transfer of budget", "Current year"), static_cast<int>(SKGBudgetRuleObject::YEAR));
 
     ui.kView->getView()->setItemDelegate(new SKGBudgetDelegate(ui.kView->getView(), getDocument()));
 
-    SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
-    if (doc) {
+    auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+    if (doc != nullptr) {
         ui.kUnitCmb->addItem(QStringLiteral("%"));
         ui.kUnitCmb->addItem(doc->getPrimaryUnit().Symbol);
         ui.kUnit->setText(doc->getPrimaryUnit().Symbol);
@@ -155,7 +155,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(QWidget* iParent, SKGDocument* iDoc
     ui.kModifyBtn->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
     ui.kAddBtn->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
     QAction* processAction = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("tool_process_budget_rules"));
-    if (processAction) {
+    if (processAction != nullptr) {
         ui.kProcessBtn->setIcon(processAction->icon());
         connect(ui.kProcessBtn, &QPushButton::clicked, processAction, &QAction::trigger);
     }
@@ -219,12 +219,12 @@ SKGBudgetPluginWidget::~SKGBudgetPluginWidget()
 
 bool SKGBudgetPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (iEvent && iEvent->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+    if ((iEvent != nullptr) && iEvent->type() == QEvent::KeyPress) {
+        auto* keyEvent = dynamic_cast<QKeyEvent*>(iEvent);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
-            if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAddBtn->isEnabled()) {
+            if ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u && ui.kAddBtn->isEnabled()) {
                 ui.kAddBtn->click();
-            } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kModifyBtn->isEnabled()) {
+            } else if ((QApplication::keyboardModifiers() &Qt::ShiftModifier) != 0u && ui.kModifyBtn->isEnabled()) {
                 ui.kModifyBtn->click();
             }
         }
@@ -241,7 +241,7 @@ QString SKGBudgetPluginWidget::getState()
     doc.appendChild(root);
 
     root.setAttribute(QStringLiteral("currentPage"), SKGServices::intToString(ui.kWidgetSelector->getSelectedMode()));
-    if (m_objectModel && m_objectModel->getRealTable() == QStringLiteral("budget")) {
+    if ((m_objectModel != nullptr) && m_objectModel->getRealTable() == QStringLiteral("budget")) {
         root.setAttribute(QStringLiteral("view"), ui.kView->getState());
         root.setAttribute(QStringLiteral("viewRule"), m_viewRule);
     } else {
@@ -268,7 +268,7 @@ void SKGBudgetPluginWidget::setState(const QString& iState)
 
     m_viewBudget = root.attribute(QStringLiteral("view"));
     m_viewRule = root.attribute(QStringLiteral("viewRule"));
-    if (m_objectModel && m_objectModel->getRealTable() == QStringLiteral("budget")) {
+    if ((m_objectModel != nullptr) && m_objectModel->getRealTable() == QStringLiteral("budget")) {
         ui.kView->setState(m_viewBudget);
     } else {
         ui.kView->setState(m_viewRule);
@@ -318,7 +318,7 @@ void SKGBudgetPluginWidget::dataModified(const QString& iTableName, int iIdTrans
 void SKGBudgetPluginWidget::onBtnModeClicked(int mode)
 {
     SKGTRACEINFUNC(10);
-    if (!m_objectModel) {
+    if (m_objectModel == nullptr) {
         return;
     }
 
@@ -405,7 +405,7 @@ void SKGBudgetPluginWidget::onAddClicked()
             } else {
                 // Automatic creation
                 if (ui.kAutoBudgetCheck->isChecked()) {
-                    err = SKGBudgetObject::createAutomaticBudget(static_cast<SKGDocumentBank*>(getDocument()),
+                    err = SKGBudgetObject::createAutomaticBudget(qobject_cast<SKGDocumentBank*>(getDocument()),
                             ui.kYearAuto->value(),
                             ui.kYearAutoBase->value(),
                             ui.kUseScheduledOperation->isChecked(),
@@ -413,7 +413,7 @@ void SKGBudgetPluginWidget::onAddClicked()
                 }
                 IFOKDO(err, getDocument()->stepForward(1))
 
-                IFOKDO(err, SKGBudgetObject::balanceBudget(static_cast<SKGDocumentBank*>(getDocument()),
+                IFOKDO(err, SKGBudgetObject::balanceBudget(qobject_cast<SKGDocumentBank*>(getDocument()),
                         ui.kYearAuto->value(), (ui.kBalancingMonthly->isChecked() ? 0 : -1),
                         ui.kBalancingAnnual->isChecked()));
                 IFOKDO(err, getDocument()->stepForward(2))
@@ -500,7 +500,7 @@ SKGError SKGBudgetPluginWidget::updateBudget(SKGBudgetObject& iBudget, int iMont
 
     SKGCategoryObject cat;
     QString catName = ui.kCategoryEdit->text().trimmed();
-    IFOKDO(err, SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catName, cat, true))
+    IFOKDO(err, SKGCategoryObject::createPathCategory(qobject_cast<SKGDocumentBank*>(getDocument()), catName, cat, true))
     IFOKDO(err, iBudget.setCategory(cat))
     IFOKDO(err, iBudget.enableSubCategoriesInclusion(ui.kIncludingSubCategories->isChecked()))
 
@@ -526,10 +526,10 @@ SKGError SKGBudgetPluginWidget::updateBudgetRule(SKGBudgetRuleObject& iRule)
     SKGError err;
     SKGCategoryObject cat;
     QString catName = ui.kCategoryRule->text().trimmed();
-    IFOKDO(err, SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catName, cat, true))
+    IFOKDO(err, SKGCategoryObject::createPathCategory(qobject_cast<SKGDocumentBank*>(getDocument()), catName, cat, true))
     SKGCategoryObject catchange;
     QString catchangeName = ui.kCategoryTransfer->text().trimmed();
-    IFOKDO(err, SKGCategoryObject::createPathCategory(static_cast<SKGDocumentBank*>(getDocument()), catchangeName, catchange, true))
+    IFOKDO(err, SKGCategoryObject::createPathCategory(qobject_cast<SKGDocumentBank*>(getDocument()), catchangeName, catchange, true))
     IFOKDO(err, iRule.enableCategoryCondition(ui.kCategoryCheck->isChecked()))
     IFOKDO(err, iRule.setBudgetCategory(cat))
     IFOKDO(err, iRule.enableYearCondition(ui.kYearCheck->isChecked()))
@@ -555,7 +555,7 @@ void SKGBudgetPluginWidget::onCreatorModified()
 {
     bool test = !ui.kAmountEdit->text().isEmpty() && !ui.kYear->text().isEmpty();
     ui.kAddBtn->setEnabled(test || ui.kWidgetSelector->getSelectedMode() != 0);
-    ui.kModifyBtn->setEnabled((test && ui.kPeriod->currentIndex() != 0 && ui.kWidgetSelector->getSelectedMode() == 0 && getNbSelectedObjects())
+    ui.kModifyBtn->setEnabled((test && ui.kPeriod->currentIndex() != 0 && ui.kWidgetSelector->getSelectedMode() == 0 && (getNbSelectedObjects() != 0))
                               || (ui.kWidgetSelector->getSelectedMode() == 2 && getNbSelectedObjects() == 1));
 
     bool monthCondition = (ui.kPeriod->currentIndex() == 2 || ui.kWidgetSelector->getSelectedMode() == 2);
@@ -566,14 +566,14 @@ void SKGBudgetPluginWidget::onCreatorModified()
 void SKGBudgetPluginWidget::onSelectionChanged()
 {
     SKGTRACEINFUNC(10);
-    if (!m_objectModel) {
+    if (m_objectModel == nullptr) {
         return;
     }
 
     SKGObjectBase::SKGListSKGObjectBase objs = getSelectedObjects();
     int nb = objs.count();
     int mode = ui.kWidgetSelector->getSelectedMode();
-    if (nb) {
+    if (nb != 0) {
         if (m_objectModel->getRealTable() == QStringLiteral("budget")) {
             SKGBudgetObject budget(objs.at(0));
             ui.kYear->setValue(budget.getYear());
@@ -598,8 +598,8 @@ void SKGBudgetPluginWidget::onSelectionChanged()
             ui.kCategoryTransfer->setText(rule.getAttribute(QStringLiteral("t_CATEGORY")));
             ui.kUnitCmb->setCurrentIndex(rule.isAbolute() ? 1 : 0);
             ui.kAmountEdit2->setValue(rule.getQuantity());
-            ui.kModeCmb->setCurrentIndex(ui.kModeCmb->findData(int(rule.getTransferMode())));
-            ui.kConditionCmb->setCurrentIndex(ui.kConditionCmb->findData(int(rule.getCondition())));
+            ui.kModeCmb->setCurrentIndex(ui.kModeCmb->findData(static_cast<int>(rule.getTransferMode())));
+            ui.kConditionCmb->setCurrentIndex(ui.kConditionCmb->findData(static_cast<int>(rule.getCondition())));
         }
     }
 
@@ -628,8 +628,8 @@ bool SKGBudgetPluginWidget::isEditor()
 void SKGBudgetPluginWidget::refreshInfoZone()
 {
     SKGTRACEINFUNC(10);
-    SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(getDocument());
-    if (doc && ui.kWidgetSelector->getSelectedMode() != 2) {
+    auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+    if ((doc != nullptr) && ui.kWidgetSelector->getSelectedMode() != 2) {
         SKGServices::SKGUnitInfo primary = doc->getPrimaryUnit();
         SKGServices::SKGUnitInfo secondary = doc->getSecondaryUnit();
         // Refresh info area with selection
@@ -647,9 +647,9 @@ void SKGBudgetPluginWidget::refreshInfoZone()
         QString budgetedS = doc->formatMoney(budgeted, primary);
         QString modifiedS = doc->formatMoney(modified, primary);
         QString v = (budgetedS == modifiedS ? budgetedS : modifiedS % " <s><small>" % budgetedS % "</small></s>");
-        if (nb) {
+        if (nb != 0) {
             ui.kInfo->setText(i18np("Selection: %1 budget for %2", "Selection: %1 budgets for %2", nb, v));
-            if (!secondary.Symbol.isEmpty() && secondary.Value) {
+            if (!secondary.Symbol.isEmpty() && (secondary.Value != 0.0)) {
                 budgetedS = doc->formatMoney(budgeted, secondary);
                 modifiedS = doc->formatMoney(modified, secondary);
                 v = (budgetedS == modifiedS ? budgetedS : modifiedS % " <s><small>" % budgetedS % "</small></s>");
