@@ -21,9 +21,9 @@
  *
  * @author Stephane MANKOWSKI
  */
-#include <qtimer.h>
-#include "ui_skgbudgetpluginwidget_base.h"
 #include "skgtabpage.h"
+#include "ui_skgbudgetpluginwidget_base.h"
+#include <qtimer.h>
 
 class SKGObjectModel;
 class SKGBudgetObject;
@@ -119,7 +119,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGBudgetPluginWidget)
 
-    Ui::skgbudgetplugin_base ui;
+    Ui::skgbudgetplugin_base ui{};
 
     SKGError updateBudget(SKGBudgetObject& iBudget, int iMonth = -1);
     SKGError updateBudgetRule(SKGBudgetRuleObject& iRule);
