@@ -21,24 +21,24 @@
  */
 #include "skgcategoriesplugin.h"
 
-#include <kactioncollection.h>
 #include <kaboutdata.h>
+#include <kactioncollection.h>
 #include <kpluginfactory.h>
 #include <kselectaction.h>
 
 #include <qaction.h>
+#include <qdiriterator.h>
 #include <qfileinfo.h>
 #include <qstandardpaths.h>
-#include <qdiriterator.h>
 
 #include "skgcategoriespluginwidget.h"
-#include "skgtraces.h"
-#include "skgmainpanel.h"
-#include "skghtmlboardwidget.h"
-#include "skgtransactionmng.h"
 #include "skgcategoryobject.h"
 #include "skgdocumentbank.h"
+#include "skghtmlboardwidget.h"
 #include "skgimportexportmanager.h"
+#include "skgmainpanel.h"
+#include "skgtraces.h"
+#include "skgtransactionmng.h"
 
 /**
  * This plugin factory.
@@ -138,9 +138,11 @@ QString SKGCategoriesPlugin::getDashboardWidgetTitle(int iIndex)
     SKGTRACEINFUNC(1);
     if (iIndex == 0) {
         return i18nc("Report header",  "5 main categories of expenditure");
-    } else if (iIndex == 1) {
+    }
+    if (iIndex == 1) {
         return i18nc("Report header",  "5 main variations");
-    } else if (iIndex == 2) {
+    }
+    if (iIndex == 2) {
         return i18nc("Report header",  "Budget");
     }
     return i18nc("Report header",  "5 main variations (issues)");
@@ -159,12 +161,14 @@ SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
                                       getDashboardWidgetTitle(iIndex),
                                       QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_period_table.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
                                       QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::ALL_PERIODS);
-    } else if (iIndex == 1) {
+    }
+    if (iIndex == 1) {
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex) % " - %1",
                                       QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/categories_variations.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
                                       QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_AND_CURRENT_PERIODS);
-    } else if (iIndex == 2) {
+    }
+    if (iIndex == 2) {
         return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
                                       getDashboardWidgetTitle(iIndex) % " - %1",
                                       QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/budget_table.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
@@ -179,7 +183,7 @@ SKGBoardWidget* SKGCategoriesPlugin::getDashboardWidget(int iIndex)
 void SKGCategoriesPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
-    if (m_currentBankDocument) {
+    if (m_currentBankDocument != nullptr) {
         // Automatic categories creation
         if (m_currentBankDocument->getMainDatabase() != nullptr) {
             QString doc_id = m_currentBankDocument->getUniqueIdentifier();
@@ -203,8 +207,8 @@ void SKGCategoriesPlugin::importCategories()
 {
     SKGTRACEINFUNC(10);
     SKGError err;
-    QAction* act = qobject_cast< QAction* >(sender());
-    if (act) {
+    auto* act = qobject_cast< QAction* >(sender());
+    if (act != nullptr) {
         QString fileName = act->data().toString();
         QString name = QFileInfo(fileName).baseName().replace('_', ' ');
         {
@@ -396,7 +400,7 @@ SKGAdviceList SKGCategoriesPlugin::advice(const QStringList& iIgnoredAdvice)
 
 SKGError SKGCategoriesPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
-    if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgmonthlyplugin_maincategoriesvariation|"))) {
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgmonthlyplugin_maincategoriesvariation|"))) {
         // Get parameters
         QString category = iAdviceIdentifier.right(iAdviceIdentifier.length() - 41);
         QString month = QDate::currentDate().toString(QStringLiteral("yyyy-MM"));
@@ -413,7 +417,7 @@ void SKGCategoriesPlugin::deleteUnusedCategories() const
 {
     SKGError err;
     _SKGTRACEINFUNCRC(10, err);
-    if (m_currentBankDocument) {
+    if (m_currentBankDocument != nullptr) {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused categories"), err);
 
         QStringList categoriesUsed;
