@@ -21,9 +21,9 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include <qstringlist.h>
-#include "ui_skgcategoriespluginwidget_base.h"
 #include "skgtabpage.h"
+#include "ui_skgcategoriespluginwidget_base.h"
+#include <qstringlist.h>
 
 class SKGDocumentBank;
 
@@ -45,7 +45,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGCategoriesPluginWidget();
+    ~SKGCategoriesPluginWidget() override;
 
     /**
      * Get the current state
@@ -53,38 +53,38 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() override;
+    QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) override;
+    void setState(const QString& iState) override;
 
     /**
      * Get attribute name to save the default state
      * MUST BE OVERWRITTEN
      * @return attribute name to save the default state.
      */
-    virtual QString getDefaultStateAttribute() override;
+    QString getDefaultStateAttribute() override;
 
     /**
      * Get the main widget
      * @return a widget
      */
-    virtual QWidget* mainWidget() override;
+    QWidget* mainWidget() override;
 
     /**
      * To know if this page contains an editor. MUST BE OVERWRITTEN
      * @return the editor state
      */
-    virtual bool isEditor() override;
+    bool isEditor() override;
 
     /**
      * To activate the editor by setting focus on right widget. MUST BE OVERWRITTEN
      */
-    virtual void activateEditor() override;
+    void activateEditor() override;
 
 protected:
     /**
@@ -93,7 +93,7 @@ protected:
      * @param iEvent event
      * @return In your reimplementation of this function, if you want to filter the event out, i.e. stop it being handled further, return true; otherwise return false.
      */
-    virtual bool eventFilter(QObject* iObject, QEvent* iEvent) override;
+    bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName, int iIdTransaction, bool iLightTransaction = false);
@@ -108,7 +108,7 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGCategoriesPluginWidget)
 
-    Ui::skgcategoriesplugin_base ui;
+    Ui::skgcategoriesplugin_base ui{};
 };
 
 #endif  // SKGCATEGORIESPLUGINWIDGET_H
