@@ -23,8 +23,8 @@
 */
 #include <qtimer.h>
 
-#include "ui_skgoperationpluginwidget_board.h"
 #include "skgboardwidget.h"
+#include "ui_skgoperationpluginwidget_board.h"
 
 class QAction;
 class SKGPeriodEdit;
@@ -75,7 +75,7 @@ private:
 
     void setValue(SKGProgressBar* iWidget, double iValue);
 
-    Ui::skgoperationplugin_board ui;
+    Ui::skgoperationplugin_board ui{};
 
     QAction* m_menuOpen;
     QAction* m_menuGroup;
