@@ -24,17 +24,17 @@
 #include <qdom.h>
 
 #include <qaction.h>
-#include <qwidgetaction.h>
-#include <qquickwidget.h>
 #include <qqmlcontext.h>
+#include <qquickwidget.h>
+#include <qwidgetaction.h>
 
 #include "skgdocumentbank.h"
-#include "skgreportbank.h"
-#include "skgtraces.h"
-#include "skgservices.h"
-#include "skgobjectbase.h"
 #include "skgmainpanel.h"
+#include "skgobjectbase.h"
 #include "skgperiodedit.h"
+#include "skgreportbank.h"
+#include "skgservices.h"
+#include "skgtraces.h"
 
 SKGOperationBoardWidgetQml::SKGOperationBoardWidgetQml(QWidget* iParent, SKGDocument* iDocument)
     : SKGHtmlBoardWidget(iParent, iDocument, i18nc("Dashboard widget title", "Income & Expenditure"),
@@ -156,12 +156,12 @@ QString SKGOperationBoardWidgetQml::getState()
     QDomElement root = doc.createElement(QStringLiteral("parameters"));
     doc.appendChild(root);
 
-    root.setAttribute(QStringLiteral("menuGroup"), m_menuGroup && m_menuGroup->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuTransfert"), m_menuTransfer && m_menuTransfer->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuTracked"), m_menuTracked && m_menuTracked->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("menuSuboperation"), m_menuSuboperation && m_menuSuboperation->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
-    root.setAttribute(QStringLiteral("period1"), m_periodEdit1 ? m_periodEdit1->getState() : QLatin1String(""));
-    root.setAttribute(QStringLiteral("period2"), m_periodEdit2 ? m_periodEdit2->getState() : QLatin1String(""));
+    root.setAttribute(QStringLiteral("menuGroup"), (m_menuGroup != nullptr) && m_menuGroup->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuTransfert"), (m_menuTransfer != nullptr) && m_menuTransfer->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuTracked"), (m_menuTracked != nullptr) && m_menuTracked->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("menuSuboperation"), (m_menuSuboperation != nullptr) && m_menuSuboperation->isChecked() ? QStringLiteral("Y") : QStringLiteral("N"));
+    root.setAttribute(QStringLiteral("period1"), m_periodEdit1 != nullptr ? m_periodEdit1->getState() : QLatin1String(""));
+    root.setAttribute(QStringLiteral("period2"), m_periodEdit2 != nullptr ? m_periodEdit2->getState() : QLatin1String(""));
     return doc.toString();
 }
 
@@ -170,28 +170,28 @@ void SKGOperationBoardWidgetQml::setState(const QString& iState)
     QDomDocument doc(QStringLiteral("SKGML"));
     doc.setContent(iState);
     QDomElement root = doc.documentElement();
-    if (m_menuGroup) {
+    if (m_menuGroup != nullptr) {
         QString val = root.attribute(QStringLiteral("menuGroup"));
         if (val.isEmpty()) {
             val = root.attribute(QStringLiteral("menuTransfert"));
         }
         m_menuGroup->setChecked(val == QStringLiteral("Y"));
     }
-    if (m_menuTransfer) {
+    if (m_menuTransfer != nullptr) {
         m_menuTransfer->setChecked(root.attribute(QStringLiteral("menuTransfert")) == QStringLiteral("Y"));
     }
-    if (m_menuTracked) {
+    if (m_menuTracked != nullptr) {
         m_menuTracked->setChecked(root.attribute(QStringLiteral("menuTracked")) != QStringLiteral("N"));
     }
-    if (m_menuSuboperation) {
+    if (m_menuSuboperation != nullptr) {
         m_menuSuboperation->setChecked(root.attribute(QStringLiteral("menuSuboperation")) == QStringLiteral("Y"));
     }
     QString period1 = root.attribute(QStringLiteral("period1"));
-    if (m_periodEdit1 && !period1.isEmpty()) {
+    if ((m_periodEdit1 != nullptr) && !period1.isEmpty()) {
         m_periodEdit1->setState(period1);
     }
     QString period2 = root.attribute(QStringLiteral("period2"));
-    if (m_periodEdit2 && !period2.isEmpty()) {
+    if ((m_periodEdit2 != nullptr) && !period2.isEmpty()) {
         m_periodEdit2->setState(period2);
     }
 
@@ -202,12 +202,12 @@ void SKGOperationBoardWidgetQml::setState(const QString& iState)
 void SKGOperationBoardWidgetQml::settingsModified()
 {
     SKGTRACEINFUNC(10);
-    if (m_menuOpen) {
-        SKGDocumentBank* doc = qobject_cast<SKGDocumentBank*>(getDocument());
-        if (doc) {
-            QString url = QStringLiteral("skg://skrooge_report_plugin/?grouped=") % (m_menuGroup && m_menuGroup->isChecked() ? QStringLiteral("Y") : QStringLiteral("N")) % "&transfers="
-                          % (m_menuTransfer && m_menuTransfer->isChecked() ? QStringLiteral("Y") : QStringLiteral("N")) % "&tracked="
-                          % (m_menuTracked && m_menuTracked->isChecked() ? QStringLiteral("Y") : QStringLiteral("N")) % "&expenses=Y&incomes=Y&lines2=t_TYPEEXPENSENLS&columns=d_DATEMONTH&currentPage=-1" %
+    if (m_menuOpen != nullptr) {
+        auto* doc = qobject_cast<SKGDocumentBank*>(getDocument());
+        if (doc != nullptr) {
+            QString url = QStringLiteral("skg://skrooge_report_plugin/?grouped=") % ((m_menuGroup != nullptr) && m_menuGroup->isChecked() ? QStringLiteral("Y") : QStringLiteral("N")) % "&transfers="
+                          % ((m_menuTransfer != nullptr) && m_menuTransfer->isChecked() ? QStringLiteral("Y") : QStringLiteral("N")) % "&tracked="
+                          % ((m_menuTracked != nullptr) && m_menuTracked->isChecked() ? QStringLiteral("Y") : QStringLiteral("N")) % "&expenses=Y&incomes=Y&lines2=t_TYPEEXPENSENLS&columns=d_DATEMONTH&currentPage=-1" %
                           "&mode=0&interval=3&period=3" %
                           "&tableAndGraphState.graphMode=1&tableAndGraphState.allPositive=Y&tableAndGraphState.show=graph&title=" %
                           SKGServices::encodeForUrl(i18nc("Noun, the title of a section", "Income & Expenditure"));
