@@ -69,7 +69,7 @@ private:
 
     QAction* m_menuOpen;
     QAction* m_menuGroup;
-    QAction* m_menuTransfert;
+    QAction* m_menuTransfer;
     QAction* m_menuTracked;
     QAction* m_menuSuboperation;
 
