@@ -173,15 +173,15 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGOperationPlugin)
 
-    static SKGError checkReconciliation(SKGDocument*);
-    static SKGError checkImport(SKGDocument*);
+    static SKGError checkReconciliation(SKGDocument* /*iDocument*/);
+    static SKGError checkImport(SKGDocument* /*iDocument*/);
 
     QMenu* m_applyTemplateMenu;
     QMenu* m_openOperationsWithMenu;
     QMenu* m_openSubOperationsWithMenu;
     SKGDocumentBank* m_currentBankDocument;
 
-    Ui::skgoperationplugin_pref ui;
+    Ui::skgoperationplugin_pref ui{};
 };
 
 #endif  // SKGOPERATIONPLUGIN_H
