@@ -21,11 +21,11 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include <qdom.h>
-#include "ui_skgoperationpluginwidget_base.h"
-#include "skgtabpage.h"
 #include "skgoperationobject.h"
 #include "skgsuboperationobject.h"
+#include "skgtabpage.h"
+#include "ui_skgoperationpluginwidget_base.h"
+#include <qdom.h>
 
 class SKGDocumentBank;
 class SKGObjectModel;
@@ -128,7 +128,7 @@ private Q_SLOTS:
     void onDoubleClick();
     void onQuantityChanged();
     // cppcheck-suppress passedByValue
-    void onDateChanged(const QDate iDate);
+    void onDateChanged(QDate iDate);
     void onSubopCellChanged(int row, int column);
     void onRemoveSubOperation(int iRow);
     void onRefreshInformationZone();
@@ -157,16 +157,16 @@ private:
     bool isTemplateMode();
     void displaySubOperations();
     // cppcheck-suppress passedByValue
-    void displaySubOperations(const SKGOperationObject& iOperation, bool iKeepId = true, const QDate iSubOperationsDate = QDate());
+    void displaySubOperations(const SKGOperationObject& iOperation, bool iKeepId = true, QDate iSubOperationsDate = QDate());
     double getRemainingQuantity();
     // cppcheck-suppress passedByValue
-    void addSubOperationLine(int row, const QDate date, const QString& category, const QString& tracker, const QString& comment, double quantity, const QString& formula, int id = 0);
+    void addSubOperationLine(int row, QDate date, const QString& category, const QString& tracker, const QString& comment, double quantity, const QString& formula, int id = 0);
     SKGError updateSelection(const SKGObjectBase::SKGListSKGObjectBase& iSelection, bool iForceCreation = false);
     void fillNumber();
     QString getAttributeOfSelection(const QString& iAttribute);
     QString currentAccount();
 
-    Ui::skgoperationplugin_base ui;
+    Ui::skgoperationplugin_base ui{};
     SKGObjectModel* m_objectModel;
     QString m_operationWhereClause;
     QString m_previousValue;
