@@ -113,7 +113,7 @@ private:
 
     SKGDocument* m_currentBankDocument;
 
-    Ui::skgpayeeplugin_pref ui;
+    Ui::skgpayeeplugin_pref ui{};
 };
 
 #endif  // SKGPAYEEPLUGIN_H
