@@ -22,9 +22,9 @@
 #include "skgreportboardwidget.h"
 
 #include "skgdocumentbank.h"
-#include "skgtraces.h"
 #include "skgmainpanel.h"
 #include "skgreportpluginwidget.h"
+#include "skgtraces.h"
 
 SKGReportBoardWidget::SKGReportBoardWidget(QWidget* iParent, SKGDocumentBank* iDocument)
     : SKGBoardWidget(iParent, iDocument, i18nc("Dashboard widget title", "Report"), true)
@@ -62,7 +62,7 @@ QString SKGReportBoardWidget::getState()
     doc.setContent(SKGBoardWidget::getState());
     QDomElement root = doc.documentElement();
 
-    if (m_graph) {
+    if (m_graph != nullptr) {
         root.setAttribute(QStringLiteral("graph"), m_graph->getState());
     }
     return doc.toString();
@@ -83,7 +83,7 @@ void SKGReportBoardWidget::setState(const QString& iState)
 
 
         QString graphS = root.attribute(QStringLiteral("graph"));
-        if (m_graph) {
+        if (m_graph != nullptr) {
             if (graphS.isEmpty()) {
                 m_graph->setState(iState);
             } else {
@@ -102,7 +102,7 @@ void SKGReportBoardWidget::dataModified(const QString& iTableName, int iIdTransa
     if (iTableName == QStringLiteral("operation") || iTableName.isEmpty()) {
         bool exist = false;
         getDocument()->existObjects(QStringLiteral("account"), QLatin1String(""), exist);
-        if (parentWidget()) {
+        if (parentWidget() != nullptr) {
             setVisible(exist);
         }
     }
