@@ -21,28 +21,28 @@
  */
 #include "skgreportplugin.h"
 
-#include <qaction.h>
-#include <kactioncollection.h>
 #include <kaboutdata.h>
+#include <kactioncollection.h>
 #include <kpluginfactory.h>
+#include <qaction.h>
 
 #include <qdom.h>
 
-#include "skgreportpluginwidget.h"
-#include "skgtraces.h"
-#include "skgmainpanel.h"
-#include "skgservices.h"
 #include "skgaccountobject.h"
 #include "skgcategoryobject.h"
-#include "skgtrackerobject.h"
-#include "skgunitobject.h"
-#include "skgruleobject.h"
-#include "skgpayeeobject.h"
-#include "skgnodeobject.h"
-#include "skgreportboardwidget.h"
 #include "skgdocumentbank.h"
 #include "skghtmlboardwidget.h"
+#include "skgmainpanel.h"
+#include "skgnodeobject.h"
+#include "skgpayeeobject.h"
 #include "skgreport_settings.h"
+#include "skgreportboardwidget.h"
+#include "skgreportpluginwidget.h"
+#include "skgruleobject.h"
+#include "skgservices.h"
+#include "skgtraces.h"
+#include "skgtrackerobject.h"
+#include "skgunitobject.h"
 
 /**
  * This plugin factory.
@@ -123,15 +123,16 @@ QString SKGReportPlugin::getDashboardWidgetTitle(int iIndex)
     Q_UNUSED(iIndex);
     if (iIndex == 0)  {
         return i18nc("Noun, the title of a section", "Report");
-    } if (iIndex == 1) {
-        return i18nc("Noun, the title of a section",  "Personal Financial Score");
-    } else {
-        SKGObjectBase::SKGListSKGObjectBase objs;
-        m_currentBankDocument->getObjects(QStringLiteral("node"), QStringLiteral("t_data like '\"Skrooge report plugin\";%' ORDER BY t_fullname"), objs);
-        if (iIndex - 2 < objs.count()) {
-            return  i18nc("Noun, the title of a section", "Report bookmarked named \"%1\"", objs[iIndex - 2].getAttribute(QStringLiteral("t_fullname")));
-        }
     }
+    if (iIndex == 1) {
+        return i18nc("Noun, the title of a section",  "Personal Financial Score");
+    }
+    SKGObjectBase::SKGListSKGObjectBase objs;
+    m_currentBankDocument->getObjects(QStringLiteral("node"), QStringLiteral("t_data like '\"Skrooge report plugin\";%' ORDER BY t_fullname"), objs);
+    if (iIndex - 2 < objs.count()) {
+        return  i18nc("Noun, the title of a section", "Report bookmarked named \"%1\"", objs[iIndex - 2].getAttribute(QStringLiteral("t_fullname")));
+    }
+
     return QLatin1String("");
 }
 
@@ -140,7 +141,8 @@ SKGBoardWidget* SKGReportPlugin::getDashboardWidget(int iIndex)
     Q_UNUSED(iIndex);
     if (iIndex == 0)  {
         return new SKGReportBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
-    } else if (iIndex == 1)  {
+    }
+    if (iIndex == 1)  {
         // Get QML mode for dashboard
         KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
         KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
@@ -150,19 +152,19 @@ SKGBoardWidget* SKGReportPlugin::getDashboardWidget(int iIndex)
                                       getDashboardWidgetTitle(iIndex) % " - %1",
                                       QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/personal_finance_score.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
                                       QStringList() << QStringLiteral("v_suboperation_consolidated"), SKGSimplePeriodEdit::PREVIOUS_MONTHS);
-    }  else {
-        SKGObjectBase::SKGListSKGObjectBase objs;
-        m_currentBankDocument->getObjects(QStringLiteral("node"), QStringLiteral("t_data like '\"Skrooge report plugin\";%' ORDER BY t_fullname"), objs);
-        if (iIndex - 2 < objs.count()) {
-            SKGReportBoardWidget* report = new SKGReportBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
-            QString state = SKGServices::splitCSVLine(objs.at(iIndex - 2).getAttribute(QStringLiteral("t_data"))).at(2);
-            state = state.replace(QStringLiteral("isToolBarVisible=&amp;quot;Y&amp;quot;"), QStringLiteral("isToolBarVisible=&amp;quot;N&amp;quot;"));
-            state = state.replace(QStringLiteral("show=&quot;&amp;quot;table&amp;quot;;&amp;quot;graph&amp;quot;&quot;"), QStringLiteral("show=&quot;&amp;quot;graph&amp;quot;&quot;"));
-            state = state.replace(QStringLiteral("currentPage=\"0\""), QStringLiteral("currentPage=\"-1\""));
-            report->setState(state);
-            return  report;
-        }
     }
+    SKGObjectBase::SKGListSKGObjectBase objs;
+    m_currentBankDocument->getObjects(QStringLiteral("node"), QStringLiteral("t_data like '\"Skrooge report plugin\";%' ORDER BY t_fullname"), objs);
+    if (iIndex - 2 < objs.count()) {
+        auto* report = new SKGReportBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
+        QString state = SKGServices::splitCSVLine(objs.at(iIndex - 2).getAttribute(QStringLiteral("t_data"))).at(2);
+        state = state.replace(QStringLiteral("isToolBarVisible=&amp;quot;Y&amp;quot;"), QStringLiteral("isToolBarVisible=&amp;quot;N&amp;quot;"));
+        state = state.replace(QStringLiteral("show=&quot;&amp;quot;table&amp;quot;;&amp;quot;graph&amp;quot;&quot;"), QStringLiteral("show=&quot;&amp;quot;graph&amp;quot;&quot;"));
+        state = state.replace(QStringLiteral("currentPage=\"0\""), QStringLiteral("currentPage=\"-1\""));
+        report->setState(state);
+        return  report;
+    }
+
     return nullptr;
 }
 
@@ -230,7 +232,7 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
 
             for (int i = 0; i < nb; ++i) {
                 SKGAccountObject tmp(iSelection.at(i));
-                if (i) {
+                if (i != 0) {
                     oWhereClause += ',';
                     oTitle += ',';
                 }
@@ -244,7 +246,7 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
 
             for (int i = 0; i < nb; ++i) {
                 SKGUnitObject tmp(iSelection.at(i));
-                if (i) {
+                if (i != 0) {
                     oWhereClause += ',';
                     oTitle += ',';
                 }
@@ -259,7 +261,7 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
 
             for (int i = 0; i < nb; ++i) {
                 SKGCategoryObject tmp(iSelection.at(i));
-                if (i) {
+                if (i != 0) {
                     oWhereClause += ',';
                     wc2 += QStringLiteral(" OR ");
                     oTitle += ',';
@@ -275,7 +277,7 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
 
             for (int i = 0; i < nb; ++i) {
                 SKGTrackerObject tmp(iSelection.at(i));
-                if (i) {
+                if (i != 0) {
                     oWhereClause += ',';
                     oTitle += ',';
                 }
@@ -289,7 +291,7 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
 
             for (int i = 0; i < nb; ++i) {
                 SKGPayeeObject tmp(iSelection.at(i));
-                if (i) {
+                if (i != 0) {
                     oWhereClause += ',';
                     oTitle += ',';
                 }
@@ -302,7 +304,7 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
             oTitle = i18nc("Noun, a list of items", "Selected operations");
 
             for (int i = 0; i < nb; ++i) {
-                if (i) {
+                if (i != 0) {
                     oWhereClause += ',';
                 }
                 oWhereClause += SKGServices::intToString(iSelection.at(i).getID());
@@ -313,7 +315,7 @@ void SKGReportPlugin::getTitleAndWhereClause(const SKGObjectBase::SKGListSKGObje
             oTitle = i18nc("Noun, a list of items", "Selected sub operations");
 
             for (int i = 0; i < nb; ++i) {
-                if (i) {
+                if (i != 0) {
                     oWhereClause += ',';
                 }
                 oWhereClause += SKGServices::intToString(iSelection.at(i).getID());
@@ -343,7 +345,7 @@ void SKGReportPlugin::onOpenReport()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    if (SKGMainPanel::getMainPanel()) {
+    if (SKGMainPanel::getMainPanel() != nullptr) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
         int nb = selection.count();
