@@ -26,6 +26,7 @@
 #include <qgraphicsscene.h>
 #include <qlistwidget.h>
 #include <qmenu.h>
+#include <qwidgetaction.h>
 
 #include "skgbankincludes.h"
 #include "skgcolorbutton.h"
@@ -114,7 +115,24 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
     }
 
     QMenu* graphMenu = ui.kTableWithGraph->getGraphContextualMenu();
-    if (graphMenu != nullptr) {
+    if (iMinimmumMode && graphMenu != nullptr) {
+        graphMenu->addSeparator();
+        QList<QCheckBox*> list;
+        list << ui.kIncomes << ui.kExpenses << ui.kGrouped << ui.kTransfers << ui.kTracked;
+        for (auto actref : qAsConst(list)) {
+            auto act = graphMenu->addAction(actref->text());
+            if (act != nullptr) {
+                act->setCheckable(true);
+                act->setChecked(actref->isChecked());
+                connect(act, &QAction::triggered, actref, &QCheckBox::setChecked);
+                connect(actref, &QCheckBox::toggled, act, &QAction::setChecked);
+            }
+        }
+        graphMenu->addSeparator();
+        auto act = new QWidgetAction(this);
+        act->setDefaultWidget(ui.kColumns);
+        graphMenu->addAction(act);
+
         graphMenu->addSeparator();
         graphMenu->addAction(m_openAction);
         graphMenu->addAction(m_openReportAction);
@@ -144,7 +162,9 @@ SKGReportPluginWidget::SKGReportPluginWidget(QWidget* iParent, SKGDocumentBank*
     for (int i = 0; i < nb; ++i) {
         m_attsForLines.push_back("p_" % properties.at(i));
     }
-    m_attsForColumns += m_attsForLines;
+    if (!iMinimmumMode) {
+        m_attsForColumns += m_attsForLines;
+    }
 
     for (const auto& att : qAsConst(m_attsForColumns)) {
         ui.kColumns->addItem(iDocument->getIcon(att), iDocument->getDisplay(att));
@@ -937,7 +957,7 @@ void SKGReportPluginWidget::dataModified(const QString& iTableName, int iIdTrans
                 bool transactionToRollback = false;
                 if (forecastMode == 1 || forecastMode == 4) {
                     // Create operations
-                    QDate lastDate = QDate::currentDate().addDays(ui.kForecastValue->value() * 365.0 / ui.kForecastValue->maximum());
+                    QDate lastDate = QDate::currentDate().addDays(ui.kForecastValue->value() * skgreport_settings::maxForecasts() * 365.0 / ui.kForecastValue->maximum());
                     if (forecastMode == 1) {
                         // Create scheduled operations
                         doc->beginTransaction("#INTERNAL#" % i18nc("Progression step", "Create scheduled operations"));
