@@ -24,14 +24,13 @@
 #include <kaboutdata.h>
 #include <kactioncollection.h>
 #include <kpluginfactory.h>
-#include <kstandardaction.h>
 #include <qstandardpaths.h>
 
 #include "skgdocumentbank.h"
-#include "skghtmlboardwidget.h"
 #include "skgmainpanel.h"
 #include "skgrecurrentoperationobject.h"
 #include "skgscheduled_settings.h"
+#include "skgscheduledboardwidget.h"
 #include "skgscheduledpluginwidget.h"
 #include "skgsuboperationobject.h"
 #include "skgtraces.h"
@@ -72,6 +71,11 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument)
     connect(actScheduleOperation, &QAction::triggered, this, &SKGScheduledPlugin::onScheduleOperation);
     actionCollection()->setDefaultShortcut(actScheduleOperation, Qt::CTRL + Qt::Key_I);
     registerGlobalAction(QStringLiteral("schedule_operation"), actScheduleOperation, QStringList() << QStringLiteral("operation"), 1, -1, 410);
+
+    auto actSkipScheduledOperation = new QAction(SKGServices::fromTheme(QStringLiteral("nextuntranslated")), i18nc("Verb, skip scheduled operations", "Skip"), this);
+    connect(actSkipScheduledOperation, &QAction::triggered, this, &SKGScheduledPlugin::onSkipScheduledOperations);
+    registerGlobalAction(QStringLiteral("skip_scheduled_operations"), actSkipScheduledOperation, QStringList() << QStringLiteral("recurrentoperation"), 1, -1, 410);
+
     return true;
 }
 
@@ -112,15 +116,8 @@ QString SKGScheduledPlugin::getDashboardWidgetTitle(int iIndex)
 
 SKGBoardWidget* SKGScheduledPlugin::getDashboardWidget(int iIndex)
 {
-    // Get QML mode for dashboard
-    KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
-    KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
-    bool qml = sklItem->property().toBool();
-
-    return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
-                                  getDashboardWidgetTitle(iIndex),
-                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/scheduled_operations.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
-                                  QStringList() << QStringLiteral("v_recurrentoperation_display"));
+    Q_UNUSED(iIndex);
+    return new SKGScheduledBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
 }
 
 SKGTabPage* SKGScheduledPlugin::getWidget()
@@ -297,6 +294,49 @@ void SKGScheduledPlugin::onScheduleOperation()
     }
 }
 
+void SKGScheduledPlugin::onSkipScheduledOperations()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(10, err);
+
+    // Get Selection
+    if (SKGMainPanel::getMainPanel() != nullptr) {
+        SKGObjectBase::SKGListSKGObjectBase selection;
+        auto selectionString = sender()->property("selection").toString();
+        if (!selectionString.isEmpty()) {
+            selection.append(SKGRecurrentOperationObject(m_currentBankDocument, SKGServices::stringToInt(SKGServices::splitCSVLine(selectionString, QLatin1Char('-'), false).at(0))));
+        } else {
+            selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+        }
+        int nb = selection.count();
+        if ((nb != 0) && (m_currentBankDocument != nullptr)) {
+            QStringList list;
+            SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Skip scheduled operations"), err, nb);
+            for (int i = 0; !err && i < nb; ++i) {
+                SKGRecurrentOperationObject rop(m_currentBankDocument, selection.at(i).getID());
+                err = rop.setDate(rop.getNextDate());
+                if (!err && rop.hasTimeLimit()) {
+                    err = rop.setTimeLimit(rop.getTimeLimit() - 1);
+                }
+                IFOKDO(err, rop.save())
+
+                IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
+                list.push_back(rop.getUniqueID());
+            }
+        }
+
+        // status bar
+        IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Scheduled operations skipped.")))
+        else {
+            err.addError(ERR_FAIL, i18nc("Error message",  "Skip of scheduled operation failed"));
+        }
+
+        // Display error
+        SKGMainPanel::displayErrorMessage(err);
+    }
+}
+
+
 SKGAdviceList SKGScheduledPlugin::advice(const QStringList& iIgnoredAdvice)
 {
     SKGTRACEINFUNC(10);
