@@ -234,6 +234,8 @@ void SKGScheduledPluginWidget::onNbOccurrenceChanged()
             int nbd = firstDate.daysTo(lastDate);
             if (punit == SKGRecurrentOperationObject::DAY) {
                 nbd = nbd / p;
+            } else if (punit == SKGRecurrentOperationObject::WEEK) {
+                nbd = nbd / p / 7;
             } else if (punit == SKGRecurrentOperationObject::MONTH) {
                 nbd = (lastDate.day() >= firstDate.day() ? 0 : -1) + (lastDate.year() - firstDate.year()) * 12 + (lastDate.month() - firstDate.month());
             } else if (punit == SKGRecurrentOperationObject::YEAR) {
@@ -250,6 +252,8 @@ void SKGScheduledPluginWidget::onNbOccurrenceChanged()
         p *= (ui.kNbTimesVal->value() - 1);
         if (punit == SKGRecurrentOperationObject::DAY) {
             firstDate = firstDate.addDays(p);
+        } else if (punit == SKGRecurrentOperationObject::WEEK) {
+            firstDate = firstDate.addDays(7 * p);
         } else if (punit == SKGRecurrentOperationObject::MONTH) {
             firstDate = firstDate.addMonths(p);
         } else if (punit == SKGRecurrentOperationObject::YEAR) {
