@@ -21,24 +21,24 @@
  */
 #include "skgsearchplugin.h"
 
-#include <kactioncollection.h>
-#include <kstandardaction.h>
 #include <kaboutdata.h>
+#include <kactioncollection.h>
 #include <kpluginfactory.h>
+#include <kstandardaction.h>
 
 #include <qdom.h>
 
-#include "skgsearchpluginwidget.h"
-#include "skgsearch_settings.h"
-#include "skgtraces.h"
-#include "skgerror.h"
-#include "skgruleobject.h"
-#include "skgmainpanel.h"
-#include "skgtransactionmng.h"
 #include "skgalarmboardwidget.h"
-#include "skgdocumentbank.h"
 #include "skgcategoryobject.h"
+#include "skgdocumentbank.h"
+#include "skgerror.h"
 #include "skghtmlboardwidget.h"
+#include "skgmainpanel.h"
+#include "skgruleobject.h"
+#include "skgsearch_settings.h"
+#include "skgsearchpluginwidget.h"
+#include "skgtraces.h"
+#include "skgtransactionmng.h"
 
 /**
  * This plugin factory.
@@ -144,7 +144,7 @@ void SKGSearchPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
     // Start alarm
-    if (m_currentBankDocument && m_currentBankDocument->getMainDatabase() != nullptr) {
+    if ((m_currentBankDocument != nullptr) && m_currentBankDocument->getMainDatabase() != nullptr) {
         QString doc_id = m_currentBankDocument->getUniqueIdentifier();
         if (m_docUniqueIdentifier != doc_id) {
             m_docUniqueIdentifier = doc_id;
@@ -156,11 +156,11 @@ void SKGSearchPlugin::refresh()
 
 void SKGSearchPlugin::raiseAlarms()
 {
-    if (m_currentBankDocument) {
+    if (m_currentBankDocument != nullptr) {
         SKGObjectBase::SKGListSKGObjectBase rules;
         SKGError err = m_currentBankDocument->getObjects(QStringLiteral("v_rule"), QStringLiteral("t_action_type='A' ORDER BY i_ORDER"), rules);
         int nb = rules.count();
-        if (!err && nb) {
+        if (!err && (nb != 0)) {
             for (int i = 0; !err && i < nb; ++i) {
                 SKGRuleObject rule(rules.at(i));
                 rule.execute();
@@ -183,7 +183,7 @@ void SKGSearchPlugin::execute(SKGRuleObject::ProcessMode iMode)
     SKGObjectBase::SKGListSKGObjectBase rules = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
     int nb = rules.count();
-    if (m_currentBankDocument) {
+    if (m_currentBankDocument != nullptr) {
         SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Process execution"), err, nb);
         for (int i = 0; !err && i < nb; ++i) {
             SKGRuleObject rule(rules.at(i));
@@ -206,7 +206,7 @@ void SKGSearchPlugin::find()
 {
     SKGError err;
     SKGTRACEINFUNCRC(10, err);
-    if (SKGMainPanel::getMainPanel()) {
+    if (SKGMainPanel::getMainPanel() != nullptr) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
 
         QString xmlsearchcondition;
@@ -290,7 +290,7 @@ void SKGSearchPlugin::find()
                     element.appendChild(elementLine);
 
                     for (int j = 0; j < attributeForQuery.count(); ++j) {
-                        QString att = attributeForQuery.at(j);
+                        const QString& att = attributeForQuery.at(j);
                         QString attRead = (att == QStringLiteral("t_REALCATEGORY") ? QStringLiteral("t_CATEGORY") : (att == QStringLiteral("f_REALCURRENTAMOUNT") ? QStringLiteral("f_CURRENTAMOUNT") : (att == QStringLiteral("t_REALREFUND") ? QStringLiteral("t_REFUND") : att)));
 
                         SKGObjectBase op(selection.at(i).getDocument(), QStringLiteral("v_operation_display_all"), selection.at(i).getID());
@@ -378,7 +378,7 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
         SKGObjectBase::SKGListSKGObjectBase rules;
         SKGError err = m_currentBankDocument->getObjects(QStringLiteral("v_rule"), QStringLiteral("t_action_type='A' ORDER BY i_ORDER"), rules);
         int nb = rules.count();
-        if (nb) {
+        if (nb != 0) {
             SKGServices::SKGUnitInfo primary = m_currentBankDocument->getPrimaryUnit();
             SKGAdvice::SKGAdviceActionList autoCorrections;
             for (int i = 0; !err && i < nb; ++i) {
@@ -424,7 +424,7 @@ SKGAdviceList SKGSearchPlugin::advice(const QStringList& iIgnoredAdvice)
 
 SKGError SKGSearchPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
-    if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgsearchplugin_alarm|"))) {
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgsearchplugin_alarm|"))) {
         // Get parameters
         QString id = iAdviceIdentifier.right(iAdviceIdentifier.length() - 22);
         SKGSearchPluginWidget::open(SKGRuleObject(m_currentBankDocument, SKGServices::stringToInt(id)));
