@@ -113,7 +113,7 @@ private:
 
     SKGDocument* m_currentBankDocument;
 
-    Ui::skgtrackerplugin_pref ui;
+    Ui::skgtrackerplugin_pref ui{};
 };
 
 #endif  // SKGTRACKERPLUGIN_H
