@@ -24,10 +24,10 @@
 #include <qdom.h>
 #include <qevent.h>
 
-#include "skgmainpanel.h"
-#include "skgtraces.h"
-#include "skgobjectmodel.h"
 #include "skgdocumentbank.h"
+#include "skgmainpanel.h"
+#include "skgobjectmodel.h"
+#include "skgtraces.h"
 #include "skgtrackerobject.h"
 #include "skgtransactionmng.h"
 
@@ -35,7 +35,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(QWidget* iParent, SKGDocument* iD
     : SKGTabPage(iParent, iDocument)
 {
     SKGTRACEINFUNC(1);
-    if (!iDocument) {
+    if (iDocument == nullptr) {
         return;
     }
 
@@ -53,7 +53,7 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(QWidget* iParent, SKGDocument* iD
     ui.kAddButton->setIcon(SKGServices::fromTheme(QStringLiteral("list-add")));
     ui.kModifyButton->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-ok")));
 
-    ui.kView->setModel(new SKGObjectModel(static_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_refund_display"), QStringLiteral("1=0"), this, QLatin1String(""), false));
+    ui.kView->setModel(new SKGObjectModel(qobject_cast<SKGDocumentBank*>(getDocument()), QStringLiteral("v_refund_display"), QStringLiteral("1=0"), this, QLatin1String(""), false));
 
     ui.kView->getView()->resizeColumnToContents(0);
 
@@ -72,19 +72,16 @@ SKGTrackerPluginWidget::SKGTrackerPluginWidget(QWidget* iParent, SKGDocument* iD
     dataModified(QLatin1String(""), 0);
 }
 
-SKGTrackerPluginWidget::~SKGTrackerPluginWidget()
-{
-    SKGTRACEINFUNC(1);
-}
+SKGTrackerPluginWidget::~SKGTrackerPluginWidget() = default;
 
 bool SKGTrackerPluginWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (iEvent && iEvent->type() == QEvent::KeyPress) {
-        QKeyEvent* keyEvent = static_cast<QKeyEvent*>(iEvent);
+    if ((iEvent != nullptr) && iEvent->type() == QEvent::KeyPress) {
+        auto* keyEvent = dynamic_cast<QKeyEvent*>(iEvent);
         if ((keyEvent->key() == Qt::Key_Return || keyEvent->key() == Qt::Key_Enter) && iObject == this) {
-            if (QApplication::keyboardModifiers() &Qt::ControlModifier && ui.kAddButton->isEnabled()) {
+            if ((QApplication::keyboardModifiers() & Qt::ControlModifier) != 0u && ui.kAddButton->isEnabled()) {
                 ui.kAddButton->click();
-            } else if (QApplication::keyboardModifiers() &Qt::ShiftModifier && ui.kModifyButton->isEnabled()) {
+            } else if ((QApplication::keyboardModifiers() &Qt::ShiftModifier) != 0u && ui.kModifyButton->isEnabled()) {
                 ui.kModifyButton->click();
             }
         }
@@ -174,7 +171,7 @@ void SKGTrackerPluginWidget::onAddTracker()
     {
         SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Tracker creation '%1'", name), err);
 
-        err = SKGTrackerObject::createTracker(static_cast<SKGDocumentBank*>(getDocument()), name, tracker);
+        err = SKGTrackerObject::createTracker(qobject_cast<SKGDocumentBank*>(getDocument()), name, tracker);
         IFOKDO(err, tracker.setComment(ui.kCommentEdit->text()))
         IFOKDO(err, tracker.save())
 
