@@ -43,7 +43,7 @@ public:
     /**
      * Default Destructor
      */
-    virtual ~SKGUnitBoardWidget();
+    ~SKGUnitBoardWidget() override;
 
     /**
      * Get the current state
@@ -51,14 +51,14 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() override;
+    QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) override;
+    void setState(const QString& iState) override;
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName = QString(), int iIdTransaction = 0);
