@@ -21,24 +21,22 @@
  */
 #include "skgunitplugin.h"
 
-#include <float.h>
-
-#include <kactioncollection.h>
 #include <kaboutdata.h>
+#include <kactioncollection.h>
 #include <kpluginfactory.h>
 
 #include <qaction.h>
 #include <qinputdialog.h>
 #include <qprocess.h>
 
-#include "skgunitpluginwidget.h"
-#include "skgunitboardwidget.h"
-#include "skgunit_settings.h"
-#include "skgtraces.h"
-#include "skgmainpanel.h"
-#include "skghtmlboardwidget.h"
-#include "skgtransactionmng.h"
 #include "skgdocumentbank.h"
+#include "skghtmlboardwidget.h"
+#include "skgmainpanel.h"
+#include "skgtraces.h"
+#include "skgtransactionmng.h"
+#include "skgunit_settings.h"
+#include "skgunitboardwidget.h"
+#include "skgunitpluginwidget.h"
 #include "skgunitvalueobject.h"
 
 /**
@@ -93,32 +91,30 @@ QString SKGUnitPlugin::getDashboardWidgetTitle(int iIndex)
 {
     if (iIndex == 0) {
         return i18nc("Noun, the title of a section", "Quotes");
-    } else {
-        return i18nc("Noun, the title of a section", "Stock portfolio");
     }
+    return i18nc("Noun, the title of a section", "Stock portfolio");
 }
 
 SKGBoardWidget* SKGUnitPlugin::getDashboardWidget(int iIndex)
 {
     if (iIndex == 0) {
         return new SKGUnitBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument);
-    } else {
-        // Get QML mode for dashboard
-        KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
-        KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
-        bool qml = sklItem->property().toBool();
-
-        return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
-                                      getDashboardWidgetTitle(iIndex),
-                                      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/portfolio.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
-                                      QStringList() << QStringLiteral("v_operation_display"));
     }
+    // Get QML mode for dashboard
+    KConfigSkeleton* skl = SKGMainPanel::getMainPanel()->getPluginByName(QStringLiteral("Dashboard plugin"))->getPreferenceSkeleton();
+    KConfigSkeletonItem* sklItem = skl->findItem(QStringLiteral("qmlmode"));
+    bool qml = sklItem->property().toBool();
+
+    return new SKGHtmlBoardWidget(SKGMainPanel::getMainPanel(), m_currentBankDocument,
+                                  getDashboardWidgetTitle(iIndex),
+                                  QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("skrooge/html/default/portfolio.") % (qml ?  QStringLiteral("qml") :  QStringLiteral("html"))),
+                                  QStringList() << QStringLiteral("v_operation_display"));
 }
 
 void SKGUnitPlugin::refresh()
 {
     SKGTRACEINFUNC(10);
-    if (SKGMainPanel::getMainPanel() && m_currentBankDocument) {
+    if ((SKGMainPanel::getMainPanel() != nullptr) && (m_currentBankDocument != nullptr)) {
         // Automatic download
         QString doc_id = m_currentBankDocument->getUniqueIdentifier();
         if (m_docUniqueIdentifier != doc_id) {
@@ -244,14 +240,14 @@ void SKGUnitPlugin::onSplitShare()
     SKGTRACEINFUNCRC(10, err);
 
     // Get Selection
-    if (SKGMainPanel::getMainPanel()) {
+    if (SKGMainPanel::getMainPanel() != nullptr) {
         SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
         int nb = selection.count();
         if (nb == 1) {
             bool ok = false;
             double ratio = QInputDialog::getDouble(SKGMainPanel::getMainPanel(), i18nc("Question", "Split share"),
                                                    i18nc("Question", "Ratio (2 means 2-for-1, 0.5 means 1-for-2):"), 2.0,
-                                                   0, DBL_MAX, 8, &ok);
+                                                   0, std::numeric_limits<double>::max(), 8, &ok);
             if (ok) {
                 SKGUnitObject unit(selection.at(0));
                 SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Split stock '%1' by '%2'", unit.getName(), ratio), err);
@@ -353,9 +349,9 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
-            QStringList line = result.at(i);
-            QString unit = line.at(0);
-            QString internet_code = line.at(1);
+            const QStringList& line = result.at(i);
+            const QString& unit = line.at(0);
+            const QString& internet_code = line.at(1);
 
             SKGAdvice ad;
             ad.setUUID("skgunitplugin_notdownloaded|" % unit);
@@ -407,8 +403,8 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
-            QStringList line = result.at(i);
-            QString unit = line.at(0);
+            const QStringList& line = result.at(i);
+            const QString& unit = line.at(0);
 
             SKGAdvice ad;
             ad.setUUID("skgunitplugin_amountnotdefined|" % unit);
@@ -436,8 +432,8 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
-            QStringList line = result.at(i);
-            QString unit = line.at(0);
+            const QStringList& line = result.at(i);
+            const QString& unit = line.at(0);
 
             SKGAdvice ad;
             ad.setUUID(QStringLiteral("skgunitplugin_toocomplex"));
@@ -465,8 +461,8 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
         autoCorrections.reserve(nb);
         for (int i = 1; i < nb; ++i) {  // Ignore header
             // Get parameters
-            QStringList line = result.at(i);
-            QString unit = line.at(0);
+            const QStringList& line = result.at(i);
+            const QString& unit = line.at(0);
 
             SKGAdvice ad;
             ad.setUUID("skgunitplugin_veryold|" % unit);
@@ -510,7 +506,7 @@ SKGAdviceList SKGUnitPlugin::advice(const QStringList& iIgnoredAdvice)
 
 SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier, int iSolution)
 {
-    if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_primaryunit|"))) {
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_primaryunit|"))) {
         if (iSolution == 1) {
             SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
         } else {
@@ -541,7 +537,8 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         }
 
         return SKGError();
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_secondaryunit|"))) {
+    }
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_secondaryunit|"))) {
         if (iSolution == 1) {
             SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
         } else {
@@ -572,7 +569,8 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         }
 
         return SKGError();
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_notdownloaded|"))) {
+    }
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_notdownloaded|"))) {
         if (iSolution == 0) {
             SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
         } else {
@@ -590,13 +588,15 @@ SKGError SKGUnitPlugin::executeAdviceCorrection(const QString& iAdviceIdentifier
         }
 
         return SKGError();
-    } else if (m_currentBankDocument && (iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_veryold|")) ||
-                                         iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_toocomplex")) ||
-                                         iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_amountnotdefined|")))
-              ) {
+    }
+    if ((m_currentBankDocument != nullptr) && (iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_veryold|")) ||
+            iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_toocomplex")) ||
+            iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_amountnotdefined|")))
+       ) {
         SKGMainPanel::getMainPanel()->openPage(QStringLiteral("skg://skrooge_unit_plugin"));
         return SKGError();
-    } else if (m_currentBankDocument && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_decimalsymbol"))) {
+    }
+    if ((m_currentBankDocument != nullptr) && iAdviceIdentifier.startsWith(QLatin1String("skgunitplugin_decimalsymbol"))) {
         QProcess::execute(QStringLiteral("kcmshell5"), QStringList() << QStringLiteral("formats"));
         return SKGError();
     }
@@ -607,7 +607,7 @@ void SKGUnitPlugin::deleteUnusedUnits() const
 {
     SKGError err;
     _SKGTRACEINFUNCRC(10, err);
-    if (m_currentBankDocument) {
+    if (m_currentBankDocument != nullptr) {
         SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Delete unused units"), err);
 
         // Modification of payee object
