@@ -21,25 +21,25 @@
  */
 #include "skgpredicatcreator.h"
 
-#include <qdom.h>
-#include <qtablewidget.h>
-#include <qcheckbox.h>
 #include <qapplication.h>
+#include <qcheckbox.h>
+#include <qdom.h>
 #include <qlineedit.h>
+#include <qtablewidget.h>
 
+#include "skgcalculatoredit.h"
+#include "skgcombobox.h"
+#include "skgdateedit.h"
 #include "skgdocument.h"
 #include "skgmainpanel.h"
-#include "skgservices.h"
-#include "skgcombobox.h"
-#include "skgcalculatoredit.h"
-#include "skgdateedit.h"
 #include "skgruleobject.h"
+#include "skgservices.h"
 
 SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document, const QString& attribute, bool iModeUpdate, const QStringList& iListAtt)
     : QWidget(iParent), m_updateMode(iModeUpdate), m_kValue1(nullptr), m_kValue2(nullptr), m_kAttributes(nullptr)
 {
     SKGServices::AttributeType attType = SKGServices::TEXT;
-    if (document) {
+    if (document != nullptr) {
         attType = document->getAttributeType(attribute);
     }
 
@@ -61,9 +61,9 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
 
     horizontalLayout->addWidget(m_kOperator);
     int nbAtt = iListAtt.count();
-    if (nbAtt) {
+    if (nbAtt != 0) {
         m_kAttributes = new SKGComboBox(this);
-        if (m_kAttributes) {
+        if (m_kAttributes != nullptr) {
             m_kAttributes->setObjectName(QStringLiteral("kAttributes"));
             m_kAttributes->setMinimumSize(QSize(100, 0));
             m_kAttributes->setEditable(false);
@@ -76,7 +76,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             horizontalLayout->addWidget(m_kAttributes);
 
             for (const auto& att : qAsConst(iListAtt)) {
-                if (document) {
+                if (document != nullptr) {
                     m_kAttributes->addItem(document->getIcon(att), document->getDisplay(att), att);
                 }
             }
@@ -84,7 +84,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     }
     if (attType == SKGServices::TEXT) {
         auto cmbVal1 = new SKGComboBox(this);
-        if (cmbVal1) {
+        if (cmbVal1 != nullptr) {
             cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
             cmbVal1->setEditable(true);
@@ -99,7 +99,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             m_kValue1 = cmbVal1;
         }
         auto cmbVal2 = new SKGComboBox(this);
-        if (cmbVal2) {
+        if (cmbVal2 != nullptr) {
             cmbVal2->setObjectName(QStringLiteral("cmbVal2"));
             cmbVal2->setMinimumSize(QSize(100, 0));
             cmbVal2->setEditable(true);
@@ -114,7 +114,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             m_kValue2 = cmbVal2;
         }
 
-        if (document) {
+        if (document != nullptr) {
             QString realTable = QStringLiteral("operation");
             QString realAtt = attribute;
             QString realCond = QLatin1String("");
@@ -148,7 +148,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
         }
     } else  if (attType == SKGServices::INTEGER || attType == SKGServices::FLOAT) {
         auto cmbVal1 = new SKGCalculatorEdit(this);
-        if (cmbVal1) {
+        if (cmbVal1 != nullptr) {
             cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
             cmbVal1->setMode(SKGCalculatorEdit::EXPRESSION);
             cmbVal1->setMinimumSize(QSize(100, 0));
@@ -157,7 +157,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             m_kValue1 = cmbVal1;
         }
         auto cmbVal2 = new SKGCalculatorEdit(this);
-        if (cmbVal2) {
+        if (cmbVal2 != nullptr) {
             cmbVal2->setObjectName(QStringLiteral("cmbVal2"));
             cmbVal2->setMode(SKGCalculatorEdit::EXPRESSION);
             cmbVal2->setMinimumSize(QSize(100, 0));
@@ -168,7 +168,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     } else  if (attType == SKGServices::DATE) {
         if (iModeUpdate) {
             auto cmbVal1 = new SKGComboBox(this);
-            if (cmbVal1) {
+            if (cmbVal1 != nullptr) {
                 cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
                 cmbVal1->setMinimumSize(QSize(100, 0));
                 cmbVal1->setEditable(true);
@@ -184,7 +184,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             }
 
             auto cmbVal2 = new SKGComboBox(this);
-            if (cmbVal2) {
+            if (cmbVal2 != nullptr) {
                 cmbVal2->setObjectName(QStringLiteral("cmbVal2"));
                 cmbVal2->setMinimumSize(QSize(100, 0));
                 cmbVal2->setEditable(false);
@@ -200,7 +200,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             }
         } else {
             auto cmbVal1 = new SKGDateEdit(this);
-            if (cmbVal1) {
+            if (cmbVal1 != nullptr) {
                 cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
                 cmbVal1->setMinimumSize(QSize(100, 0));
 
@@ -209,7 +209,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
             }
 
             auto cmbVal2 = new SKGDateEdit(this);
-            if (cmbVal2) {
+            if (cmbVal2 != nullptr) {
                 cmbVal2->setObjectName(QStringLiteral("cmbVal2"));
                 cmbVal2->setMinimumSize(QSize(100, 0));
 
@@ -219,7 +219,7 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
         }
     } else  if (attType == SKGServices::BOOL || attType == SKGServices::TRISTATE) {
         auto cmbVal1 = new QCheckBox(this);
-        if (cmbVal1) {
+        if (cmbVal1 != nullptr) {
             cmbVal1->setObjectName(QStringLiteral("cmbVal1"));
             cmbVal1->setMinimumSize(QSize(100, 0));
             cmbVal1->setTristate(attType == SKGServices::TRISTATE);
@@ -233,16 +233,16 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
     m_kOperator->clear();
     m_kOperator->addItem(QLatin1String(""), "");
 
-    if (m_kValue1) {
+    if (m_kValue1 != nullptr) {
         m_kValue1->installEventFilter(this);
     }
-    if (m_kValue2) {
+    if (m_kValue2 != nullptr) {
         m_kValue2->installEventFilter(this);
     }
-    if (m_kOperator) {
+    if (m_kOperator != nullptr) {
         m_kOperator->installEventFilter(this);
     }
-    if (m_kAttributes) {
+    if (m_kAttributes != nullptr) {
         m_kAttributes->installEventFilter(this);
     }
 
@@ -252,12 +252,12 @@ SKGPredicatCreator::SKGPredicatCreator(QWidget* iParent, SKGDocument* document,
         nb = 1;    // TODO(Stephane MANKOWSKI): unblock t_REALCATEGORY
     }
     for (int i = 0; i < nb; ++i) {
-        QString op = listOps.at(i);
+        const QString& op = listOps.at(i);
         QString nlsOp = SKGRuleObject::getDisplayForOperator(op,
                         i18nc("Default value", "..."),
                         i18nc("Default value", "..."),
                         i18nc("Noun, an item's attribute", "attribute"));
-        if (m_kOperator) {
+        if (m_kOperator != nullptr) {
             m_kOperator->addItem(nlsOp, op);
         }
     }
@@ -277,16 +277,16 @@ SKGPredicatCreator::~SKGPredicatCreator()
 bool SKGPredicatCreator::eventFilter(QObject* iObject, QEvent* iEvent)
 {
     Q_UNUSED(iObject);
-    if (iEvent && (iEvent->type() == QEvent::FocusIn || iEvent->type() == QEvent::FocusOut)) {
+    if ((iEvent != nullptr) && (iEvent->type() == QEvent::FocusIn || iEvent->type() == QEvent::FocusOut)) {
         QObject* appliFocus = QApplication::focusWidget();
 
-        while (appliFocus) {
+        while (appliFocus != nullptr) {
             if (appliFocus == this) {
                 break;
             }
             appliFocus = appliFocus->parent();
         }
-        if (!appliFocus) {
+        if (appliFocus == nullptr) {
             Q_EMIT editingFinished();
         }
     }
@@ -296,18 +296,18 @@ bool SKGPredicatCreator::eventFilter(QObject* iObject, QEvent* iEvent)
 void SKGPredicatCreator::onOperatorChanged()
 {
     QString req;
-    if (m_kOperator) {
+    if (m_kOperator != nullptr) {
         req = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
 
         m_kOperator->setToolTip(SKGRuleObject::getToolTipForOperator(req));
     }
-    if (m_kValue1) {
+    if (m_kValue1 != nullptr) {
         m_kValue1->setVisible(req.contains(QStringLiteral("#V1S#")) || req.contains(QStringLiteral("#V1#")));
     }
-    if (m_kValue2) {
+    if (m_kValue2 != nullptr) {
         m_kValue2->setVisible(req.contains(QStringLiteral("#V2S#")) || req.contains(QStringLiteral("#V2#")) || req.contains(QStringLiteral("#DF#")));
     }
-    if (m_kAttributes) {
+    if (m_kAttributes != nullptr) {
         m_kAttributes->setVisible(req.contains(QStringLiteral("#ATT2#")));
     }
 }
@@ -332,7 +332,7 @@ QString SKGPredicatCreator::getTextFromXml(const QString& iXML)
 QString SKGPredicatCreator::xmlDescription()
 {
     QString output;
-    if (m_kOperator) {
+    if (m_kOperator != nullptr) {
         QString op = m_kOperator->itemData(m_kOperator->currentIndex()).toString();
         if (!op.isEmpty()) {
             QDomDocument doc(QStringLiteral("SKGML"));
@@ -341,45 +341,45 @@ QString SKGPredicatCreator::xmlDescription()
 
             // Condition
             root.setAttribute(QStringLiteral("operator"), op);
-            if (m_kValue1 && m_kValue1->isVisible()) {
-                SKGDateEdit* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
-                if (cmbVal1) {
+            if ((m_kValue1 != nullptr) && m_kValue1->isVisible()) {
+                auto* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
+                if (cmbVal1 != nullptr) {
                     root.setAttribute(QStringLiteral("value"), SKGServices::dateToSqlString(QDateTime(cmbVal1->date())));
                 } else {
-                    SKGCalculatorEdit* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
-                    if (cmbVal12) {
+                    auto* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
+                    if (cmbVal12 != nullptr) {
                         root.setAttribute(QStringLiteral("value"), cmbVal12->text());
                     } else {
-                        QCheckBox* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
-                        if (cmbVal13) {
+                        auto* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
+                        if (cmbVal13 != nullptr) {
                             root.setAttribute(QStringLiteral("value"), cmbVal13->checkState() == Qt::Checked ? QStringLiteral("Y") : cmbVal13->checkState() == Qt::Unchecked ? QStringLiteral("N") : QStringLiteral("P"));
                         } else {
-                            SKGComboBox* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
-                            if (cmbVal14) {
+                            auto* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
+                            if (cmbVal14 != nullptr) {
                                 root.setAttribute(QStringLiteral("value"), cmbVal14->text());
                             }
                         }
                     }
                 }
             }
-            if (m_kValue2 && m_kValue2->isVisible()) {
-                SKGDateEdit* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
-                if (cmbVal2) {
+            if ((m_kValue2 != nullptr) && m_kValue2->isVisible()) {
+                auto* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
+                if (cmbVal2 != nullptr) {
                     root.setAttribute(QStringLiteral("value2"), SKGServices::dateToSqlString(QDateTime(cmbVal2->date())));
                 } else {
-                    SKGCalculatorEdit* cmbVal21 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
-                    if (cmbVal21) {
+                    auto* cmbVal21 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
+                    if (cmbVal21 != nullptr) {
                         root.setAttribute(QStringLiteral("value2"), cmbVal21->text());
                     } else {
-                        SKGComboBox* cmbVal22 = qobject_cast<SKGComboBox*> (m_kValue2);
-                        if (cmbVal22) {
+                        auto* cmbVal22 = qobject_cast<SKGComboBox*> (m_kValue2);
+                        if (cmbVal22 != nullptr) {
                             root.setAttribute(QStringLiteral("value2"), cmbVal22->text());
                         }
                     }
                 }
             }
 
-            if (m_kAttributes && m_kAttributes->isVisible()) {
+            if ((m_kAttributes != nullptr) && m_kAttributes->isVisible()) {
                 root.setAttribute(QStringLiteral("att2"), m_kAttributes->itemData(m_kAttributes->currentIndex()).toString());
                 root.setAttribute(QStringLiteral("att2s"), m_kAttributes->text());
             }
@@ -397,44 +397,44 @@ void SKGPredicatCreator::setXmlDescription(const QString& iXML)
     QDomElement root = doc.documentElement();
 
     // Condition
-    if (m_kOperator) {
+    if (m_kOperator != nullptr) {
         m_kOperator->setCurrentIndex(m_kOperator->findData(root.attribute(QStringLiteral("operator"))));
-        SKGDateEdit* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
-        if (cmbVal1) {
+        auto* cmbVal1 = qobject_cast<SKGDateEdit*> (m_kValue1);
+        if (cmbVal1 != nullptr) {
             cmbVal1->setDate(SKGServices::stringToTime(root.attribute(QStringLiteral("value"))).date());
         } else {
-            SKGCalculatorEdit* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
-            if (cmbVal12) {
+            auto* cmbVal12 = qobject_cast<SKGCalculatorEdit*> (m_kValue1);
+            if (cmbVal12 != nullptr) {
                 cmbVal12->setText(root.attribute(QStringLiteral("value")));
             } else {
-                QCheckBox* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
-                if (cmbVal13) {
+                auto* cmbVal13 = qobject_cast<QCheckBox*> (m_kValue1);
+                if (cmbVal13 != nullptr) {
                     cmbVal13->setCheckState(root.attribute(QStringLiteral("value")) == QStringLiteral("Y") ? Qt::Checked : root.attribute(QStringLiteral("value")) == QStringLiteral("P") ? Qt::PartiallyChecked : Qt::Unchecked);
                 } else {
-                    SKGComboBox* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
-                    if (cmbVal14) {
+                    auto* cmbVal14 = qobject_cast<SKGComboBox*> (m_kValue1);
+                    if (cmbVal14 != nullptr) {
                         cmbVal14->setText(root.attribute(QStringLiteral("value")));
                     }
                 }
             }
         }
 
-        SKGDateEdit* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
-        if (cmbVal2) {
+        auto* cmbVal2 = qobject_cast<SKGDateEdit*> (m_kValue2);
+        if (cmbVal2 != nullptr) {
             cmbVal2->setDate(SKGServices::stringToTime(root.attribute(QStringLiteral("value2"))).date());
         } else {
-            SKGCalculatorEdit* cmbVal22 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
-            if (cmbVal22) {
+            auto* cmbVal22 = qobject_cast<SKGCalculatorEdit*> (m_kValue2);
+            if (cmbVal22 != nullptr) {
                 cmbVal22->setText(root.attribute(QStringLiteral("value2")));
             } else {
-                SKGComboBox* cmbVal23 = qobject_cast<SKGComboBox*> (m_kValue2);
-                if (cmbVal23) {
+                auto* cmbVal23 = qobject_cast<SKGComboBox*> (m_kValue2);
+                if (cmbVal23 != nullptr) {
                     cmbVal23->setText(root.attribute(QStringLiteral("value2")));
                 }
             }
         }
 
-        if (m_kAttributes) {
+        if (m_kAttributes != nullptr) {
             m_kAttributes->setCurrentIndex(m_kAttributes->findData(root.attribute(QStringLiteral("att2"))));
         }
     }
