@@ -50,11 +50,11 @@ public:
      * @param iParent the parent
      * @param document the document
      * @param attribute name of the attribute
-     * @param iSQL to enable sql mode
+     * @param iModeUpdate to enable mode update
      * @param iListAtt list of attribute
      */
     explicit SKGPredicatCreator(QWidget* iParent, SKGDocument* document, const QString& attribute = QString(),
-                                bool iSQL = false, const QStringList& iListAtt = QStringList());
+                                bool iModeUpdate = false, const QStringList& iListAtt = QStringList());
 
     /**
      * Default Destructor
