@@ -25,11 +25,11 @@
 #include <qheaderview.h>
 #include <qmenu.h>
 
-#include "skgquerydelegate.h"
-#include "skgservices.h"
 #include "skgdocument.h"
 #include "skgpredicatcreator.h"
+#include "skgquerydelegate.h"
 #include "skgruleobject.h"
+#include "skgservices.h"
 
 #define ADDOPERATOR(title, op) \
     { \
@@ -138,7 +138,7 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
 //     ui.kLabel->setPixmap ( SKGServices::fromTheme( updateMode ? "view-refresh" :"edit-find" ).pixmap ( 22, 22 ), KTitleWidget::ImageLeft );
 
     // Build list of attributes
-    if (m_document) {
+    if (m_document != nullptr) {
         auto delegate = new SKGQueryDelegate(ui.kList, m_document, m_updateMode, iListAttribute);
         connect(delegate, &SKGQueryDelegate::commitData, this, &SKGQueryCreator::onCloseEditor, Qt::QueuedConnection);
 
@@ -159,7 +159,7 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
 
         // Adding properties
         for (int i = 0; i < nb; ++i) {
-            QString att = iListAttribute.at(i);
+            const QString& att = iListAttribute.at(i);
             if (att.startsWith(QLatin1String("p_"))) {
                 SKGServices::SKGAttributeInfo info;
                 info.name = att;
@@ -194,7 +194,7 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
             ui.kListAtt->addItem(listItem);
             listItem->setData(Qt::UserRole, listAtts.at(i).name);
 
-            if (helpMenu) {
+            if (helpMenu != nullptr) {
                 QAction* act = helpMenu->addAction(listAtts.at(i).icon, listAtts.at(i).display);
                 act->setData(listAtts.at(i).display);
                 connect(act, &QAction::triggered, this, &SKGQueryCreator::onAddText);
@@ -202,7 +202,7 @@ void SKGQueryCreator::setParameters(SKGDocument* iDocument, const QString& iTabl
         }
         ui.kListAtt->sortItems();
         ui.kListAtt->setModelColumn(nbCol);
-        if (helpMenu) {
+        if (helpMenu != nullptr) {
             helpMenu->addSeparator();
             {
                 QAction* act = helpMenu->addAction(i18nc("Operator contains", "Contains"));
@@ -232,11 +232,11 @@ int SKGQueryCreator::getIndexQueryColumn(const QString& iAttribute, int row)
     int nbCol = ui.kList->columnCount();
     for (int i = 0; i < nbCol && output == -1; ++i) {
         QTableWidgetItem* it_h = ui.kList->horizontalHeaderItem(i);
-        if (it_h && iAttribute == it_h->data(Qt::UserRole).toString()) {
+        if ((it_h != nullptr) && iAttribute == it_h->data(Qt::UserRole).toString()) {
             if (row >= 0) {
                 // Check if the cell is empty
                 QTableWidgetItem* it = ui.kList->item(row, i);
-                if (it) {
+                if (it != nullptr) {
                     if (it->text().isEmpty()) {
                         output = i;
                     }
@@ -252,7 +252,7 @@ int SKGQueryCreator::getIndexQueryColumn(const QString& iAttribute, int row)
         int nb = ui.kListAtt->count();
         for (int i = 0; i < nb; ++i) {
             QListWidgetItem* it = ui.kListAtt->item(i);
-            if (it && iAttribute == it->data(Qt::UserRole).toString()) {
+            if ((it != nullptr) && iAttribute == it->data(Qt::UserRole).toString()) {
                 addColumnFromAttribut(it);
                 output = nbCol;
                 break;
@@ -309,7 +309,7 @@ void SKGQueryCreator::setXMLCondition(const QString& iXML)
                             root2.setAttribute(QStringLiteral("att2"), element.attribute(QStringLiteral("att2")));
                             root2.setAttribute(QStringLiteral("att2s"), element.attribute(QStringLiteral("att2s")));
                             QTableWidgetItem* it = ui.kList->item(row, idx);
-                            if (it) {
+                            if (it != nullptr) {
                                 QString xml = doc2.toString();
 
                                 it->setText(SKGPredicatCreator::getTextFromXml(xml));
@@ -337,7 +337,7 @@ QString SKGQueryCreator::getXMLCondition()
     if (advancedSearchMode()) {
         // Mode advanced
         QHeaderView* hHeader = ui.kList->horizontalHeader();
-        if (hHeader) {
+        if (hHeader != nullptr) {
             QDomDocument doc(QStringLiteral("SKGML"));
             QDomElement element = doc.createElement(QStringLiteral("element"));
             doc.appendChild(element);
@@ -357,7 +357,7 @@ QString SKGQueryCreator::getXMLCondition()
                 for (int i = 0; i < nbCol; ++i) {
                     int iRealPos = hHeader->logicalIndex(i);
                     QTableWidgetItem* it = ui.kList->item(j, iRealPos);
-                    if (it) {
+                    if (it != nullptr) {
                         QString co = it->data(Qt::UserRole).toString();
                         if (!co.isEmpty()) {
                             QDomElement elementElement = doc.createElement(QStringLiteral("element"));
@@ -422,7 +422,7 @@ void SKGQueryCreator::onCloseEditor()
         lineEmpty = true;
         for (int i = 0; lineEmpty && i < nbCol; ++i) {
             QTableWidgetItem* it = ui.kList->item(j, i);
-            if (it && !it->text().isEmpty()) {
+            if ((it != nullptr) && !it->text().isEmpty()) {
                 lineEmpty = false;
             }
         }
@@ -437,8 +437,8 @@ void SKGQueryCreator::onCloseEditor()
 
 void SKGQueryCreator::onAddText()
 {
-    QAction* act = qobject_cast< QAction* >(sender());
-    if (act) {
+    auto* act = qobject_cast< QAction* >(sender());
+    if (act != nullptr) {
         ui.kFilterEdit->insert(act->data().toString());
     }
 }
@@ -452,17 +452,17 @@ void SKGQueryCreator::onAddColumn()
     }
 }
 
-void SKGQueryCreator::addColumnFromAttribut(const QListWidgetItem* listItem)
+void SKGQueryCreator::addColumnFromAttribut(const QListWidgetItem* iListItem)
 {
-    if (listItem) {
+    if (iListItem != nullptr) {
         bool previous = ui.kList->blockSignals(true);
 
         int nb = ui.kList->columnCount();
         ui.kList->setColumnCount(nb + 1);
 
         // Create header
-        auto item = new QTableWidgetItem(listItem->icon(), listItem->text());
-        item->setData(Qt::UserRole, listItem->data(Qt::UserRole));
+        auto item = new QTableWidgetItem(iListItem->icon(), iListItem->text());
+        item->setData(Qt::UserRole, iListItem->data(Qt::UserRole));
         ui.kList->setHorizontalHeaderItem(nb, item);
 
         // Create items
