@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgnamedobject.h"
 #include "skgbankmodeler_export.h"
+#include "skgnamedobject.h"
 class SKGBankObject;
 class SKGOperationObject;
 class SKGUnitObject;
@@ -43,15 +43,15 @@ public:
         SKGObjectBase object;   /**< The object (an operation, an interest or nothing for initial balance) */
         QDate date;             /**< The date */
         QDate valueDate;        /**< The valueDate */
-        int base;               /**< Base */
-        double amount;          /**< Amount */
-        double coef;            /**< Coef */
-        double rate;            /**< Rate */
-        double annualInterest;  /**< Annual Interest */
-        double accruedInterest; /**< Accrued Interest */
+        int base{};               /**< Base */
+        double amount{};          /**< Amount */
+        double coef{};            /**< Coef */
+        double rate{};            /**< Rate */
+        double annualInterest{};  /**< Annual Interest */
+        double accruedInterest{}; /**< Accrued Interest */
     };
 
-    typedef QVector<SKGAccountObject::SKGInterestItem> SKGInterestItemList;
+    using SKGInterestItemList = QVector<SKGAccountObject::SKGInterestItem>;
 
     /**
      * This enumerate defines type of account
@@ -105,7 +105,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGAccountObject& operator= (const SKGObjectBase& iObject) override;
+    SKGAccountObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
@@ -262,7 +262,7 @@ public:
      * @return amount of the account
      */
     // cppcheck-suppress passedByValue
-    virtual double getAmount(const QDate iDate, bool iOnlyCurrencies = false) const;
+    virtual double getAmount(QDate iDate, bool iOnlyCurrencies = false) const;
 
     /**
      * Set the type of this account
@@ -375,7 +375,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    virtual SKGError setReconciliationDate(const QDate iDate);
+    virtual SKGError setReconciliationDate(QDate iDate);
 
     /**
      * Get reconciliation date of this account
@@ -429,7 +429,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    virtual SKGError getInterest(const QDate iDate, SKGInterestObject& oInterest) const;
+    virtual SKGError getInterest(QDate iDate, SKGInterestObject& oInterest) const;
 
     /**
      * Get and compute interest items
@@ -476,7 +476,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    virtual SKGError transferDeferredOperations(const SKGAccountObject& iTargetAccount, const QDate iDate = QDate::currentDate());
+    virtual SKGError transferDeferredOperations(const SKGAccountObject& iTargetAccount, QDate iDate = QDate::currentDate());
 
     /**
      * Get all list of operations that can be checked to reconcile with target balance
