@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgnamedobject.h"
 #include "skgbankmodeler_export.h"
+#include "skgnamedobject.h"
 
 class SKGAccountObject;
 /**
@@ -68,7 +68,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGBankObject& operator= (const SKGObjectBase& iObject) override;
+    SKGBankObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
