@@ -22,10 +22,10 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgobjectbase.h"
-#include "skgerror.h"
-#include "skgcategoryobject.h"
 #include "skgbankmodeler_export.h"
+#include "skgcategoryobject.h"
+#include "skgerror.h"
+#include "skgobjectbase.h"
 
 class SKGDocumentBank;
 
@@ -75,7 +75,7 @@ public:
     /**
      * Destructor
      */
-    ~SKGBudgetRuleObject();
+    ~SKGBudgetRuleObject() override;
 
     /**
      * Copy constructor
@@ -93,7 +93,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGBudgetRuleObject& operator= (const SKGObjectBase& iObject) override;
+    SKGBudgetRuleObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Enable / disable condition on year of the budget
@@ -107,7 +107,7 @@ public:
      * To know if condition on year is enabled or disabled
      * @return condition
      */
-    int isYearConditionEnabled() const;
+    bool isYearConditionEnabled() const;
 
     /**
      * Set year of the condition of the rule
@@ -135,7 +135,7 @@ public:
      * To know if condition on month is enabled or disabled
      * @return condition
      */
-    int isMonthConditionEnabled() const;
+    bool isMonthConditionEnabled() const;
 
     /**
      * Set month of the condition of the rule
@@ -163,7 +163,7 @@ public:
      * To know if condition on category is enabled or disabled
      * @return condition
      */
-    int isCategoryConditionEnabled() const;
+    bool isCategoryConditionEnabled() const;
 
     /**
      * Set the category of the condition of the rule
@@ -235,7 +235,7 @@ public:
      * To know if transfer change the category
      * @return transfer change the category
      */
-    int isCategoryChangeEnabled() const;
+    bool isCategoryChangeEnabled() const;
 
     /**
      * Set the transfer to apply
