@@ -23,8 +23,8 @@
 
 #include <klocalizedstring.h>
 
-#include "skgsuboperationobject.h"
 #include "skgdocumentbank.h"
+#include "skgsuboperationobject.h"
 #include "skgtraces.h"
 
 SKGCategoryObject::SKGCategoryObject() : SKGCategoryObject(nullptr)
@@ -48,7 +48,7 @@ SKGCategoryObject::SKGCategoryObject(const SKGObjectBase& iObject)
     }
 }
 
-const SKGCategoryObject& SKGCategoryObject::operator= (const SKGObjectBase& iObject)
+SKGCategoryObject& SKGCategoryObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -103,7 +103,7 @@ SKGError SKGCategoryObject::createPathCategory(SKGDocumentBank* iDocument,
     // Check if category is already existing
     if (iFullPath.isEmpty()) {
         oCategory = SKGCategoryObject(nullptr, 0);
-    } else if (iDocument) {
+    } else if (iDocument != nullptr) {
         if (!iRenameIfAlreadyExist) {
             iDocument->getObject(QStringLiteral("v_category"), "t_fullname='" % SKGServices::stringToSqlString(iFullPath) % '\'', oCategory);
         } else {
@@ -173,7 +173,7 @@ SKGError SKGCategoryObject::addCategory(SKGCategoryObject& oCategory)
     if (getID() == 0) {
         err = SKGError(ERR_FAIL,  i18nc("Error message", "%1 failed because linked object is not yet saved in the database.", QStringLiteral("SKGCategoryObject::addCategory")));
     } else {
-        oCategory = SKGCategoryObject(static_cast<SKGDocumentBank*>(getDocument()));
+        oCategory = SKGCategoryObject(qobject_cast<SKGDocumentBank*>(getDocument()));
         err = oCategory.setAttribute(QStringLiteral("rd_category_id"), SKGServices::intToString(getID()));
     }
     return err;
@@ -268,7 +268,7 @@ SKGError SKGCategoryObject::bookmark(bool iBookmark)
 
 bool SKGCategoryObject::isBookmarked() const
 {
-    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y") ? true : false);
+    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
 }
 
 SKGError SKGCategoryObject::setClosed(bool iClosed)
@@ -278,7 +278,7 @@ SKGError SKGCategoryObject::setClosed(bool iClosed)
 
 bool SKGCategoryObject::isClosed() const
 {
-    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y") ? true : false);
+    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y"));
 }
 
 SKGError SKGCategoryObject::merge(const SKGCategoryObject& iCategory)
