@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgnamedobject.h"
 #include "skgbankmodeler_export.h"
+#include "skgnamedobject.h"
 class SKGDocumentBank;
 /**
  * This class manages category object
@@ -60,12 +60,12 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGCategoryObject& operator= (const SKGObjectBase& iObject) override;
+    SKGCategoryObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
      */
-    ~SKGCategoryObject();
+    ~SKGCategoryObject() override;
 
     /**
      * Create a category branch if needed and return the leaf of the branch
@@ -106,6 +106,21 @@ public:
      */
     bool isBookmarked() const;
 
+    /**
+     * To set the closed attribute of a payee
+     * @param iClosed the closed attribute: true or false
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual SKGError setClosed(bool iClosed);
+
+    /**
+     * To know if the payee has been closed or not
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    virtual bool isClosed() const;
+
     /**
      * Get the full name of this category.
      * The full name is the unique name of the category.
