@@ -187,10 +187,11 @@ public:
     /**
      * Anonymize the document.
      * This function must not be launched into a transaction
+     * @param iKey the key for anonymisation. If "" then the anonymisation is not reversible, else the anonymisation can be undone with the same key.
      * @return an object managing the error.
      *   @see SKGError
      */
-    SKGError anonymize();
+    SKGError anonymize(const QString& iKey);
 
     /**
      * Find and group operations
