@@ -29,8 +29,7 @@ SKGInterestObject::SKGInterestObject(SKGDocument* iDocument, int iID): SKGObject
 {}
 
 SKGInterestObject::SKGInterestObject(const SKGInterestObject& iObject)
-    : SKGObjectBase(iObject)
-{}
+    = default;
 
 SKGInterestObject::SKGInterestObject(const SKGObjectBase& iObject)
 {
@@ -41,15 +40,14 @@ SKGInterestObject::SKGInterestObject(const SKGObjectBase& iObject)
     }
 }
 
-const SKGInterestObject& SKGInterestObject::operator= (const SKGObjectBase& iObject)
+SKGInterestObject& SKGInterestObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
 }
 
 SKGInterestObject::~SKGInterestObject()
-{
-}
+    = default;
 
 SKGError SKGInterestObject::setRate(double iValue)
 {
@@ -61,7 +59,7 @@ double SKGInterestObject::getRate() const
     return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_rate")));
 }
 
-SKGError SKGInterestObject::setDate(const QDate iDate)
+SKGError SKGInterestObject::setDate(QDate iDate)
 {
     return setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(QDateTime(iDate)));
 }
