@@ -23,14 +23,14 @@
 
 #include <klocalizedstring.h>
 
-#include "skgrecurrentoperationobject.h"
-#include "skgsuboperationobject.h"
 #include "skgaccountobject.h"
-#include "skgunitobject.h"
-#include "skgpayeeobject.h"
-#include "skgservices.h"
 #include "skgdocument.h"
+#include "skgpayeeobject.h"
+#include "skgrecurrentoperationobject.h"
+#include "skgservices.h"
+#include "skgsuboperationobject.h"
 #include "skgtraces.h"
+#include "skgunitobject.h"
 
 SKGOperationObject::SKGOperationObject() : SKGOperationObject(nullptr)
 {}
@@ -53,13 +53,13 @@ SKGOperationObject::SKGOperationObject(const SKGObjectBase& iObject)
     }
 }
 
-const SKGOperationObject& SKGOperationObject::operator= (const SKGObjectBase& iObject)
+SKGOperationObject& SKGOperationObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
 }
 
-SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, const QDate iDate, bool iTemplateMode) const
+SKGError SKGOperationObject::duplicate(SKGOperationObject& oOperation, QDate iDate, bool iTemplateMode) const
 {
     SKGError err;
     SKGTRACEINFUNCRC(20, err);
@@ -211,7 +211,8 @@ SKGOperationObject::OperationStatus SKGOperationObject::getStatus() const
     QString t_status = getAttribute(QStringLiteral("t_status"));
     if (t_status == QStringLiteral("Y")) {
         return SKGOperationObject::CHECKED;
-    } else if (t_status == QStringLiteral("P")) {
+    }
+    if (t_status == QStringLiteral("P")) {
         return SKGOperationObject::POINTED;
     }
     return SKGOperationObject::NONE;
@@ -222,7 +223,7 @@ SKGError SKGOperationObject::setStatus(SKGOperationObject::OperationStatus iStat
     return setAttribute(QStringLiteral("t_status"), (iStatus == SKGOperationObject::CHECKED ? QStringLiteral("Y") : (iStatus == SKGOperationObject::POINTED ? QStringLiteral("P") : QStringLiteral("N"))));
 }
 
-SKGError SKGOperationObject::setDate(const QDate iDate, bool iRefreshSubOperations)
+SKGError SKGOperationObject::setDate(QDate iDate, bool iRefreshSubOperations)
 {
     SKGError err;
     // Compute delta of the change of date
@@ -355,7 +356,7 @@ SKGError SKGOperationObject::bookmark(bool iBookmark)
 
 bool SKGOperationObject::isBookmarked() const
 {
-    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y") ? true : false);
+    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
 }
 
 SKGError SKGOperationObject::setImported(bool iImported)
@@ -365,7 +366,7 @@ SKGError SKGOperationObject::setImported(bool iImported)
 
 bool SKGOperationObject::isImported() const
 {
-    return (getAttribute(QStringLiteral("t_imported")) != QStringLiteral("N") ? true : false);
+    return (getAttribute(QStringLiteral("t_imported")) != QStringLiteral("N"));
 }
 
 SKGError SKGOperationObject::setImportID(const QString& iImportID)
@@ -389,7 +390,7 @@ SKGError SKGOperationObject::setTemplate(bool iTemplate)
 
 bool SKGOperationObject::isTemplate() const
 {
-    return (getAttribute(QStringLiteral("t_template")) != QStringLiteral("N") ? true : false);
+    return (getAttribute(QStringLiteral("t_template")) != QStringLiteral("N"));
 }
 
 int SKGOperationObject::getNbSubOperations() const
@@ -441,7 +442,7 @@ double SKGOperationObject::getBalance() const
     return output;
 }
 
-double SKGOperationObject::getAmount(const QDate iDate) const
+double SKGOperationObject::getAmount(QDate iDate) const
 {
     // Get quantity
     double quantity = SKGServices::stringToDouble(getAttribute(QStringLiteral("f_QUANTITY")));
