@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgobjectbase.h"
 #include "skgbankmodeler_export.h"
+#include "skgobjectbase.h"
 class SKGAccountObject;
 class SKGUnitObject;
 class SKGSubOperationObject;
@@ -91,7 +91,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGOperationObject& operator= (const SKGObjectBase& iObject) override;
+    SKGOperationObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
@@ -107,7 +107,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError duplicate(SKGOperationObject& oOperation, const QDate iDate = QDate::currentDate(), bool iTemplateMode = false) const;
+    SKGError duplicate(SKGOperationObject& oOperation, QDate iDate = QDate::currentDate(), bool iTemplateMode = false) const;
 
     /**
      * Get the parent account
@@ -132,13 +132,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    SKGError setNumber(qlonglong iNumber);
+    SKGError setNumber(const QString& iNumber);
 
     /**
      * Get the number of this operation
      * @return the number
      */
-    qlonglong getNumber() const;
+    QString getNumber() const;
 
     /**
      * Set the mode of operation
@@ -206,7 +206,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError setDate(const QDate iDate, bool iRefreshSubOperations = true);
+    SKGError setDate(QDate iDate, bool iRefreshSubOperations = true);
 
     /**
      * Get date of this operation
@@ -366,7 +366,7 @@ public:
      * @return amount of the operation
      */
     // cppcheck-suppress passedByValue
-    double getAmount(const QDate iDate) const;
+    double getAmount(QDate iDate) const;
 
     /**
      * Create a recurrent operation based on this one
