@@ -23,9 +23,10 @@
 
 #include <klocalizedstring.h>
 
+#include "skgcategoryobject.h"
 #include "skgdocumentbank.h"
-#include "skgtraces.h"
 #include "skgoperationobject.h"
+#include "skgtraces.h"
 
 SKGPayeeObject::SKGPayeeObject(): SKGPayeeObject(nullptr)
 {}
@@ -34,10 +35,9 @@ SKGPayeeObject::SKGPayeeObject(SKGDocument* iDocument, int iID): SKGNamedObject(
 {}
 
 SKGPayeeObject::~SKGPayeeObject()
-{}
+    = default;
 
-SKGPayeeObject::SKGPayeeObject(const SKGPayeeObject& iObject) : SKGNamedObject(iObject)
-{}
+SKGPayeeObject::SKGPayeeObject(const SKGPayeeObject& iObject) = default;
 
 SKGPayeeObject::SKGPayeeObject(const SKGObjectBase& iObject)
 
@@ -49,7 +49,7 @@ SKGPayeeObject::SKGPayeeObject(const SKGObjectBase& iObject)
     }
 }
 
-const SKGPayeeObject& SKGPayeeObject::operator= (const SKGObjectBase& iObject)
+SKGPayeeObject& SKGPayeeObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -66,7 +66,7 @@ SKGError SKGPayeeObject::createPayee(SKGDocumentBank* iDocument,
     // Check if refund is already existing
     if (iName.isEmpty()) {
         oPayee = SKGPayeeObject(nullptr, 0);
-    } else if (iDocument) {
+    } else if (iDocument != nullptr) {
         iDocument->getObject(QStringLiteral("v_payee"), "t_name='" % SKGServices::stringToSqlString(iName) % '\'', oPayee);
         if (oPayee.getID() == 0) {
             // No, we have to create it
@@ -101,6 +101,16 @@ QString SKGPayeeObject::getAddress() const
     return getAttribute(QStringLiteral("t_address"));
 }
 
+SKGError SKGPayeeObject::setClosed(bool iClosed)
+{
+    return setAttribute(QStringLiteral("t_close"), iClosed ? QStringLiteral("Y") : QStringLiteral("N"));
+}
+
+bool SKGPayeeObject::isClosed() const
+{
+    return (getAttribute(QStringLiteral("t_close")) == QStringLiteral("Y"));
+}
+
 SKGError SKGPayeeObject::bookmark(bool iBookmark)
 {
     return setAttribute(QStringLiteral("t_bookmarked"), iBookmark ? QStringLiteral("Y") : QStringLiteral("N"));
@@ -108,7 +118,18 @@ SKGError SKGPayeeObject::bookmark(bool iBookmark)
 
 bool SKGPayeeObject::isBookmarked() const
 {
-    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y") ? true : false);
+    return (getAttribute(QStringLiteral("t_bookmarked")) == QStringLiteral("Y"));
+}
+
+SKGError SKGPayeeObject::getCategory(SKGCategoryObject& oCategory) const
+{
+    SKGError err = getDocument()->getObject(QStringLiteral("v_category"), "id=" % getAttribute(QStringLiteral("r_category_id")), oCategory);
+    return err;
+}
+
+SKGError SKGPayeeObject::setCategory(const SKGCategoryObject& iCategory)
+{
+    return setAttribute(QStringLiteral("r_category_id"), SKGServices::intToString(iCategory.getID()));
 }
 
 SKGError SKGPayeeObject::merge(const SKGPayeeObject& iPayee)
