@@ -132,6 +132,9 @@ SKGError SKGRecurrentOperationObject::setTimeLimit(QDate iLastDate)
 {
     // Get parameters
     QDate firstDate = this->getDate();
+    if (iLastDate < firstDate) {
+        return setTimeLimit(0);
+    }
     SKGRecurrentOperationObject::PeriodUnit period = this->getPeriodUnit();
     int occu = qMax(this->getPeriodIncrement(), 1);
 
