@@ -475,20 +475,45 @@ QVariantList SKGReportBank::getScheduledOperations()
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10);
         SKGObjectBase::SKGListSKGObjectBase objs;
-        SKGError err = m_document->getObjects(QStringLiteral("v_recurrentoperation_display"), QStringLiteral("i_nb_times!=0 ORDER BY d_date LIMIT 5"), objs);
+        auto scheduled_operation_days_max = m_parameters.value(QStringLiteral("scheduled_operation_days_max"), QStringLiteral("30")).toString();
+        SKGError err = m_document->getObjects(QStringLiteral("v_recurrentoperation_display"),
+                                              QStringLiteral("i_nb_times!=0 AND d_date<=date('now','+") + scheduled_operation_days_max + " day') ORDER BY d_date", objs);
+        QDate d = QDate::currentDate().addDays(SKGServices::stringToInt(scheduled_operation_days_max));
+        QString dateFormatShort = QLocale::system().dateFormat(QLocale::ShortFormat);
         IFOK(err) {
             int nb = objs.count();
             if (nb != 0) {
                 table.reserve(nb);
                 for (int i = 0; i < nb; ++i) {
                     SKGRecurrentOperationObject obj(objs.at(i));
-                    bool bold = false;
-                    if (obj.isWarnEnabled() &&  QDate::currentDate() >= obj.getDate().addDays(-obj.getWarnDays())) {
-                        bold = true;
+                    bool first = true;
+                    auto obj_date = obj.getDate().toString(dateFormatShort);
+                    while (true) {
+                        if (obj.getDate() > d || (obj.hasTimeLimit() && obj.getTimeLimit() == 0)) {
+                            break;
+                        } else {
+                            bool bold = false;
+                            if (obj.isWarnEnabled() &&  QDate::currentDate() >= obj.getDate().addDays(-obj.getWarnDays())) {
+                                bold = true;
+                            }
+                            auto name = obj.getDisplayName();
+                            if (!first) {
+                                name = name.replace(obj_date, obj.getDate().toString(dateFormatShort));
+                            }
+                            table.push_back(QVariantList() << bold << name << (first ? obj.getUniqueID() : QString()) << obj.getDate());
+                            first = false;
+                            obj.setDate(obj.getNextDate());
+                            if (obj.hasTimeLimit()) {
+                                obj.setTimeLimit(obj.getTimeLimit() - 1);
+                            }
+                        }
                     }
-                    table.push_back(QVariantList() << bold << obj.getDisplayName());
                 }
             }
+            qSort(table.begin(), table.end(), [](const QVariant & v1, const QVariant & v2) {
+                return v1.toList().at(3).toDate() < v2.toList().at(3).toDate();
+            }
+                 );
             m_cache[cacheId] = table;
         }
     }
