@@ -22,10 +22,10 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgdocument.h"
-#include "skgobjectbase.h"
-#include "skgerror.h"
 #include "skgbankmodeler_export.h"
+#include "skgdocument.h"
+#include "skgerror.h"
+#include "skgobjectbase.h"
 
 /**
  * This class allows to define rules
@@ -39,13 +39,13 @@ public:
      */
     struct SKGAlarmInfo {
         /** To know if the alarm is raised */
-        bool Raised;
+        bool Raised{};
         /** The message to display */
         QString Message;
         /** The amount in absolute value */
-        double Amount;
+        double Amount{};
         /** The limit */
-        double Limit;
+        double Limit{};
     };
 
     /**
@@ -103,7 +103,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGRuleObject& operator= (const SKGObjectBase& iObject) override;
+    SKGRuleObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
