@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgnamedobject.h"
 #include "skgbankmodeler_export.h"
+#include "skgnamedobject.h"
 class SKGDocumentBank;
 
 /**
@@ -62,12 +62,12 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGTrackerObject& operator= (const SKGObjectBase& iObject) override;
+    SKGTrackerObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
      */
-    ~SKGTrackerObject();
+    ~SKGTrackerObject() override;
 
     /**
      * Create a tracker if needed and return it
