@@ -23,10 +23,10 @@
  */
 #include <qurl.h>
 
-#include "skgnamedobject.h"
-#include "skgerror.h"
-#include "skgservices.h"
 #include "skgbankmodeler_export.h"
+#include "skgerror.h"
+#include "skgnamedobject.h"
+#include "skgservices.h"
 
 class SKGUnitValueObject;
 class SKGDocumentBank;
@@ -109,7 +109,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGUnitObject& operator= (const SKGObjectBase& iObject) override;
+    SKGUnitObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Get unit information
@@ -159,7 +159,7 @@ public:
      * @return Value in target unit
      */
     // cppcheck-suppress passedByValue
-    static double convert(double iValue, const SKGUnitObject& iUnitFrom, const SKGUnitObject& iUnitTo, const QDate iDate = QDate::currentDate());
+    static double convert(double iValue, const SKGUnitObject& iUnitFrom, const SKGUnitObject& iUnitTo, QDate iDate = QDate::currentDate());
 
     /**
      * Set the symbol of this unit
@@ -277,7 +277,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError getUnitValue(const QDate iDate, SKGUnitValueObject& oUnitValue) const;
+    SKGError getUnitValue(QDate iDate, SKGUnitValueObject& oUnitValue) const;
 
     /**
      * Download values
@@ -347,7 +347,7 @@ public:
      * @return amount of the unit
      */
     // cppcheck-suppress passedByValue
-    double getAmount(const QDate iDate = QDate::currentDate()) const;
+    double getAmount(QDate iDate = QDate::currentDate()) const;
 
     /**
      * Get daily change in percentage at a date.
@@ -355,7 +355,7 @@ public:
      * @return daily change
      */
     // cppcheck-suppress passedByValue
-    double getDailyChange(const QDate iDate = QDate::currentDate()) const;
+    double getDailyChange(QDate iDate = QDate::currentDate()) const;
 
     /**
      * Set the unit
