@@ -23,8 +23,8 @@
 
 #include <klocalizedstring.h>
 
-#include "skgunitobject.h"
 #include "skgdocument.h"
+#include "skgunitobject.h"
 
 SKGUnitValueObject::SKGUnitValueObject() : SKGUnitValueObject(nullptr)
 {}
@@ -43,7 +43,7 @@ SKGUnitValueObject::SKGUnitValueObject(const SKGObjectBase& iObject)
     }
 }
 
-const SKGUnitValueObject& SKGUnitValueObject::operator= (const SKGObjectBase& iObject)
+SKGUnitValueObject& SKGUnitValueObject::operator= (const SKGObjectBase& iObject)
 {
     copyFrom(iObject);
     return *this;
@@ -65,7 +65,7 @@ double SKGUnitValueObject::getQuantity() const
     return SKGServices::stringToDouble(getAttribute(QStringLiteral("f_quantity")));
 }
 
-SKGError SKGUnitValueObject::setDate(const QDate iDate)
+SKGError SKGUnitValueObject::setDate(QDate iDate)
 {
     return setAttribute(QStringLiteral("d_date"), SKGServices::dateToSqlString(QDateTime(iDate)));
 }
@@ -91,7 +91,7 @@ QString SKGUnitValueObject::getWhereclauseId() const
 SKGError SKGUnitValueObject::getUnit(SKGUnitObject& oUnit) const
 {
     SKGError err;
-    if (getDocument()) {
+    if (getDocument() != nullptr) {
         err = getDocument()->getObject(QStringLiteral("v_unit"), "id=" % getAttribute(QStringLiteral("rd_unit_id")), oUnit);
     }
     return err;
