@@ -22,9 +22,9 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgobjectbase.h"
-#include "skgerror.h"
 #include "skgbankmodeler_export.h"
+#include "skgerror.h"
+#include "skgobjectbase.h"
 
 class SKGUnitObject;
 
@@ -64,7 +64,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGUnitValueObject& operator= (const SKGObjectBase& iObject) override;
+    SKGUnitValueObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
@@ -92,7 +92,7 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    SKGError setDate(const QDate iDate);
+    SKGError setDate(QDate iDate);
 
     /**
      * Get date of this value
