@@ -22,8 +22,8 @@
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
-#include "skgwidget.h"
 #include "skgbasegui_export.h"
+#include "skgwidget.h"
 
 class QAction;
 class QMenu;
@@ -105,7 +105,7 @@ public:
 
     /**
      * Set the zoom ratio
-     * @param iRation the zoom ratio (1 <= iRatio <=5)
+     * @param iRatio the zoom ratio (1 <= iRatio <=5)
      */
     virtual void setZoomRatio(double iRatio);
 
@@ -157,8 +157,8 @@ private Q_SLOTS:
 private:
     Q_DISABLE_COPY(SKGBoardWidget)
 
-    QLabel* m_Title;
-    QGridLayout* m_gridLayout;
+    QLabel* m_Title{};
+    QGridLayout* m_gridLayout{};
     QFrame* m_frame;
     QToolButton* m_toolButton;
     QMenu* m_menu;
