@@ -23,11 +23,11 @@
 
 #include <kcolorscheme.h>
 
-#include <qvalidator.h>
+#include <qcompleter.h>
 #include <qevent.h>
 #include <qscriptengine.h>
-#include <qcompleter.h>
 #include <qstringlistmodel.h>
+#include <qvalidator.h>
 
 #include "skgservices.h"
 #include "skgtraces.h"
@@ -51,9 +51,10 @@ double SKGCalculatorEdit::value()
 int SKGCalculatorEdit::sign() const
 {
     QString t = text();
-    if (t.isEmpty() == false && t[0] == '+') {
+    if (!t.isEmpty() && t[0] == '+') {
         return 1;
-    } else if (t.isEmpty() == false && t[0] == '-') {
+    }
+    if (!t.isEmpty() && t[0] == '-') {
         return -1;
     }
     return 0;
@@ -139,7 +140,7 @@ void SKGCalculatorEdit::addParameterValue(const QString& iParameter, double iVal
 
 void SKGCalculatorEdit::keyPressEvent(QKeyEvent* iEvent)
 {
-    if (iEvent) {
+    if (iEvent != nullptr) {
         int key = iEvent->key();
         if (mode() == CALCULATOR) {
             bool hasText = !text().isEmpty() && selectedText() != text();
