@@ -21,7 +21,7 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include <kdateedit.h>
+#include "kdateedit.h"
 
 #include "skgbasegui_export.h"
 /**
@@ -64,13 +64,13 @@ public:
      * Get the mode
      * @return the mode
      */
-    virtual Mode mode() const;
+    Mode mode() const;
 
     /**
      * Set the mode
      * @param iMode the mode
      */
-    virtual void setMode(Mode iMode);
+    void setMode(Mode iMode);
 
 Q_SIGNALS:
     /**
