@@ -21,10 +21,11 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include <qtimer.h>
 #include <qwidget.h>
 
-#include "ui_skgfilteredtableview.h"
 #include "skgbasegui_export.h"
+#include "ui_skgfilteredtableview.h"
 
 class SKGShow;
 class SKGObjectModelBase;
@@ -113,15 +114,16 @@ public Q_SLOTS:
 private Q_SLOTS:
     void pageChanged();
     void onFilterChanged();
-    void onTextFilterChanged(const QString& iFilter);
+    void onTextFilterChanged();
     void dataModified(const QString& iTableName, int iIdTransaction);
 
 private:
     Q_DISABLE_COPY(SKGFilteredTableView)
 
-    Ui::skgfilteredtableview_base ui;
+    Ui::skgfilteredtableview_base ui{};
     SKGObjectModelBase* m_objectModel;
     bool m_refreshNeeded;
+    QTimer m_timer;
 };
 
 #endif  // SKGFILTEREDTABLEVIEW_H
