@@ -100,7 +100,7 @@ public:
      * Reimplement this function in layout managers that support height for width
      * @return height
      */
-    int heightForWidth(int) const override;
+    int heightForWidth(int /*width*/ /*unused*/) const override;
 
     /**
      * Returns the number of items
@@ -142,7 +142,7 @@ public:
 
 
 private:
-    int doLayout(const QRect rect, bool testOnly) const;
+    int doLayout(QRect rect, bool testOnly) const;
     int smartSpacing(QStyle::PixelMetric pm) const;
 
     QList<QLayoutItem*> m_itemList;
