@@ -23,8 +23,8 @@
  */
 
 
-#include <qwidget.h>
 #include <qtimer.h>
+#include <qwidget.h>
 
 #include "skgbasegui_export.h"
 #include "ui_skggraphicsview.h"
@@ -65,94 +65,94 @@ public:
      * Set current scene
      * @param iScene The scene
      */
-    virtual void setScene(QGraphicsScene* iScene);
+    void setScene(QGraphicsScene* iScene);
 
     /**
      * Get the internal Graphic view
      * @return the internal Graphic view
      */
-    virtual QGraphicsView* graphicsView();
+    QGraphicsView* graphicsView();
 
     /**
      * Set the visibility of the ToolBar
      * @param iVisibility visibility
      */
-    virtual void setToolBarVisible(bool iVisibility);
+    void setToolBarVisible(bool iVisibility);
 
     /**
      * Get the visibility of the ToolBar
      * @return visibility
      */
-    virtual bool isToolBarVisible() const;
+    bool isToolBarVisible() const;
 
     /**
      * Add a widget in the toolbar
      * @param iWidget widget
      */
-    virtual void addToolbarWidget(QWidget* iWidget);
+    void addToolbarWidget(QWidget* iWidget);
 
     /**
      * Get the current state
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() const;
+    QString getState() const;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState);
+    void setState(const QString& iState);
 
     /**
      * Get a pointer on the contextual menu
      * @return contextual menu
      */
-    virtual QMenu* getContextualMenu() const;
+    QMenu* getContextualMenu() const;
 
 public Q_SLOTS:
     /**
      * Set the zoom
      */
-    virtual void onZoom();
+    void onZoom();
 
     /**
      * Print
      */
-    virtual void onPrint();
+    void onPrint();
 
     /**
      * Export to a file
      * @param iFileName the file name
      */
-    virtual void exportInFile(const QString& iFileName);
+    void exportInFile(const QString& iFileName);
 
     /**
      * Export
      */
-    virtual void onExport();
+    void onExport();
 
     /**
      * Copy
      */
-    virtual void onCopy();
+    void onCopy();
 
     /**
      * Swith tool bar visibility
      */
-    virtual void onSwitchToolBarVisibility();
+    void onSwitchToolBarVisibility();
 
     /**
      * Set antialiasing
      * @param iAntialiasing enabled or disabled
      */
-    virtual void setAntialiasing(bool iAntialiasing);
+    void setAntialiasing(bool iAntialiasing);
 
     /**
      * Reinitialize zoom
      */
-    virtual void initializeZoom();
+    void initializeZoom();
 
 Q_SIGNALS:
     /**
@@ -175,18 +175,18 @@ protected:
     bool eventFilter(QObject* iObject, QEvent* iEvent) override;
 
 private Q_SLOTS:
-    void showMenu(const QPoint iPos);
+    void showMenu(QPoint iPos);
 
 private:
     Q_DISABLE_COPY(SKGGraphicsView)
-    Ui::skggraphicview_base ui;
+    Ui::skggraphicview_base ui{};
 
     double m_oscale;
 
-    QMenu* m_mainMenu;
-    QAction* m_actZoomOriginal;
+    QMenu* m_mainMenu{};
+    QAction* m_actZoomOriginal{};
     QAction* m_actShowToolBar;
-    QAction* m_actAntialiasing;
+    QAction* m_actAntialiasing{};
     bool m_toolBarVisible;
     QTimer m_timer;
 };
