@@ -38,7 +38,7 @@
 #include "skgtraces.h"
 
 SKGHtmlBoardWidget::SKGHtmlBoardWidget(QWidget* iParent, SKGDocument* iDocument, const QString& iTitle, const QString& iTemplate, QStringList  iTablesRefreshing, SKGSimplePeriodEdit::Modes iOptions)
-    : SKGBoardWidget(iParent, iDocument, iTitle), m_Quick(nullptr), m_Text(nullptr), m_Report(iDocument->getReport()),  m_Template(iTemplate), m_TablesRefreshing(std::move(iTablesRefreshing)), m_refreshNeeded(false), m_period(nullptr)
+    : SKGBoardWidget(iParent, iDocument, iTitle), m_Quick(nullptr), m_Report(iDocument->getReport()),  m_Text(nullptr), m_Template(iTemplate), m_TablesRefreshing(std::move(iTablesRefreshing)), m_refreshNeeded(false), m_period(nullptr)
 {
     SKGTRACEINFUNC(10);
     // Create menu
