@@ -76,16 +76,16 @@ public:
 
 protected Q_SLOTS:
     void pageChanged();
-    void dataModified(const QString& iTableName = QString(), int iIdTransaction = 0);
+    virtual void dataModified(const QString& iTableName = QString(), int iIdTransaction = 0);
 
 protected:
     QQuickWidget* m_Quick;
+    SKGReport* m_Report;
 
 private:
     Q_DISABLE_COPY(SKGHtmlBoardWidget)
 
     QLabel* m_Text;
-    SKGReport* m_Report;
     QString m_Template;
     QStringList m_TablesRefreshing;
     bool m_refreshNeeded;
