@@ -21,34 +21,32 @@
  */
 #include "skgobjectmodelbase.h"
 
-#include <float.h>
-
-#include <klocalizedstring.h>
 #include <kcolorscheme.h>
 #include <kformat.h>
+#include <klocalizedstring.h>
 
-#include <qicon.h>
 #include <qapplication.h>
-#include <qmimedata.h>
-#include <qdir.h>
 #include <qcolor.h>
+#include <qdir.h>
+#include <qicon.h>
+#include <qmimedata.h>
 
-#include "skgtraces.h"
 #include "skgdocument.h"
-#include "skgnodeobject.h"
-#include "skgtransactionmng.h"
-#include <skgpropertyobject.h>
 #include "skgmainpanel.h"
+#include "skgnodeobject.h"
+#include "skgpropertyobject.h"
+#include "skgtraces.h"
+#include "skgtransactionmng.h"
 
 SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
                                        const QString& iTable,
-                                       const QString& iWhereClause,
+                                       QString  iWhereClause,
                                        QWidget* iParent,
-                                       const QString& iParentAttribute,
+                                       QString  iParentAttribute,
                                        bool iResetOnCreation)
     : QAbstractItemModel(iParent), m_isResetRealyNeeded(iResetOnCreation), m_cache(new QMap<QString, QVariant>()), m_document(iDocument),
-      m_whereClause(iWhereClause),
-      m_parentAttribute(iParentAttribute),
+      m_whereClause(std::move(iWhereClause)),
+      m_parentAttribute(std::move(iParentAttribute)),
       m_doctransactionTable(false), m_nodeTable(false), m_parametersTable(false),
       m_refreshBlocked(false)
 {
@@ -57,7 +55,7 @@ SKGObjectModelBase::SKGObjectModelBase(SKGDocument* iDocument,
     setTable(iTable);
 
     connect(m_document, &SKGDocument::tableModified, this, &SKGObjectModelBase::dataModified);
-    if (SKGMainPanel::getMainPanel()) {
+    if (SKGMainPanel::getMainPanel() != nullptr) {
         connect(SKGMainPanel::getMainPanel(), &SKGMainPanel::currentPageChanged, this, &SKGObjectModelBase::pageChanged, Qt::QueuedConnection);
     }
 }
@@ -121,7 +119,7 @@ void SKGObjectModelBase::setSupportedAttributes(const QStringList& iListAttribut
     for (int i = 0; i < nb; ++i) {
         QStringList values = l.at(i).split('|');
         int nbValues = values.count();
-        QString att = values.at(0);
+        const QString& att = values.at(0);
 
         if (nbValues > 0 && !m_listSupported.contains(att) && attributesAvailables.contains(att)) {
             m_listSupported.push_back(att);
@@ -158,7 +156,7 @@ void SKGObjectModelBase::setTable(const QString& iTable)
         }
         m_table = iTable;
         m_realTable = SKGServices::getRealTable(m_table);
-        if (m_document) {
+        if (m_document != nullptr) {
             m_listSchema = m_document->getDisplaySchemas(m_realTable);
         }
     }
@@ -248,7 +246,7 @@ void SKGObjectModelBase::refresh()
     {
         _SKGTRACEINFUNC(10);
         QStringList listAttibutesTmp;
-        if (m_document && m_document->getAttributesList(m_table, listAttibutesTmp).isSucceeded()) {
+        if (m_document != nullptr && m_document->getAttributesList(m_table, listAttibutesTmp).isSucceeded()) {
             m_isResetRealyNeeded = false;
             if (!listAttibutesTmp.isEmpty()) {
                 // Filter attributes
@@ -310,7 +308,7 @@ void SKGObjectModelBase::refresh()
                     wc += " ORDER BY " % m_groupby;
                 }
             }
-            if (m_document) {
+            if (m_document != nullptr) {
                 m_document->getObjects(m_table, wc, m_listObjects);
             }
 
@@ -329,7 +327,7 @@ void SKGObjectModelBase::refresh()
             SKGTRACEL(1) << nb << " objects found" << endl;
             for (int t = 0; t < nb; ++t) {
                 auto c = new SKGObjectBase(m_listObjects.at(t));
-                int id = (c ? c->getID() : 0);
+                int id = (c != nullptr ? c->getID() : 0);
 
                 int idparent = 0;
                 if (m_groupby.isEmpty()) {
@@ -491,7 +489,7 @@ int SKGObjectModelBase::columnCount(const QModelIndex& iParent) const
 QModelIndex SKGObjectModelBase::index(int row, int column, const QModelIndex& iParent) const
 {
     if (!hasIndex(row, column, iParent)) {
-        return QModelIndex();
+        return {};
     }
     _SKGTRACEINFUNC(10);
 
@@ -503,13 +501,13 @@ QModelIndex SKGObjectModelBase::index(int row, int column, const QModelIndex& iP
     int idChild = m_parentChildRelations.value(idParent).at(row);
 
     // SKGTRACE << table << "-" << idParent << "(" << row << ") ==> " << idChild << endl;
-    return (idChild ? createIndex(row, column, idChild) : QModelIndex());
+    return (idChild != 0 ? createIndex(row, column, idChild) : QModelIndex());
 }
 
 QModelIndex SKGObjectModelBase::parent(const QModelIndex& iIndex) const
 {
     if (!iIndex.isValid()) {
-        return QModelIndex();
+        return {};
     }
     _SKGTRACEINFUNC(10);
 
@@ -521,7 +519,7 @@ QModelIndex SKGObjectModelBase::parent(const QModelIndex& iIndex) const
     int idParent = m_childParentRelations.value(idChild);
     int row = m_objectsHashTableRows.value(idParent);
     // SKGTRACE << table << "-" << idChild << "(" << row << ") <== " << idParent << endl;
-    return idParent ? createIndex(row, 0, idParent) : QModelIndex();
+    return idParent != 0 ? createIndex(row, 0, idParent) : QModelIndex();
 }
 
 int SKGObjectModelBase::getIndexAttribute(const QString& iAttributeName) const
@@ -543,26 +541,27 @@ SKGServices::AttributeType SKGObjectModelBase::getAttributeType(int iIndex) cons
     return m_listAttributeTypes.value(iIndex);
 }
 
-QVariant SKGObjectModelBase::headerData(int section, Qt::Orientation orientation, int role) const
+QVariant SKGObjectModelBase::headerData(int iSection, Qt::Orientation iOrientation, int iRole) const
 {
     _SKGTRACEINFUNC(10);
 
-    if (orientation == Qt::Horizontal) {
-        if (role == Qt::DisplayRole) {
+    if (iOrientation == Qt::Horizontal) {
+        if (iRole == Qt::DisplayRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) {
-                att = m_listAttibutes.at(section);
+            if (iSection >= 0 && iSection < m_listAttibutes.count()) {
+                att = m_listAttibutes.at(iSection);
             } else {
-                att = SKGServices::intToString(section);
+                att = SKGServices::intToString(iSection);
             }
 
             return getDocument()->getDisplay(getTable() % '.' % att);
-        } else if (role == Qt::UserRole) {
+        }
+        if (iRole == Qt::UserRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) {
-                att = m_listAttibutes.at(section);
+            if (iSection >= 0 && iSection < m_listAttibutes.count()) {
+                att = m_listAttibutes.at(iSection);
             } else {
-                att = SKGServices::intToString(section);
+                att = SKGServices::intToString(iSection);
             }
 
             int indexAtt = m_listSupported.indexOf(att);
@@ -578,12 +577,13 @@ QVariant SKGObjectModelBase::headerData(int section, Qt::Orientation orientation
                 }
             }
             return att;
-        } else if (role == Qt::DecorationRole) {
+        }
+        if (iRole == Qt::DecorationRole) {
             QString att;
-            if (section >= 0 && section < m_listAttibutes.count()) {
-                att = m_listAttibutes.at(section);
+            if (iSection >= 0 && iSection < m_listAttibutes.count()) {
+                att = m_listAttibutes.at(iSection);
             } else {
-                att = SKGServices::intToString(section);
+                att = SKGServices::intToString(iSection);
             }
 
             return getDocument()->getIcon(getTable() % '.' % att);
@@ -655,82 +655,80 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
             if (iIndex.column() == 0) {
                 if (iRole == Qt::UserRole) {
                     return -obj->getID();   // For sorting
-                } else {
-                    int nb = rowCount(iIndex);
-
-                    // Is it possible to compute sums of f_CURRENTAMOUNT ?
-                    int posAmount = m_listAttibutes.indexOf(QStringLiteral("f_CURRENTAMOUNT"));
-                    if (posAmount == -1) {
-                        posAmount = m_listAttibutes.indexOf(QStringLiteral("f_REALCURRENTAMOUNT"));
-                    }
-                    if (posAmount != -1 && nb > 0) {
-                        // Compute sums
-                        double sum = 0.0;
-                        double average = 0.0;
-                        double min = DBL_MAX;
-                        double max = -DBL_MAX;
-                        for (int i = 0; i < nb ; ++i) {
-                            double amount = data(SKGObjectModelBase::index(i, posAmount, iIndex), Qt::UserRole).toDouble();
-                            sum += amount;
-                            max = qMax(max, amount);
-                            min = qMin(min, amount);
-                        }
-                        average = sum / nb;
-
-                        return i18nc("How to display a grouping title. Here \"title (count) Sum= [min , average , max]\"", "%1: %2 (%3) Sum=%4 [%5 , %6 , %7]",
-                                     getDocument()->getDisplay(m_groupby),
-                                     obj->getAttribute(QStringLiteral("t_title")),
-                                     nb,
-                                     formatMoney(sum),
-                                     formatMoney(min),
-                                     formatMoney(average),
-                                     formatMoney(max));
-                    } else {
-                        return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
-                                     getDocument()->getDisplay(m_groupby),
-                                     obj->getAttribute(QStringLiteral("t_title")),
-                                     nb);
-                    }
                 }
+                int nb = rowCount(iIndex);
+
+                // Is it possible to compute sums of f_CURRENTAMOUNT ?
+                int posAmount = m_listAttibutes.indexOf(QStringLiteral("f_CURRENTAMOUNT"));
+                if (posAmount == -1) {
+                    posAmount = m_listAttibutes.indexOf(QStringLiteral("f_REALCURRENTAMOUNT"));
+                }
+                if (posAmount != -1 && nb > 0) {
+                    // Compute sums
+                    double sum = 0.0;
+                    double average = 0.0;
+                    double min = std::numeric_limits<double>::max();
+                    double max = -std::numeric_limits<double>::max();
+                    for (int i = 0; i < nb ; ++i) {
+                        double amount = data(SKGObjectModelBase::index(i, posAmount, iIndex), Qt::UserRole).toDouble();
+                        sum += amount;
+                        max = qMax(max, amount);
+                        min = qMin(min, amount);
+                    }
+                    average = sum / nb;
+
+                    return i18nc("How to display a grouping title. Here \"title (count) Sum= [min , average , max]\"", "%1: %2 (%3) Sum=%4 [%5 , %6 , %7]",
+                                 getDocument()->getDisplay(m_groupby),
+                                 obj->getAttribute(QStringLiteral("t_title")),
+                                 nb,
+                                 formatMoney(sum),
+                                 formatMoney(min),
+                                 formatMoney(average),
+                                 formatMoney(max));
+                }
+                return i18nc("How to display a grouping title. Here \"title (count)\"", "%1: %2 (%3)",
+                             getDocument()->getDisplay(m_groupby),
+                             obj->getAttribute(QStringLiteral("t_title")),
+                             nb);
             }
             return "";
+        }
+        QString val;
+        if (att.startsWith(QLatin1String("p_"))) {
+            // This is a property
+            val = obj->getProperty(att.right(att.count() - 2));
         } else {
-            QString val;
-            if (att.startsWith(QLatin1String("p_"))) {
-                // This is a property
-                val = obj->getProperty(att.right(att.count() - 2));
-            } else {
-                // This is a real attribute
-                val = obj->getAttribute(att);
+            // This is a real attribute
+            val = obj->getAttribute(att);
 
-                switch (getAttributeType(iIndex.column())) {
-                case SKGServices::FLOAT: {
-                    double dval = SKGServices::stringToDouble(val);
+            switch (getAttributeType(iIndex.column())) {
+            case SKGServices::FLOAT: {
+                double dval = SKGServices::stringToDouble(val);
+                return dval;
+            }
+            case SKGServices::INTEGER: {
+                return SKGServices::stringToInt(val);
+            }
+            case SKGServices::DATE: {
+                QDate dval = SKGServices::stringToTime(val).date();
+                if (iRole == Qt::DisplayRole) {
+                    return SKGMainPanel::dateToString(dval);
+                }
+                if (iRole == Qt::UserRole) {
                     return dval;
                 }
-                case SKGServices::INTEGER: {
-                    return SKGServices::stringToInt(val);
-                }
-                case SKGServices::DATE: {
-                    QDate dval = SKGServices::stringToTime(val).date();
-                    if (iRole == Qt::DisplayRole) {
-                        return SKGMainPanel::dateToString(dval);
-                    } else if (iRole == Qt::UserRole) {
-                        return dval;
-                    }
-                }
-                default: {
-                }
-                }
-
-                if (m_doctransactionTable && att == QStringLiteral("t_savestep")) {
-                    return "";
-                }
+            }
+            default: {
+            }
             }
 
-            // return val+"("+SKGServices::intToString(rowCount(index))+")";
-            return val;
+            if (m_doctransactionTable && att == QStringLiteral("t_savestep")) {
+                return "";
+            }
         }
+
+        // return val+"("+SKGServices::intToString(rowCount(index))+")";
+        return val;
     }
 
     case Qt::FontRole: {
@@ -748,7 +746,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
         }
 
         int propertyId = data(iIndex, 101).toInt();
-        if (propertyId) {
+        if (propertyId != 0) {
             SKGPropertyObject p(m_document, propertyId);
             if (!p.getUrl().scheme().isEmpty()) {
                 QFont f;
@@ -771,7 +769,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
         }
 
         int propertyId = data(iIndex, 101).toInt();
-        if (propertyId) {
+        if (propertyId != 0) {
             SKGPropertyObject p(m_document, propertyId);
             if (!p.getUrl().scheme().isEmpty()) {
                 KColorScheme scheme(QPalette::Normal);
@@ -795,18 +793,20 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
                 return QVariant::fromValue(SKGServices::fromTheme(QStringLiteral("arrow-right")));
             };
             return "";
-        } else {
-            if (iIndex.column() == 0 && m_nodeTable) {
-                SKGNodeObject node(*obj);
-                return QVariant::fromValue(node.getIcon());
-            } else if (iIndex.column() == 0 && m_doctransactionTable) {
-                return QVariant::fromValue(SKGServices::fromTheme(obj->getAttribute(QStringLiteral("t_mode")) == QStringLiteral("U") ? QStringLiteral("edit-undo") : QStringLiteral("edit-redo")));
-            } else if (m_doctransactionTable && att == QStringLiteral("t_savestep")) {
-                if (obj->getAttribute(QStringLiteral("t_savestep")) == QStringLiteral("Y")) {
-                    return QVariant::fromValue(SKGServices::fromTheme(QStringLiteral("document-save")));
-                }
+        }
+        if (iIndex.column() == 0 && m_nodeTable) {
+            SKGNodeObject node(*obj);
+            return QVariant::fromValue(node.getIcon());
+        }
+        if (iIndex.column() == 0 && m_doctransactionTable) {
+            return QVariant::fromValue(SKGServices::fromTheme(obj->getAttribute(QStringLiteral("t_mode")) == QStringLiteral("U") ? QStringLiteral("edit-undo") : QStringLiteral("edit-redo")));
+        }
+        if (m_doctransactionTable && att == QStringLiteral("t_savestep")) {
+            if (obj->getAttribute(QStringLiteral("t_savestep")) == QStringLiteral("Y")) {
+                return QVariant::fromValue(SKGServices::fromTheme(QStringLiteral("document-save")));
             }
         }
+
         break;
     }
     case Qt::ToolTipRole: {
@@ -814,12 +814,12 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
         QString toolTipString;
         SKGObjectBase* obj = getObjectPointer(iIndex);
 
-        if (obj && m_document) {
+        if (obj != nullptr && m_document != nullptr) {
             if (m_doctransactionTable) {
                 SKGDocument::SKGMessageList msg;
                 m_document->getMessages(obj->getID(), msg);
                 int nbMessages = msg.count();
-                if (nbMessages) {
+                if (nbMessages > 0) {
                     for (int i = 0; i < nbMessages; ++i) {
                         if (i != 0) {
                             toolTipString += '\n';
@@ -861,7 +861,7 @@ QVariant SKGObjectModelBase::computeData(const QModelIndex& iIndex, int iRole) c
     }
     case 99: {
         SKGObjectBase* obj = getObjectPointer(iIndex);
-        if (obj) {
+        if (obj != nullptr) {
             return SKGServices::stringToDouble(obj->getAttribute(QStringLiteral("f_sortorder")));
         }
         break;
@@ -997,7 +997,7 @@ bool SKGObjectModelBase::dropMimeData(const QMimeData* iData,
     if (iAction == Qt::IgnoreAction) {
         return true;
     }
-    if (!iData || !(iData->hasFormat(QStringLiteral("application/skg.node.ids")) || iData->hasUrls())) {
+    if ((iData == nullptr) || !(iData->hasFormat(QStringLiteral("application/skg.node.ids")) || iData->hasUrls())) {
         return false;    // TODO(Stephane MANKOWSKI): accept all
     }
     if (iColumn > 0) {
@@ -1113,7 +1113,7 @@ void SKGObjectModelBase::dataModified(const QString& iTableName, int iIdTransact
         SKGTRACEL(1) << "getTable=" << getRealTable() << endl;
         SKGTRACEL(1) << "Parameters=" << iTableName << " , " << iIdTransaction << endl;
         SKGTabPage* page = SKGTabPage::parentTabPage(qobject_cast< QWidget* >(this->QObject::parent()));
-        SKGTabPage* cpage = SKGMainPanel::getMainPanel() ? SKGMainPanel::getMainPanel()->currentPage() : nullptr;
+        SKGTabPage* cpage = SKGMainPanel::getMainPanel() != nullptr ? SKGMainPanel::getMainPanel()->currentPage() : nullptr;
         if (page != nullptr && page != cpage) {
             m_isResetRealyNeeded = true;
             return;
@@ -1132,10 +1132,9 @@ QString SKGObjectModelBase::getAttributeForGrouping(const SKGObjectBase& iObject
     if (iAttribute.startsWith(QLatin1String("p_"))) {
         // This is a property
         return iObject.getProperty(iAttribute.right(iAttribute.count() - 2));
-    } else {
-        // This is a real attribute
-        return iObject.getAttribute(iAttribute);
     }
+    // This is a real attribute
+    return iObject.getAttribute(iAttribute);
 }
 
 QString SKGObjectModelBase::formatMoney(double iValue) const
