@@ -25,9 +25,9 @@
 #include <qabstractitemmodel.h>
 #include <qstringlist.h>
 
-#include "skgobjectbase.h"
 #include "skgbasegui_export.h"
 #include "skgdocument.h"
+#include "skgobjectbase.h"
 
 class QWidget;
 /**
@@ -48,9 +48,9 @@ public:
      */
     SKGObjectModelBase(SKGDocument* iDocument,
                        const QString& iTable,
-                       const QString& iWhereClause,
+                       QString  iWhereClause,
                        QWidget* iParent,
-                       const QString& iParentAttribute = QString(),
+                       QString  iParentAttribute = QString(),
                        bool iResetOnCreation = true);
 
     /**
@@ -96,10 +96,10 @@ public:
 
     /**
      * Returns the parent of the model item with the given index, or QModelIndex() if it has no parent.
-     * @param index index
+     * @param iIndex index
      * @return the parent
      */
-    QModelIndex parent(const QModelIndex& index) const override;
+    QModelIndex parent(const QModelIndex& iIndex) const override;
 
     /**
      * Returns the number of columns for the given parent.
@@ -110,58 +110,58 @@ public:
 
     /**
      * Returns the data stored under the given role for the item referred to by the index.
-     * @param index the index
-     * @param role the role
+     * @param iIndex the index
+     * @param iRole the role
      * @return the returned value
      */
-    QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
+    QVariant data(const QModelIndex& iIndex, int iRole = Qt::DisplayRole) const override;
 
     /**
      * Returns the data stored under the given role for the item referred to by the index.
-     * @param index the index
-     * @param role the role
+     * @param iIndex the index
+     * @param iRole the role
      * @return the returned value
      */
-    virtual QVariant computeData(const QModelIndex& index, int role = Qt::DisplayRole) const;
+    virtual QVariant computeData(const QModelIndex& iIndex, int iRole = Qt::DisplayRole) const;
 
     /**
      * Returns the SKGObjectBase for the item referred to by the index.
-     * @param index the index
+     * @param iIndex the index
      * @return the returned SKGObjectBase
      */
-    virtual SKGObjectBase getObject(const QModelIndex& index) const;
+    virtual SKGObjectBase getObject(const QModelIndex& iIndex) const;
 
     /**
      * Returns the SKGObjectBase for the item referred to by the index.
-     * @param index the index
+     * @param iIndex the index
      * @return the returned SKGObjectBase. Do not delete it !
      */
-    virtual SKGObjectBase* getObjectPointer(const QModelIndex& index) const;
+    virtual SKGObjectBase* getObjectPointer(const QModelIndex& iIndex) const;
 
     /**
      * Returns the data for the given role and section in the header with the specified orientation.
-     * @param section the section
-     * @param orientation the orientation
-     * @param role the role
+     * @param iSection the section
+     * @param iOrientation the orientation
+     * @param iRole the role
      * @return the header data
      */
-    QVariant headerData(int section, Qt::Orientation orientation, int role = Qt::DisplayRole) const override;
+    QVariant headerData(int iSection, Qt::Orientation iOrientation, int iRole = Qt::DisplayRole) const override;
 
     /**
      * Returns the item flags for the given index.
-     * @param index index of the object
+     * @param iIndex index of the object
      * @return flags of the given index
      */
-    Qt::ItemFlags flags(const QModelIndex& index) const override;
+    Qt::ItemFlags flags(const QModelIndex& iIndex) const override;
 
     /**
      * Sets the role data for the item at index to value. Returns true if successful; otherwise returns false.
-     * @param index index of the object
-     * @param value value
-     * @param role role
+     * @param iIndex index of the object
+     * @param iValue value
+     * @param iRole role
      * @return
      */
-    bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
+    bool setData(const QModelIndex& iIndex, const QVariant& iValue, int iRole = Qt::EditRole) override;
 
     /**
      * Return the index of the attribute, -1 if not found
@@ -188,7 +188,7 @@ public:
      * Set the table. Do not forget to do a reset after that.
      * @param iTable the table name
      */
-    virtual void setTable(const QString& iTable);
+    void setTable(const QString& iTable);
 
     /**
      * Get table name
@@ -274,26 +274,26 @@ public:
      * Returns an object that contains serialized items of data corresponding to the list of indexes specified.
      *The formats used to describe the encoded data is obtained from the mimeTypes() function.
      * If the list of indexes is empty, or there are no supported MIME types, 0 is returned rather than a serialized empty list.
-     * @param indexes the index object
+     * @param iIndexes the index object
      * @return the mime data
      */
-    QMimeData* mimeData(const QModelIndexList& indexes) const override;
+    QMimeData* mimeData(const QModelIndexList& iIndexes) const override;
 
     /**
      * Handles the data supplied by a drag and drop operation that ended with the given action.
      * Returns true if the data and action can be handled by the model; otherwise returns false.
      * Although the specified row, column and parent indicate the location of an item in the model where the operation ended,
      *it is the responsibility of the view to provide a suitable location for where the data should be inserted.
-     * @param data mime data
-     * @param action action
-     * @param row row
-     * @param column column
+     * @param iData mime data
+     * @param iAction action
+     * @param iRow row
+     * @param iColumn column
      * @param iParent parent
      * @return true if the dropping was successful otherwise false.
      */
-    bool dropMimeData(const QMimeData* data,
-                      Qt::DropAction action,
-                      int row, int column,
+    bool dropMimeData(const QMimeData* iData,
+                      Qt::DropAction iAction,
+                      int iRow, int iColumn,
                       const QModelIndex& iParent) override;
 Q_SIGNALS:
     /**
