@@ -32,12 +32,12 @@ SKGPeriodEdit::SKGPeriodEdit(QWidget* iParent, bool iModeEnabled)
 {
     ui.setupUi(this);
 
-    ui.kPeriod->addItem(i18nc("Period mode", "All Dates"), int(SKGPeriodEdit::ALL));
-    ui.kPeriod->addItem(i18nc("Period mode", "Current..."), int(SKGPeriodEdit::CURRENT));
-    ui.kPeriod->addItem(i18nc("Period mode", "Previous..."), int(SKGPeriodEdit::PREVIOUS));
-    ui.kPeriod->addItem(i18nc("Period mode", "Last..."), int(SKGPeriodEdit::LAST));
-    ui.kPeriod->addItem(i18nc("Period mode", "Custom..."), int(SKGPeriodEdit::CUSTOM));
-    ui.kPeriod->addItem(i18nc("Period mode", "Timeline..."), int(SKGPeriodEdit::TIMELINE));
+    ui.kPeriod->addItem(i18nc("Period mode", "All Dates"), static_cast<int>(SKGPeriodEdit::ALL));
+    ui.kPeriod->addItem(i18nc("Period mode", "Current..."), static_cast<int>(SKGPeriodEdit::CURRENT));
+    ui.kPeriod->addItem(i18nc("Period mode", "Previous..."), static_cast<int>(SKGPeriodEdit::PREVIOUS));
+    ui.kPeriod->addItem(i18nc("Period mode", "Last..."), static_cast<int>(SKGPeriodEdit::LAST));
+    ui.kPeriod->addItem(i18nc("Period mode", "Custom..."), static_cast<int>(SKGPeriodEdit::CUSTOM));
+    ui.kPeriod->addItem(i18nc("Period mode", "Timeline..."), static_cast<int>(SKGPeriodEdit::TIMELINE));
 
     ui.kInterval->addItem(i18nc("Period interval", "day(s)"), 0);
     ui.kInterval->addItem(i18nc("Period interval", "week(s)"), 1);
@@ -210,7 +210,7 @@ SKGPeriodEdit::PeriodMode SKGPeriodEdit::mode() const
     return static_cast<PeriodMode>(ui.kPeriod->itemData(ui.kPeriod->currentIndex()).toInt());
 }
 
-void SKGPeriodEdit::getDates(SKGPeriodEdit::PeriodMode iPeriod, SKGPeriodEdit::PeriodInterval iInterval, int iValue, QDate& oBeginDate, QDate& oEndDate, const QDate iDate)
+void SKGPeriodEdit::getDates(SKGPeriodEdit::PeriodMode iPeriod, SKGPeriodEdit::PeriodInterval iInterval, int iValue, QDate& oBeginDate, QDate& oEndDate, QDate iDate)
 {
     QDate a = iDate;
     QDate b = a;
@@ -471,10 +471,10 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         if (ui.kFuture->isChecked()) {
             wc +=  QStringLiteral(" OR d_date > (SELECT date('now'))");
         }
-        if (oWhereClausForPreviousData) {
+        if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now'), " % strfFormat % "))";
         }
-        if (oWhereClausForForecastData) {
+        if (oWhereClausForForecastData != nullptr) {
             *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now'))");
         }
         break;
@@ -485,10 +485,10 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         if (iForecast) {
             wc += " AND period(d_date, " % strfFormat % ")<=(SELECT period(date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";    // For forecast based on scheduled operations
 
-            if (oWhereClausForPreviousData) {
+            if (oWhereClausForPreviousData != nullptr) {
                 *oWhereClausForPreviousData = sqlAttribute % " < (SELECT period(date('now','start of month', '-" % SKGServices::intToString(val) % ' ' % sqlInterval % "')," % strfFormat % "))";
             }
-            if (oWhereClausForForecastData) {
+            if (oWhereClausForForecastData != nullptr) {
                 *oWhereClausForForecastData = sqlAttribute % " > (SELECT period(date('now','start of month', '-" % SKGServices::intToString(one) % ' ' % sqlInterval % "')," % strfFormat % "))";
             }
         }
@@ -509,10 +509,10 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         if (ui.kFuture->isChecked()) {
             wc += QStringLiteral(" OR d_date > (SELECT date('now'))");
         }
-        if (oWhereClausForPreviousData) {
+        if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = "d_date <= (SELECT date('now','-" % SKGServices::intToString(val) % ' ' % sqlInterval % "'))";
         }
-        if (oWhereClausForForecastData) {
+        if (oWhereClausForForecastData != nullptr) {
             *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now'))");
         }
         break;
@@ -522,10 +522,10 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         if (iForecast) {
             wc += "AND d_date<='" % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date())) % '\'';    // For forecast based on scheduled operations
         }
-        if (oWhereClausForPreviousData) {
+        if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(QDateTime(ui.kDateBegin->date())) % '\'';
         }
-        if (oWhereClausForForecastData) {
+        if (oWhereClausForForecastData != nullptr) {
             *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now'))");
         }
         break;
@@ -537,10 +537,10 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         if (iForecast) {
             wc += "AND d_date<='" % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date())) % '\'';    // For forecast based on scheduled operations
         }
-        if (oWhereClausForPreviousData) {
+        if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = "d_date<'" % SKGServices::dateToSqlString(QDateTime(ui.kDateBegin->date())) % '\'';
         }
-        if (oWhereClausForForecastData) {
+        if (oWhereClausForForecastData != nullptr) {
             *oWhereClausForForecastData = "d_date>'" % SKGServices::dateToSqlString(QDateTime(ui.kDateEnd->date())) % '\'';
         }
         break;
@@ -550,17 +550,17 @@ QString SKGPeriodEdit::getWhereClause(bool iForecast, QString* oWhereClausForPre
         ui.kDateBegin->setDate(a);
         ui.kDateEnd->setDate(b);
         wc = QStringLiteral("1=1");
-        if (oWhereClausForPreviousData) {
+        if (oWhereClausForPreviousData != nullptr) {
             *oWhereClausForPreviousData = QStringLiteral("1=0");
         }
-        if (oWhereClausForForecastData) {
+        if (oWhereClausForForecastData != nullptr) {
             *oWhereClausForForecastData = QStringLiteral("d_date > (SELECT date('now'))");
         }
         break;
     }
 
     wc = "((" % wc % ") OR d_date='0000') AND d_date!='0000-00-00'";
-    if (oWhereClausForPreviousData) {
+    if (oWhereClausForPreviousData != nullptr) {
         *oWhereClausForPreviousData = "((" % *oWhereClausForPreviousData % ") OR d_date='0000-00-00')";
     }
 
