@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "ui_skgperiodedit.h"
 #include "skgbasegui_export.h"
+#include "ui_skgperiodedit.h"
 /**
  * This file is a period editor.
  */
@@ -130,7 +130,7 @@ public:
      * @param iDate the input date
      */
     // cppcheck-suppress passedByValue
-    static void getDates(PeriodMode iPeriod, PeriodInterval iInterval, int iValue, QDate& oBeginDate, QDate& oEndDate, const QDate iDate = QDate::currentDate());
+    static void getDates(PeriodMode iPeriod, PeriodInterval iInterval, int iValue, QDate& oBeginDate, QDate& oEndDate, QDate iDate = QDate::currentDate());
 
     /**
      * Get begin and end dates
@@ -150,7 +150,7 @@ Q_SIGNALS:
     void changed();
 
 private:
-    Ui::skgperiodedit_base ui;
+    Ui::skgperiodedit_base ui{};
 
     bool m_modeEnable;
     int m_count;
