@@ -22,10 +22,10 @@
 #include "skgshow.h"
 
 #include <klocalizedstring.h>
-#include <qmenu.h>
-#include <qicon.h>
-#include <qwidgetaction.h>
 #include <qdom.h>
+#include <qicon.h>
+#include <qmenu.h>
+#include <qwidgetaction.h>
 
 #include "skgperiodedit.h"
 #include "skgservices.h"
@@ -68,16 +68,16 @@ void SKGShow::setMode(SKGShow::OperatorMode iMode)
 QString SKGShow::getState()
 {
     QStringList itemsChecked;
-    if (m_menu) {
+    if (m_menu != nullptr) {
         QList<QAction*> actionsList = m_menu->actions();
         int nb = actionsList.count();
         itemsChecked.reserve(nb);
         for (int i = 0; i < nb; ++i) {
             QAction* act = actionsList.at(i);
-            if (act) {
-                QWidgetAction* wact = qobject_cast<QWidgetAction*>(act);
-                if (wact) {
-                    SKGPeriodEdit* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
+            if (act != nullptr) {
+                auto* wact = qobject_cast<QWidgetAction*>(act);
+                if (wact != nullptr) {
+                    auto* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
                     itemsChecked.push_back(act->data().toString() % ":" % pedit->getState());
                 } else {
                     if (act->isChecked()) {
@@ -98,17 +98,17 @@ void SKGShow::setDefaultState(const QString& iState)
 
 void SKGShow::setState(const QString& iState)
 {
-    if (m_menu) {
+    if (m_menu != nullptr) {
         QStringList itemsChecked = SKGServices::splitCSVLine(iState.isEmpty() ? m_defaultState : iState);
 
         int nb = m_actions.count();
         for (int i = 0; i < nb; ++i) {
             QAction* act = m_actions.at(i);
-            if (act) {
+            if (act != nullptr) {
                 QString identifier = m_actions.at(i)->data().toString();
-                QWidgetAction* wact = qobject_cast<QWidgetAction*>(act);
-                if (wact) {
-                    SKGPeriodEdit* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
+                auto* wact = qobject_cast<QWidgetAction*>(act);
+                if (wact != nullptr) {
+                    auto* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
                     for (const auto& item : qAsConst(itemsChecked)) {
                         if (item.startsWith(identifier % ":")) {
                             pedit->setState(item.right(item.length() - identifier.length() - 1));
@@ -132,17 +132,17 @@ void SKGShow::setState(const QString& iState)
 QString SKGShow::getWhereClause() const
 {
     QString wc;
-    if (m_menu) {
+    if (m_menu != nullptr) {
         QList<QAction*> actionsList = m_menu->actions();
         int nb = actionsList.count();
         bool noCheck = true;
         for (int i = 0; i < nb; ++i) {
             QAction* act = actionsList.at(i);
 
-            if (act) {
-                QWidgetAction* wact = qobject_cast<QWidgetAction*>(act);
-                if (wact) {
-                    SKGPeriodEdit* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
+            if (act != nullptr) {
+                auto* wact = qobject_cast<QWidgetAction*>(act);
+                if (wact != nullptr) {
+                    auto* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
                     if (!wc.isEmpty()) {
                         wc += (m_mode == OR ? QStringLiteral(" OR ") : QStringLiteral(" AND "));
                     }
@@ -165,7 +165,7 @@ QString SKGShow::getWhereClause() const
                 }
             }
         }
-        if (nb && noCheck) {
+        if ((nb != 0) && noCheck) {
             wc = QStringLiteral("1=0");
         }
     }
@@ -175,14 +175,14 @@ QString SKGShow::getWhereClause() const
 QString SKGShow::getTitle() const
 {
     QString wc;
-    if (m_menu) {
+    if (m_menu != nullptr) {
         int nb = m_actions.count();
         for (int i = 0; i < nb; ++i) {
             QAction* act = m_actions.at(i);
-            if (act) {
-                QWidgetAction* wact = qobject_cast<QWidgetAction*>(act);
-                if (wact) {
-                    SKGPeriodEdit* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
+            if (act != nullptr) {
+                auto* wact = qobject_cast<QWidgetAction*>(act);
+                if (wact != nullptr) {
+                    auto* pedit = qobject_cast<SKGPeriodEdit*>(wact->defaultWidget());
                     if (!wc.isEmpty()) {
                         wc += (m_mode == OR ? QStringLiteral(" + ") : QStringLiteral(" , "));
                     }
@@ -222,9 +222,9 @@ int SKGShow::count()
 int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, const QString& iIcon,
                             const QString& iWhereClose, const QString& iGroup, const QKeySequence& iShortcut)
 {
-    if (m_menu) {
+    if (m_menu != nullptr) {
         QActionGroup* groupAction = m_groups.value(iGroup);
-        if (!groupAction) {
+        if (groupAction == nullptr) {
             groupAction = new QActionGroup(this);
             m_groups[iGroup] = groupAction;
         }
@@ -232,7 +232,7 @@ int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, co
         QString name = iText;
         name = name.replace('&', QStringLiteral("&&"));
         QAction* act = m_menu->addAction(name);
-        if (act) {
+        if (act != nullptr) {
             act->setToolTip(name);
             act->setIcon(SKGServices::fromTheme(iIcon));
             act->setData(iIdentifier);
@@ -264,7 +264,7 @@ int SKGShow::addGroupedItem(const QString& iIdentifier, const QString& iText, co
 
 int SKGShow::addPeriodItem(const QString& iIdentifier)
 {
-    if (m_menu) {
+    if (m_menu != nullptr) {
         auto m_periodEdit1 = new SKGPeriodEdit(this);
 
         // Set default
@@ -276,7 +276,7 @@ int SKGShow::addPeriodItem(const QString& iIdentifier)
 
         // Add widget in menu
         auto act = new QWidgetAction(this);
-        if (act) {
+        if (act != nullptr) {
             act->setData(iIdentifier);
             act->setDefaultWidget(m_periodEdit1);
 
@@ -310,11 +310,11 @@ int SKGShow::addItem(const QString& iIdentifier, const QString& iText, const QSt
                      const QKeySequence& iShortcut
                     )
 {
-    if (m_menu) {
+    if (m_menu != nullptr) {
         QString name = iText;
         name = name.replace('&', QStringLiteral("&&"));
         QAction* act = m_menu->addAction(name);
-        if (act) {
+        if (act != nullptr) {
             act->setToolTip(name);
             act->setIcon(SKGServices::fromTheme(iIcon));
             act->setData(iIdentifier);
@@ -364,15 +364,15 @@ void SKGShow::setListIdToUncheckWhenUnchecked(int iIndex, const QString& iIds)
 
 void SKGShow::addSeparator()
 {
-    if (m_menu) {
+    if (m_menu != nullptr) {
         m_menu->addSeparator();
     }
 }
 
 void SKGShow::trigger()
 {
-    QAction* act = qobject_cast<QAction*>(sender());
-    if (act && !m_inTrigger) {
+    auto* act = qobject_cast<QAction*>(sender());
+    if ((act != nullptr) && !m_inTrigger) {
         m_inTrigger = true;
 
         // Apply rules
@@ -384,7 +384,7 @@ void SKGShow::trigger()
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
                     QAction* act2 = getAction(items.at(i));
-                    if (act2 && act2 != act) {
+                    if ((act2 != nullptr) && act2 != act) {
                         act2->setChecked(true);
                     }
                 }
@@ -396,7 +396,7 @@ void SKGShow::trigger()
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
                     QAction* act2 = getAction(items.at(i));
-                    if (act2 && act2 != act) {
+                    if ((act2 != nullptr) && act2 != act) {
                         act2->setChecked(false);
                     }
                 }
@@ -408,7 +408,7 @@ void SKGShow::trigger()
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
                     QAction* act2 = getAction(items.at(i));
-                    if (act2 && act2 != act) {
+                    if ((act2 != nullptr) && act2 != act) {
                         act2->setChecked(true);
                     }
                 }
@@ -420,7 +420,7 @@ void SKGShow::trigger()
                 int nb = items.count();
                 for (int i = 0; i < nb; ++i) {
                     QAction* act2 = getAction(items.at(i));
-                    if (act2 && act2 != act) {
+                    if ((act2 != nullptr) && act2 != act) {
                         act2->setChecked(false);
                     }
                 }
@@ -433,12 +433,12 @@ void SKGShow::trigger()
         // Change icon
         QStringList icons;
         QString mainIcon;
-        if (m_menu) {
+        if (m_menu != nullptr) {
             int nb = m_actions.count();
             icons.reserve(nb);
             for (int i = 0; i < nb; ++i) {
                 QAction* act2 = m_actions.at(i);
-                if (act2 && act2->isChecked()) {
+                if ((act2 != nullptr) && act2->isChecked()) {
                     if (!m_icons.at(i).isEmpty()) {
                         if (mainIcon.isEmpty()) {
                             mainIcon = m_icons.at(i);
@@ -500,12 +500,12 @@ void SKGShow::refreshTitle()
 QAction* SKGShow::getAction(const QString& iIdentifier) const
 {
     QAction* output = nullptr;
-    if (m_menu) {
+    if (m_menu != nullptr) {
         QList<QAction*> actionsList = m_menu->actions();
         int nb = actionsList.count();
-        for (int i = 0; !output && i < nb; ++i) {
+        for (int i = 0; (output == nullptr) && i < nb; ++i) {
             QAction* act = actionsList.at(i);
-            if (act && act->data().toString() == iIdentifier) {
+            if ((act != nullptr) && act->data().toString() == iIdentifier) {
                 output = act;
             }
         }
