@@ -25,8 +25,8 @@
 #include <qdatetime.h>
 #include <qflags.h>
 
-#include "skgcombobox.h"
 #include "skgbasegui_export.h"
+#include "skgcombobox.h"
 /**
  * This file is a simple period selector.
  */
@@ -53,18 +53,18 @@ public:
      * This enumerate for mode
      */
     enum Mode {
-        NONE = 0,                                              /**< None */
-        PREVIOUS_MONTHS = 1,                                   /**< Only previous months */
-        PREVIOUS_YEARS = 32,                                   /**< Only previous years */
-        PREVIOUS_PERIODS = 2,                                  /**< All previous periods including quarters, semesters and years*/
-        CURRENT_MONTH = 4,                                     /**< Current month */
-        CURRENT_YEAR = 64,                                     /**< Current years */
-        CURRENT_PERIOD = 8,                                    /**< Current period including quarter, semester and year */
-        ALL = 16,                                              /**< The "All dates" period */
-        PREVIOUS_AND_CURRENT_MONTHS = 1 | 4,                   /**< Previous and current months*/
-        PREVIOUS_AND_CURRENT_YEARS = 32 | 64,                  /**< Previous and current years*/
-        PREVIOUS_AND_CURRENT_PERIODS = 1 | 2 | 4 | 8,          /**< Previous and current periods including quarters, semesters and years*/
-        ALL_PERIODS =  1 | 2 | 4 | 8 | 16                      /**< All periods*/
+        NONE = 0u,                                              /**< None */
+        PREVIOUS_MONTHS = 1u,                                   /**< Only previous months */
+        PREVIOUS_YEARS = 32u,                                   /**< Only previous years */
+        PREVIOUS_PERIODS = 2u,                                  /**< All previous periods including quarters, semesters and years*/
+        CURRENT_MONTH = 4u,                                     /**< Current month */
+        CURRENT_YEAR = 64u,                                     /**< Current years */
+        CURRENT_PERIOD = 8u,                                    /**< Current period including quarter, semester and year */
+        ALL = 16u,                                              /**< The "All dates" period */
+        PREVIOUS_AND_CURRENT_MONTHS = 1u | 4u,                  /**< Previous and current months*/
+        PREVIOUS_AND_CURRENT_YEARS = 32u | 64u,                 /**< Previous and current years*/
+        PREVIOUS_AND_CURRENT_PERIODS = 1u | 2u | 4u | 8u,       /**< Previous and current periods including quarters, semesters and years*/
+        ALL_PERIODS =  1u | 2u | 4u | 8u | 16u                  /**< All periods*/
     };
 
     /**
@@ -102,7 +102,7 @@ public:
      * @param iDate the first date to take into account
      */
     // cppcheck-suppress passedByValue
-    virtual void setFirstDate(const QDate iDate);
+    virtual void setFirstDate(QDate iDate);
 
     /**
      * To know if the mode of widget (default: PREVIOUS_MONTHS)
