@@ -41,12 +41,11 @@ SKGTableWidget::SKGTableWidget(QWidget* iParent)
 }
 
 SKGTableWidget::~SKGTableWidget()
-{
-}
+    = default;
 
 void SKGTableWidget::onRangeChanged()
 {
-    QScrollBar* scrollb = qobject_cast<QScrollBar*>(sender());
+    auto* scrollb = qobject_cast<QScrollBar*>(sender());
     if ((stickH && scrollb == horizontalScrollBar()) || (stickV && scrollb == verticalScrollBar())) {
         scrollb->setValue(scrollb->maximum());
     }
@@ -54,8 +53,8 @@ void SKGTableWidget::onRangeChanged()
 
 void SKGTableWidget::onActionTriggered()
 {
-    QScrollBar* scrollb = qobject_cast<QScrollBar*>(sender());
-    if (scrollb) {
+    auto* scrollb = qobject_cast<QScrollBar*>(sender());
+    if (scrollb != nullptr) {
         if (scrollb == horizontalScrollBar()) {
             stickH = (scrollb->value() == scrollb->maximum());
         }
@@ -87,8 +86,8 @@ bool SKGTableWidget::stickVertical() const
 bool SKGTableWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 {
     if (iObject == this && iEvent != nullptr && iEvent->type() == QEvent::KeyPress) {
-        QKeyEvent* kevent = static_cast<QKeyEvent*>(iEvent);
-        if (kevent) {
+        auto* kevent = dynamic_cast<QKeyEvent*>(iEvent);
+        if (kevent != nullptr) {
             if (kevent->key() == Qt::Key_Delete && state() != QAbstractItemView::EditingState) {
                 QList<QTableWidgetItem*> listOfSelectedItems = this->selectedItems();
                 int nb = listOfSelectedItems.count();
@@ -112,14 +111,14 @@ bool SKGTableWidget::eventFilter(QObject* iObject, QEvent* iEvent)
                         Q_EMIT removeLine(listIndex.at(i));
                     }
 
-                    if (iEvent) {
+                    if (iEvent != nullptr) {
                         iEvent->accept();
                     }
                     return true;  // stop the process
                 }
             } else if (kevent->matches(QKeySequence::Copy) && this->state() != QAbstractItemView::EditingState) {
                 copy();
-                if (iEvent) {
+                if (iEvent != nullptr) {
                     iEvent->accept();
                 }
                 return true;  // stop the process
@@ -133,10 +132,10 @@ bool SKGTableWidget::eventFilter(QObject* iObject, QEvent* iEvent)
 void SKGTableWidget::copy()
 {
     QItemSelectionModel* selection = selectionModel();
-    if (selection) {
+    if (selection != nullptr) {
         QModelIndexList indexes = selection->selectedIndexes();
 
-        if (indexes.size() < 1) {
+        if (indexes.empty()) {
             return;
         }
 
