@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include <qtablewidget.h>
 #include "skgbasegui_export.h"
+#include <qtablewidget.h>
 /**
  * This file is a combo box with more features.
  */
@@ -71,7 +71,7 @@ Q_SIGNALS:
     /**
      * Line must be removed
      */
-    void removeLine(int);
+    void removeLine(int /*_t1*/);
 
 protected:
     /**
