@@ -26,9 +26,9 @@
 
 
 #include "skgbasegui_export.h"
-#include "ui_skgtablewithgraph.h"
 #include "skgcombobox.h"
 #include "skgservices.h"
+#include "ui_skgtablewithgraph.h"
 
 class SKGGraphicsScene;
 class QMenu;
@@ -123,105 +123,105 @@ public:
     * @return a string containing all information needed to set the same state.
     * Could be an XML stream
      */
-    virtual QString getState();
+    QString getState();
 
     /**
      * Returns the table.
      * @return table
      */
-    virtual QTableWidget* table() const;
+    QTableWidget* table() const;
 
     /**
      * Returns the graph.
      * @return graph
      */
-    virtual SKGGraphicsView* graph() const;
+    SKGGraphicsView* graph() const;
 
     /**
      * Returns the text report.
      * @return text report
      */
-    virtual SKGWebView* textReport() const;
+    SKGWebView* textReport() const;
 
     /**
      * Get the mode for the additional display
      * @return the mode
      */
-    virtual SKGTableWithGraph::DisplayAdditionalFlag getAdditionalDisplayMode() const;
+    SKGTableWithGraph::DisplayAdditionalFlag getAdditionalDisplayMode() const;
 
     /**
      * Get the table content
      * @return the table content
      */
-    virtual SKGStringListList getTable();
+    SKGStringListList getTable();
 
     /**
      * Get a pointer on the contextual menu of the table
      * @return contextual menu
      */
-    virtual QMenu* getTableContextualMenu() const;
+    QMenu* getTableContextualMenu() const;
 
     /**
      * Get a pointer on the contextual menu of the graph
      * @return contextual menu
      */
-    virtual QMenu* getGraphContextualMenu() const;
+    QMenu* getGraphContextualMenu() const;
 
     /**
      * Get the visibility of the graph type selector zone
      * @return the visibility
      */
-    virtual bool isGraphTypeSelectorVisible() const;
+    bool isGraphTypeSelectorVisible() const;
 
     /**
      * Get the selectability of items
      * @return the selectability
      */
-    virtual bool isSelectable() const;
+    bool isSelectable() const;
 
     /**
      * Get the shadows visibility
      * @return the visibility
      */
-    virtual bool isShadowVisible() const;
+    bool isShadowVisible() const;
 
     /**
      * Get the graph type
      *  @return the type of graph
      */
-    virtual SKGTableWithGraph::GraphType getGraphType() const;
+    SKGTableWithGraph::GraphType getGraphType() const;
 
     /**
      * Get the number of columns
      * @param iWithComputed with compute columns (average, sum, forecast, ...) or not
      * @return the number of columns
      */
-    virtual int getNbColumns(bool iWithComputed = false) const;
+    int getNbColumns(bool iWithComputed = false) const;
 
     /**
      * @brief Get show widget
      *
      * @return SKGShow*
      **/
-    virtual SKGShow* getShowWidget() const;
+    SKGShow* getShowWidget() const;
 
     /**
      * To know if the table is visible
      * @return the visibility
      */
-    virtual bool isTableVisible() const;
+    bool isTableVisible() const;
 
     /**
      * To know if the graph is visible
      * @return the visibility
      */
-    virtual bool isGraphVisible() const;
+    bool isGraphVisible() const;
 
     /**
      * To know if the text report is visible
      * @return the visibility
      */
-    virtual bool isTextReportVisible() const;
+    bool isTextReportVisible() const;
 
 public Q_SLOTS:
 
@@ -230,7 +230,7 @@ public Q_SLOTS:
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState);
+    void setState(const QString& iState);
 
     /**
      * Set Data
@@ -238,162 +238,162 @@ public Q_SLOTS:
      * @param iPrimaryUnit the primary unit
      * @param iSecondaryUnit the secondary unit
      * @param iAdditionalInformation show sum and average columns
-     * @param iNbVirtualColumn number of virtual columns
+     * @param iNbVirtualColumn number of columns
      */
-    virtual void setData(const SKGStringListList& iData,
-                         const SKGServices::SKGUnitInfo& iPrimaryUnit,
-                         const SKGServices::SKGUnitInfo& iSecondaryUnit,
-                         SKGTableWithGraph::DisplayAdditionalFlag iAdditionalInformation = SKGTableWithGraph::ALL,
-                         int iNbVirtualColumn = 0);
+    void setData(const SKGStringListList& iData,
+                 const SKGServices::SKGUnitInfo& iPrimaryUnit,
+                 const SKGServices::SKGUnitInfo& iSecondaryUnit,
+                 SKGTableWithGraph::DisplayAdditionalFlag iAdditionalInformation = SKGTableWithGraph::ALL,
+                 int iNbVirtualColumn = 0);
 
 
     /**
      * Set the visibility of the graph type selector zone
      * @param iVisible the visibility
      */
-    virtual void setGraphTypeSelectorVisible(bool iVisible);
+    void setGraphTypeSelectorVisible(bool iVisible);
 
     /**
      * Enable / disable the selectability of items
      * @param iSelectable the selectability
      */
-    virtual void setSelectable(bool iSelectable);
+    void setSelectable(bool iSelectable);
 
     /**
      * Enable / disable the shadows
      * @param iShadow the shadows
      */
-    virtual void setShadowVisible(bool iShadow);
+    void setShadowVisible(bool iShadow);
 
     /**
      * Set the graph type
      * @param iType the type of graph
      */
-    virtual void setGraphType(SKGTableWithGraph::GraphType iType);
+    void setGraphType(SKGTableWithGraph::GraphType iType);
 
     /**
      * Set tool bar visibility
      * @param iVisibility the visibility
      */
-    virtual void setFilterVisibility(bool iVisibility) const;
+    void setFilterVisibility(bool iVisibility) const;
 
     /**
      * Set the axis color
      * @param iColor the color
      */
-    virtual void setAxisColor(const QColor& iColor = Qt::gray);
+    void setAxisColor(const QColor& iColor = Qt::gray);
 
     /**
      * Set the grid color
      * @param iColor the color
      */
-    virtual void setGridColor(const QColor& iColor = Qt::lightGray);
+    void setGridColor(const QColor& iColor = Qt::lightGray);
 
     /**
      * Set the min color
      * @param iColor the color
      */
-    virtual void setMinColor(const QColor& iColor = Qt::red);
+    void setMinColor(const QColor& iColor = Qt::red);
 
     /**
      * Set the max color
      * @param iColor the color
      */
-    virtual void setMaxColor(const QColor& iColor = Qt::green);
+    void setMaxColor(const QColor& iColor = Qt::green);
 
     /**
      * Set the pareto color
      * @param iColor the color
      */
-    virtual void setParetoColor(const QColor& iColor = Qt::darkRed);
+    void setParetoColor(const QColor& iColor = Qt::darkRed);
 
     /**
      * Set the average color
      * @param iColor the color
      */
-    virtual void setAverageColor(const QColor& iColor = Qt::blue);
+    void setAverageColor(const QColor& iColor = Qt::blue);
 
     /**
      * Set the tendency color
      * @param iColor the color
      */
-    virtual void setTendencyColor(const QColor& iColor = Qt::darkYellow);
+    void setTendencyColor(const QColor& iColor = Qt::darkYellow);
 
     /**
      * Set the outline color
      * @param iColor the color
      */
-    virtual void setOutlineColor(const QColor& iColor = Qt::black);
+    void setOutlineColor(const QColor& iColor = Qt::black);
 
     /**
      * Set the background color
      * @param iColor the color
      */
-    virtual void setBackgroundColor(const QColor& iColor = Qt::white);
+    void setBackgroundColor(const QColor& iColor = Qt::white);
 
     /**
      * Set the text color
      * @param iColor the color
      */
-    virtual void setTextColor(const QColor& iColor = Qt::black);
+    void setTextColor(const QColor& iColor = Qt::black);
 
     /**
      * Set antialiasing
      * @param iAntialiasing enabled or disabled
      */
-    virtual void setAntialiasing(bool iAntialiasing = true);
+    void setAntialiasing(bool iAntialiasing = true);
 
     /**
      * Redraw the graph after some milliseconds
      */
-    virtual void redrawGraphDelayed();
+    void redrawGraphDelayed();
 
     /**
      * Switch the limits visibility
      * @return the new visibility
      */
-    virtual bool switchLimitsVisibility();
+    bool switchLimitsVisibility();
 
     /**
      * Switch the average visibility
      * @return the new visibility
      */
-    virtual bool switchAverageVisibility();
+    bool switchAverageVisibility();
 
     /**
      * Switch the linear regression visibility
      * @return the new visibility
      */
-    virtual bool switchLinearRegressionVisibility();
+    bool switchLinearRegressionVisibility();
 
     /**
      * Switch the pareto curve visibility
      * @return the new visibility
      */
-    virtual bool switchParetoVisibility();
+    bool switchParetoVisibility();
 
     /**
      * Switch the legend visibility
      * @return the new visibility
      */
-    virtual bool switchLegendVisibility();
+    bool switchLegendVisibility();
 
     /**
      * Switch the origin visibility
      * @return the new visibility
      */
-    virtual bool swithOriginVisibility();
+    bool swithOriginVisibility();
 
     /**
      * Switch the decimals visibility
      * @return the new visibility
      */
-    virtual bool swithDecimalsVisibility();
+    bool swithDecimalsVisibility();
 
     /**
      * Reset the colors
      */
-    virtual void resetColors();
+    void resetColors();
 
     /**
      * Export to a file
@@ -401,7 +401,7 @@ public Q_SLOTS:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError exportInFile(const QString& iFileName);
+    SKGError exportInFile(const QString& iFileName);
 
 Q_SIGNALS:
     /**
@@ -431,18 +431,18 @@ private Q_SLOTS:
     void onFilterModified();
     void onDisplayModeChanged();
     void onChangeColor();
-    void onHorizontalScrollBarChanged(int);
+    void onHorizontalScrollBarChanged(int /*iValue*/);
     void refresh();
     void redrawText();
     void redrawGraph();
-    void showMenu(const QPoint iPos);
+    void showMenu(QPoint iPos);
 
 private:
     Q_DISABLE_COPY(SKGTableWithGraph)
 
     double computeStepSize(double iRange, double iTargetSteps);
-    void addArrow(const QPointF iPeak, double iSize, double iArrowAngle = 45, double iDegree = 90);
-    void addLegend(const QPointF iPosition, double iSize, double iScaleText, double iMaxY);
+    void addArrow(QPointF iPeak, double iSize, double iArrowAngle = 45, double iDegree = 90);
+    void addLegend(QPointF iPosition, double iSize, double iScaleText, double iMaxY);
     QGraphicsItem* drawPoint(qreal iX, qreal iY, qreal iRadius, int iMode, const QBrush& iBrush);
     int getAverageColumnIndex() const;
     int getMinColumnIndex() const;
@@ -450,7 +450,7 @@ private:
     QStringList getSumItems(const QString& iString) const;
     void addSums(SKGStringListList& ioTable, int& iNblines);
 
-    Ui::skgtablewithgraph_base ui;
+    Ui::skgtablewithgraph_base ui{};
     SKGGraphicsScene* m_scene;
 
     SKGStringListList m_data;
@@ -485,14 +485,14 @@ private:
     QAction* m_actShowZero;
     QAction* m_actShowDecimal;
     QAction* m_allPositiveMenu;
-    QWidgetAction* m_displayModeWidget;
+    QWidgetAction* m_displayModeWidget{};
 
     int m_indexSum;
     int m_indexAverage;
     int m_indexMin;
     int m_indexLinearRegression;
     QMap<QString, QColor> m_mapTitleColor;
-    QMap<QTableWidgetItem*, QGraphicsItem*> m_mapItemGraphic;
+    QMap<QTableWidgetItem*, QGraphicsItem*> m_mapItemGraphic{};
 
     QColor m_axisColor;
     QColor m_backgroundColor;
@@ -507,7 +507,7 @@ private:
     QBrush m_NegativeColor;
     QBrush m_WhiteColor;
 
-    SKGComboBox* m_displayMode;
+    SKGComboBox* m_displayMode{};
 
     Qt::SortOrder m_sortOrder;
     int m_sortColumn;
