@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include <qwidget.h>
 #include <qlist.h>
+#include <qwidget.h>
 
 
 
@@ -53,7 +53,7 @@ public:
     /**
      * List of history item
      */
-    typedef QVector<SKGTabPage::SKGPageHistoryItem> SKGPageHistoryItemList;
+    using SKGPageHistoryItemList = QVector<SKGTabPage::SKGPageHistoryItem>;
 
 
     /**
@@ -88,9 +88,9 @@ public:
     /**
      * Overwrite bookmark if page is opened from a bookmark
      * Overwrite context if page is opened from a context
-     * @param iNeedUserConfirmation to display a confirmation panel
+     * @param iUserConfirmation to display a confirmation panel
      */
-    virtual void overwrite(bool iNeedUserConfirmation = true);
+    virtual void overwrite(bool iUserConfirmation = true);
 
     /**
      * Get previous pages
