@@ -24,14 +24,14 @@
 #include <klocalizedstring.h>
 
 #include <qicon.h>
-#include <qtabbar.h>
 #include <qpushbutton.h>
-#include <qtimer.h>
 #include <qstringlist.h>
+#include <qtabbar.h>
+#include <qtimer.h>
 
+#include "skgmainpanel.h"
 #include "skgtabpage.h"
 #include "skgtraces.h"
-#include "skgmainpanel.h"
 
 SKGTabWidget::SKGTabWidget(QWidget* iParent)
     : QTabWidget(iParent)
@@ -39,8 +39,8 @@ SKGTabWidget::SKGTabWidget(QWidget* iParent)
     m_timerSave.setSingleShot(true);
     connect(&m_timerSave, &QTimer::timeout, this, &SKGTabWidget::onRefreshSaveIcon, Qt::QueuedConnection);
     connect(tabBar(), &QTabBar::tabMoved, this, &::SKGTabWidget::onMoveTab);
-    if (iParent) {
-        connect(static_cast<SKGMainPanel*>(iParent), &SKGMainPanel::currentPageChanged, this, &SKGTabWidget::onCurrentChanged);
+    if (iParent != nullptr) {
+        connect(qobject_cast<SKGMainPanel*>(iParent), &SKGMainPanel::currentPageChanged, this, &SKGTabWidget::onCurrentChanged);
     }
 
     // Use new KDE for moving tabs.
@@ -54,7 +54,7 @@ SKGTabWidget::~SKGTabWidget()
 
 void SKGTabWidget::onCurrentChanged()
 {
-    if (currentWidget() && !m_tabIndexSaveButton.contains(currentWidget())) {
+    if ((currentWidget() != nullptr) && !m_tabIndexSaveButton.contains(currentWidget())) {
         // Build widgets
         auto kSave = new QPushButton(this);
         kSave->setIcon(SKGServices::fromTheme(QStringLiteral("document-save")));
@@ -76,7 +76,7 @@ void SKGTabWidget::onCurrentChanged()
     for (int i = 0; i < nb; ++i) {
         QWidget* w = widget(i);
         QPushButton* save = m_tabIndexSaveButton.value(w);
-        if (w && save) {
+        if ((w != nullptr) && (save != nullptr)) {
             save->setVisible(false);
             TabIndexSaveButton2[w] = save;
         }
@@ -104,8 +104,8 @@ void SKGTabWidget::onMoveTab(int oldPos, int newPos)
 
 void SKGTabWidget::onSaveRequested()
 {
-    SKGTabPage* page = qobject_cast<SKGTabPage*>(currentWidget());
-    if (page) {
+    auto* page = qobject_cast<SKGTabPage*>(currentWidget());
+    if (page != nullptr) {
         page->overwrite(false);
         onRefreshSaveIcon();
     }
@@ -113,10 +113,10 @@ void SKGTabWidget::onSaveRequested()
 
 void SKGTabWidget::onRefreshSaveIcon()
 {
-    SKGTabPage* page = qobject_cast<SKGTabPage*>(currentWidget());
-    if (page) {
+    auto* page = qobject_cast<SKGTabPage*>(currentWidget());
+    if (page != nullptr) {
         QPushButton* save = m_tabIndexSaveButton.value(page);
-        if (save) {
+        if (save != nullptr) {
             if (page->isOverwriteNeeded()) {
                 save->show();
                 save->setEnabled(true);
