@@ -54,12 +54,12 @@
 #include "skgmainpanel.h"
 #include "skgobjectbase.h"
 #include "skgobjectmodelbase.h"
+#include "skgpropertyobject.h"
 #include "skgservices.h"
 #include "skgsortfilterproxymodel.h"
 #include "skgtableview.h"
 #include "skgtraces.h"
 #include "skgtransactionmng.h"
-#include "skgpropertyobject.h"
 
 SKGTreeView::SKGTreeView(QWidget* iParent)
     : QTreeView(iParent),
@@ -108,7 +108,7 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     m_actCollapseAll->setProperty("isShortcutConfigurable", false);
     m_actCollapseAll->setShortcutContext(Qt::WidgetShortcut);
     connect(m_actCollapseAll, &QAction::triggered, this, &SKGTreeView::collapseAll);
-    if (SKGMainPanel::getMainPanel()) {
+    if (SKGMainPanel::getMainPanel() != nullptr) {
         SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("edit_copy"), m_actCopy);
         SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("edit_expandall"), m_actExpandAll);
         SKGMainPanel::getMainPanel()->registerGlobalAction(QStringLiteral("edit_collapseall"), m_actCollapseAll);
@@ -132,7 +132,7 @@ SKGTreeView::SKGTreeView(QWidget* iParent)
     connect(this, &SKGTreeView::expanded, this, &SKGTreeView::onExpand);
 
     QWidget* vp = this->viewport();
-    if (vp) {
+    if (vp != nullptr) {
         vp->installEventFilter(this);
         this->installEventFilter(this);
     }
@@ -168,12 +168,12 @@ QString SKGTreeView::getState()
     doc.appendChild(root);
 
     QHeaderView* hHeader = header();
-    if (hHeader && m_model) {
+    if ((hHeader != nullptr) && (m_model != nullptr)) {
         if (isSortingEnabled()) {
             root.setAttribute(QStringLiteral("sortOrder"), SKGServices::intToString(static_cast<int>(hHeader->sortIndicatorOrder())));
             root.setAttribute(QStringLiteral("sortColumn"), m_model->getAttribute(hHeader->sortIndicatorSection()));
 
-            if (m_proxyModel) {
+            if (m_proxyModel != nullptr) {
                 root.setAttribute(QStringLiteral("sortPreviousColumn"), SKGServices::intToString(m_proxyModel->getPreviousSortColumn()));
             }
         }
@@ -181,23 +181,23 @@ QString SKGTreeView::getState()
 
         // Memorize order
         int nb = hHeader->count();
-        if (nb) {
+        if (nb != 0) {
             QString columns;
             QString columnsSize;
             QString columnsVisibility;
             for (int i = 0; i < nb; ++i) {
                 int idx = hHeader->logicalIndex(i);
-                if (i) {
+                if (i != 0) {
                     columns += ';';
                 }
                 columns += m_model->getAttribute(idx);
 
-                if (i) {
+                if (i != 0) {
                     columnsSize += ';';
                 }
                 columnsSize += SKGServices::intToString(hHeader->sectionSize(idx));
 
-                if (i) {
+                if (i != 0) {
                     columnsVisibility += ';';
                 }
                 columnsVisibility += (hHeader->isSectionHidden(idx) ? QStringLiteral("N") : QStringLiteral("Y"));
@@ -219,11 +219,11 @@ QString SKGTreeView::getState()
     root.setAttribute(QStringLiteral("zoomPosition"), SKGServices::intToString(zoomPosition()));
 
     QScrollBar* scroll2 = horizontalScrollBar();
-    if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
+    if ((scroll2 != nullptr) && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
         root.setAttribute(QStringLiteral("stickH"), QStringLiteral("Y"));
     }
     scroll2 = verticalScrollBar();
-    if (scroll2 && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
+    if ((scroll2 != nullptr) && scroll2->value() == scroll2->maximum() && scroll2->value() != scroll2->minimum()) {
         root.setAttribute(QStringLiteral("stickV"), QStringLiteral("Y"));
     }
     return doc.toString(-1);
@@ -237,7 +237,7 @@ void SKGTreeView::setState(const QString& iState)
     QDomDocument doc(QStringLiteral("SKGML"));
 
     QString viewState = iState;
-    if (viewState.isEmpty() && m_document) {
+    if (viewState.isEmpty() && (m_document != nullptr)) {
         // Get default state
         viewState = m_document->getParameter(m_parameterName);
     }
@@ -279,7 +279,7 @@ void SKGTreeView::setState(const QString& iState)
                 }
             }
         }
-        if (m_model) {
+        if (m_model != nullptr) {
             m_model->setSupportedAttributes(listAtt);
         }
 
@@ -294,10 +294,10 @@ void SKGTreeView::setState(const QString& iState)
         }
 
         // Set sort
-        if (m_proxyModel && !sortPreviousColumn.isEmpty()) {
+        if ((m_proxyModel != nullptr) && !sortPreviousColumn.isEmpty()) {
             m_proxyModel->setPreviousSortColumn(SKGServices::stringToInt(sortPreviousColumn));
         }
-        if (m_model && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
+        if ((m_model != nullptr) && isSortingEnabled() && !sortOrder.isEmpty() && !sortColumn.isEmpty()) {
             int index = SKGServices::splitCSVLine(columns, ';').indexOf(sortColumn);
             if (index == -1) {
                 index = m_model->getIndexAttribute(sortColumn);
@@ -309,7 +309,7 @@ void SKGTreeView::setState(const QString& iState)
             this->sortByColumn(index, qtsortorder);
         }
 
-        if (m_model) {
+        if (m_model != nullptr) {
             QString att = m_groupby;
             if (att == QStringLiteral("#")) {
                 att = sortColumn;
@@ -332,7 +332,7 @@ void SKGTreeView::setState(const QString& iState)
         m_expandedNodes = SKGServices::splitCSVLine(expandedGroups);
         resetSelection();
     } else {
-        if (m_model) {
+        if (m_model != nullptr) {
             m_model->setSupportedAttributes(QStringList());
             m_groupby = QLatin1String("");
             m_model->setGroupBy(m_groupby);
@@ -349,10 +349,10 @@ void SKGTreeView::refreshExpandCollapse()
 {
     bool treeMode = !m_model->getParentChildAttribute().isEmpty();
     setRootIsDecorated(treeMode && m_groupby.isEmpty());
-    if (m_actExpandAll) {
+    if (m_actExpandAll != nullptr) {
         m_actExpandAll->setVisible(treeMode || !m_groupby.isEmpty());
     }
-    if (m_actCollapseAll) {
+    if (m_actCollapseAll != nullptr) {
         m_actCollapseAll->setVisible(treeMode || !m_groupby.isEmpty());
     }
 }
@@ -368,7 +368,7 @@ void SKGTreeView::respanFirstColumns()
 
 void SKGTreeView::onRangeChanged()
 {
-    QScrollBar* scroll2 = qobject_cast<QScrollBar*>(sender());
+    auto* scroll2 = qobject_cast<QScrollBar*>(sender());
     if ((stickH && scroll2 == horizontalScrollBar()) || (stickV && scroll2 == verticalScrollBar())) {
         scroll2->setValue(scroll2->maximum());
     }
@@ -376,8 +376,8 @@ void SKGTreeView::onRangeChanged()
 
 void SKGTreeView::onActionTriggered(int action)
 {
-    QScrollBar* scroll2 = qobject_cast<QScrollBar*>(sender());
-    if (scroll2 && action == QAbstractSlider::SliderToMaximum) {
+    auto* scroll2 = qobject_cast<QScrollBar*>(sender());
+    if ((scroll2 != nullptr) && action == QAbstractSlider::SliderToMaximum) {
         if (scroll2 == horizontalScrollBar()) {
             stickH = true;
         }
@@ -400,7 +400,7 @@ void SKGTreeView::insertGlobalAction(const QString& iRegisteredAction)
         auto sep = new QAction(this);
         sep->setSeparator(true);
         this->insertAction(nullptr, sep);
-    } else if (SKGMainPanel::getMainPanel()) {
+    } else if (SKGMainPanel::getMainPanel() != nullptr) {
         QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(iRegisteredAction);
         this->insertAction(nullptr, act);
     }
@@ -423,7 +423,7 @@ void SKGTreeView::resizeColumnsToContents()
     int nb = header()->count();
     for (int i = nb - 1; i >= 0; --i) {
         SKGTRACEIN(10, "SKGTreeView::resizeColumnsToContents-resizeColumnToContents(" + SKGServices::intToString(i) + ')');
-        if (! isColumnHidden(i)) {
+        if (!isColumnHidden(i)) {
             resizeColumnToContents(i);
         }
     }
@@ -436,7 +436,7 @@ void SKGTreeView::showHeaderMenu()
 
 void SKGTreeView::showHeaderMenu(const QPoint iPos)
 {
-    if (m_headerMenu) {
+    if (m_headerMenu != nullptr) {
         m_headerMenu->popup(header()->mapToGlobal(iPos));
     }
 }
@@ -450,12 +450,12 @@ void SKGTreeView::setDefaultSaveParameters(SKGDocument* iDocument, const QString
 void SKGTreeView::setupHeaderMenu()
 {
     SKGTRACEINFUNC(10);
-    if (m_model && m_model->isRefreshBlocked()) {
+    if ((m_model != nullptr) && m_model->isRefreshBlocked()) {
         return;
     }
 
     setCornerWidget(nullptr);
-    if (m_model && m_headerMenu) {
+    if ((m_model != nullptr) && (m_headerMenu != nullptr)) {
         // Corner button on tables to show the contextual menu
         auto btn = new QPushButton(this);
         btn->setIcon(SKGServices::fromTheme(QStringLiteral("configure")));
@@ -475,16 +475,16 @@ void SKGTreeView::setupHeaderMenu()
             groupbymenu = m_headerMenu->addMenu(i18nc("Noun, Menu name", "Group by"));
             groupby = new QActionGroup(groupbymenu);
             m_actGroupByNone = groupbymenu->addAction(i18nc("Noun, grouping option", "None"));
-            if (m_actGroupByNone) {
+            if (m_actGroupByNone != nullptr) {
                 m_actGroupByNone->setIcon(SKGServices::fromTheme(QStringLiteral("dialog-cancel")));
                 m_actGroupByNone->setCheckable(true);
                 m_actGroupByNone->setChecked(m_groupby.isEmpty());
                 m_actGroupByNone->setData(QLatin1String(""));
                 groupby->addAction(m_actGroupByNone);
             }
-            if (m_proxyModel) {
+            if (m_proxyModel != nullptr) {
                 QAction* actSort = groupbymenu->addAction(i18nc("Noun, grouping option", "Sorted column"));
-                if (actSort) {
+                if (actSort != nullptr) {
                     actSort->setIcon(SKGServices::fromTheme(QStringLiteral("view-sort-ascending")));
                     actSort->setCheckable(true);
                     actSort->setChecked(m_groupby == QStringLiteral("#"));
@@ -498,7 +498,7 @@ void SKGTreeView::setupHeaderMenu()
         // Set right click menu
         SKGDocument::SKGModelTemplateList schemas = m_model->getSchemas();
         int nbSchemas = schemas.count();
-        if (nbSchemas) {
+        if (nbSchemas != 0) {
             QMenu* viewAppearanceMenu = columns->addMenu(SKGServices::fromTheme(QStringLiteral("view-file-columns")), i18nc("Noun, user action", "View appearance"));
 
             for (int i = 0; i < nbSchemas; ++i) {
@@ -522,20 +522,20 @@ void SKGTreeView::setupHeaderMenu()
         connect(m_actAutoResize, &QAction::triggered, this, &SKGTreeView::switchAutoResize);
 
         QAction* actAlternatingRowColors = m_headerMenu->addAction(i18nc("Noun, user action", "Alternate row colors"));
-        if (actAlternatingRowColors) {
+        if (actAlternatingRowColors != nullptr) {
             actAlternatingRowColors->setCheckable(true);
             actAlternatingRowColors->setChecked(alternatingRowColors());
             connect(actAlternatingRowColors, &QAction::triggered, this, &SKGTreeView::setAlternatingRowColors);
         }
 
-        if (m_document) {
+        if (m_document != nullptr) {
             QAction* actDefault = m_headerMenu->addAction(SKGServices::fromTheme(QStringLiteral("document-save")), i18nc("Noun, user action", "Save parameters"));
             connect(actDefault, &QAction::triggered, this, &SKGTreeView::saveDefaultClicked);
         }
 
         columns->addSeparator();
 
-        if (m_model) {
+        if (m_model != nullptr) {
             // Build menus for columns
             QHeaderView* hHeader = header();
             int nbcol = hHeader->count();
@@ -558,7 +558,7 @@ void SKGTreeView::setupHeaderMenu()
 
                 // Column menu
                 QAction* act = columns->addAction(values.at(0));
-                if (act) {
+                if (act != nullptr) {
                     act->setCheckable(true);
                     act->setChecked(!hHeader->isSectionHidden(idx));
                     act->setIcon(m_model->headerData(idx, Qt::Horizontal, Qt::DecorationRole).value<QIcon>());
@@ -569,9 +569,9 @@ void SKGTreeView::setupHeaderMenu()
 
                     // Group by menu
                     QString att = m_model->getAttribute(idx);
-                    if (groupbymenu && groupby) {
+                    if ((groupbymenu != nullptr) && (groupby != nullptr)) {
                         QAction* act2 = groupbymenu->addAction(values.at(0));
-                        if (act2) {
+                        if (act2 != nullptr) {
                             act2->setCheckable(true);
                             act2->setChecked(att == m_groupby);
                             act2->setIcon(act->icon());
@@ -583,7 +583,7 @@ void SKGTreeView::setupHeaderMenu()
             }
             m_autoResizeDone = true;
         }
-        if (groupby) {
+        if (groupby != nullptr) {
             connect(groupby, &QActionGroup::triggered, this, &SKGTreeView::groupByChanged);
         }
         m_headerMenu->addSeparator();
@@ -599,11 +599,11 @@ void SKGTreeView::setupHeaderMenu()
 
 void SKGTreeView::setSelectionModel(QItemSelectionModel* iSelectionModel)
 {
-    if (this->selectionModel()) {
+    if (this->selectionModel() != nullptr) {
         disconnect(this->selectionModel(), &QItemSelectionModel::selectionChanged, this, &SKGTreeView::onSelectionChanged);
     }
     QTreeView::setSelectionModel(iSelectionModel);
-    if (iSelectionModel) {
+    if (iSelectionModel != nullptr) {
         connect(iSelectionModel, &QItemSelectionModel::selectionChanged, this, &SKGTreeView::onSelectionChanged);
     }
 }
@@ -614,15 +614,15 @@ void SKGTreeView::onSelectionChanged()
     SKGObjectBase::SKGListSKGObjectBase selection;
     SKGObjectBase::SKGListSKGObjectBase selectionparents;
     QItemSelectionModel* selModel = selectionModel();
-    if (selModel) {
-        if (m_model) {
+    if (selModel != nullptr) {
+        if (m_model != nullptr) {
             auto indexes = selModel->selectedRows();
 
             int nb = indexes.count();
             QVector<QModelIndex> indexesToSource;
             indexesToSource.reserve(indexes.count());
             for (const auto& index : qAsConst(indexes)) {
-                indexesToSource.push_back(m_proxyModel ? m_proxyModel->mapToSource(index) : index);
+                indexesToSource.push_back(m_proxyModel != nullptr ? m_proxyModel->mapToSource(index) : index);
             }
 
             selection.reserve(indexesToSource.count());
@@ -632,13 +632,13 @@ void SKGTreeView::onSelectionChanged()
                 QModelIndex idxs = indexesToSource.at(i);
 
                 // Get above
-                QModelIndex idxtmp = (m_proxyModel ? m_proxyModel->mapToSource(indexAbove(index)) : indexAbove(index));
+                QModelIndex idxtmp = (m_proxyModel != nullptr ? m_proxyModel->mapToSource(indexAbove(index)) : indexAbove(index));
                 auto* tmp = m_model->getObjectPointer(idxtmp);
                 if (tmp != nullptr && idxtmp.parent() == idxs.parent() && !indexesToSource.contains(idxtmp)) {
                     selectionparents.push_back(*tmp);
                 } else {
                     // Get below
-                    idxtmp = (m_proxyModel ? m_proxyModel->mapToSource(indexBelow(index)) : indexBelow(index));
+                    idxtmp = (m_proxyModel != nullptr ? m_proxyModel->mapToSource(indexBelow(index)) : indexBelow(index));
                     tmp = m_model->getObjectPointer(idxtmp);
                     if (tmp != nullptr && idxtmp.parent() == idxs.parent() && !indexesToSource.contains(idxtmp)) {
                         selectionparents.push_back(*tmp);
@@ -666,7 +666,7 @@ void SKGTreeView::onSelectionChanged()
 
 void SKGTreeView::saveDefaultClicked()
 {
-    if (m_document) {
+    if (m_document != nullptr) {
         SKGError err;
         SKGBEGINTRANSACTION(*m_document, i18nc("Noun, name of the user action", "Save default parameters"), err);
         err = m_document->setParameter(m_parameterName, getState());
@@ -687,14 +687,14 @@ void SKGTreeView::switchAutoResize()
 
 void SKGTreeView::groupByChanged(QAction* iAction)
 {
-    if (m_model && m_model->isRefreshBlocked()) {
+    if ((m_model != nullptr) && m_model->isRefreshBlocked()) {
         return;
     }
 
-    if (iAction && m_model) {
-        m_groupby = iAction->data().toString();;
+    if ((iAction != nullptr) && (m_model != nullptr)) {
+        m_groupby = iAction->data().toString();
         QString att = m_groupby;
-        if (att == QStringLiteral("#") && m_proxyModel) {
+        if (att == QStringLiteral("#") && (m_proxyModel != nullptr)) {
             att = m_model->getAttribute(m_proxyModel->sortColumn());
         }
         m_model->setGroupBy(att);
@@ -708,7 +708,7 @@ void SKGTreeView::groupByChanged(QAction* iAction)
 void SKGTreeView::onSortChanged(int iIndex, Qt::SortOrder iOrder)
 {
     Q_UNUSED(iOrder);
-    if (m_groupby == QStringLiteral("#") && m_model) {
+    if (m_groupby == QStringLiteral("#") && (m_model != nullptr)) {
         m_model->setGroupBy(m_model->getAttribute(iIndex));
         m_model->refresh();
     }
@@ -718,8 +718,8 @@ void SKGTreeView::onSortChanged(int iIndex, Qt::SortOrder iOrder)
 
 void SKGTreeView::showHideColumn()
 {
-    QAction* send = static_cast<QAction*>(this->sender());
-    if (send) {
+    auto* send = qobject_cast<QAction*>(this->sender());
+    if (send != nullptr) {
         QHeaderView* hHeader = header();
 
         int idx = send->data().toInt();
@@ -744,12 +744,12 @@ void SKGTreeView::changeSchema()
 {
     QStringList list;
 
-    QAction* send = static_cast<QAction*>(this->sender());
-    if (send) {
+    auto* send = qobject_cast<QAction*>(this->sender());
+    if (send != nullptr) {
         list = SKGServices::splitCSVLine(send->data().toString(), ';');
     }
 
-    if (m_model) {
+    if (m_model != nullptr) {
         // Reset column oder
         resetColumnsOrder();
 
@@ -766,9 +766,9 @@ QStringList SKGTreeView::getCurrentSchema() const
 {
     QStringList list;
     QHeaderView* hHeader = header();
-    if (hHeader && m_model) {
+    if ((hHeader != nullptr) && (m_model != nullptr)) {
         int nb = hHeader->count();
-        if (nb) {
+        if (nb != 0) {
             QString att;
             for (int i = 0; i < nb; ++i) {
                 int idx = hHeader->logicalIndex(i);
@@ -834,12 +834,12 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
     SKGTRACEL(10) << iUniqueIDs.count() << " objects to select" << endl;
     int nbset = 0;
     QItemSelectionModel* selModel = selectionModel();
-    if (selModel) {
+    if (selModel != nullptr) {
         bool previous = selModel->blockSignals(true);
 
         selModel->clearSelection();
 
-        if (m_model) {
+        if (m_model != nullptr) {
             // Get all indexes
             QVector<QModelIndex> items;
             items.reserve(items.count() * 2);
@@ -854,14 +854,14 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
             items.removeAt(0);
 
             int nbRows = items.count();
-            if (nbRows) {
+            if (nbRows != 0) {
                 // Expand nodes
                 bool previousForThis = this->blockSignals(true);
                 for (int i = 0; i < nbRows; ++i) {
                     QModelIndex index = items.at(i);
                     SKGObjectBase obj = m_model->getObject(index);
                     if (m_expandedNodes.contains(obj.getUniqueID())) {
-                        QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapFromSource(index) : index);
+                        QModelIndex idxs = (m_proxyModel != nullptr ? m_proxyModel->mapFromSource(index) : index);
                         setExpanded(idxs, true);
                     }
                 }
@@ -873,7 +873,7 @@ void SKGTreeView::selectObjects(const QStringList& iUniqueIDs, bool iFocusOnFirs
                     QModelIndex index = items.at(i);
                     SKGObjectBase obj = m_model->getObject(index);
                     if (iUniqueIDs.contains(obj.getUniqueID())) {
-                        QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapFromSource(index) : index);
+                        QModelIndex idxs = (m_proxyModel != nullptr ? m_proxyModel->mapFromSource(index) : index);
                         selModel->select(idxs, QItemSelectionModel::Select | QItemSelectionModel::Rows);
                         selModel->setCurrentIndex(idxs, QItemSelectionModel::NoUpdate);
                         ++nbset;
@@ -899,7 +899,7 @@ void SKGTreeView::resetSelection()
 
     auto lastSelection_parents_save = m_lastSelection_if_deleted;  // because selectObjects will modify m_lastSelection_if_deleted
     selectObjects(m_selection);
-    if (lastSelection_parents_save.count() && !getSelectedObjects().count()) {
+    if ((lastSelection_parents_save.count() != 0) && (getSelectedObjects().count() == 0)) {
         // Try to select parent objects
         int nb = lastSelection_parents_save.count();
         // We save the selection only if not too big
@@ -919,8 +919,8 @@ void SKGTreeView::resetSelection()
 void SKGTreeView::scroolOnSelection()
 {
     QItemSelectionModel* selModel = selectionModel();
-    if (selModel) {
-        if (m_model) {
+    if (selModel != nullptr) {
+        if (m_model != nullptr) {
             QModelIndexList indexes = selModel->selectedRows();
             if (!indexes.isEmpty()) {
                 scrollTo(indexes.at(0));
@@ -932,8 +932,8 @@ void SKGTreeView::scroolOnSelection()
 void SKGTreeView::onExpand(const QModelIndex& index)
 {
     SKGTRACEINFUNC(10);
-    if (index.isValid() && m_model) {
-        QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapToSource(index) : index);
+    if (index.isValid() && (m_model != nullptr)) {
+        QModelIndex idxs = (m_proxyModel != nullptr ? m_proxyModel->mapToSource(index) : index);
 
         SKGObjectBase obj = m_model->getObject(idxs);
         QString id = obj.getUniqueID();
@@ -958,8 +958,8 @@ void SKGTreeView::expandAll()
 void SKGTreeView::onCollapse(const QModelIndex& index)
 {
     SKGTRACEINFUNC(10);
-    if (index.isValid() && m_model) {
-        QModelIndex idxs = (m_proxyModel ? m_proxyModel->mapToSource(index) : index);
+    if (index.isValid() && (m_model != nullptr)) {
+        QModelIndex idxs = (m_proxyModel != nullptr ? m_proxyModel->mapToSource(index) : index);
 
         SKGObjectBase obj = m_model->getObject(idxs);
 
@@ -975,7 +975,7 @@ void SKGTreeView::onCollapse(const QModelIndex& index)
 void SKGTreeView::onClick(const QModelIndex& index)
 {
     SKGTRACEINFUNC(10);
-    if (index.isValid() && m_actExpandAll && m_actExpandAll->isVisible()) {
+    if (index.isValid() && (m_actExpandAll != nullptr) && m_actExpandAll->isVisible()) {
         this->setExpanded(index, !this->isExpanded(index));
     }
 }
@@ -983,10 +983,10 @@ void SKGTreeView::onClick(const QModelIndex& index)
 void SKGTreeView::copy()
 {
     QItemSelectionModel* selection = selectionModel();
-    if (selection) {
+    if (selection != nullptr) {
         QModelIndexList indexes = selection->selectedIndexes();
 
-        if (indexes.size() < 1) {
+        if (indexes.empty()) {
             return;
         }
 
@@ -1002,7 +1002,6 @@ void SKGTreeView::copy()
         SKGStringListList columns_values;
         int index = 0;
         for (const auto& current : qAsConst(indexes)) {
-
             if (columns_values.count() < index + 1) {
                 columns_values.append(QStringList());
                 columns_values.append(QStringList());
@@ -1074,7 +1073,7 @@ void SKGTreeView::copy()
         if (nbCols > 0) {
             for (int r = 0; r < nbRows; ++r) {
                 for (int c = 0; c < nbCols; ++c) {
-                    if (c) {
+                    if (c != 0) {
                         text += QLatin1Char(';');
                     }
                     text += columns_values.at(c).at(r);
@@ -1084,7 +1083,7 @@ void SKGTreeView::copy()
         }
 
         auto clipBoard = QApplication::clipboard();
-        if (clipBoard) {
+        if (clipBoard != nullptr) {
             clipBoard->setText(text);
         }
     }
@@ -1115,11 +1114,11 @@ int SKGTreeView::zoomPosition()
     return this->font().pointSize() - m_fontOriginalPointSize;
 }
 
-bool SKGTreeView::eventFilter(QObject* object, QEvent* iEvent)
+bool SKGTreeView::eventFilter(QObject* iObject, QEvent* iEvent)
 {
-    if (object == this && iEvent != nullptr && iEvent->type() == QEvent::Wheel) {
-        QWheelEvent* e = static_cast<QWheelEvent*>(iEvent);
-        if (m_textResizable && e && e->orientation() == Qt::Vertical && QApplication::keyboardModifiers() &Qt::ControlModifier) {
+    if (iObject == this && iEvent != nullptr && iEvent->type() == QEvent::Wheel) {
+        auto* e = dynamic_cast<QWheelEvent*>(iEvent);
+        if (m_textResizable && (e != nullptr) && e->orientation() == Qt::Vertical && ((QApplication::keyboardModifiers() &Qt::ControlModifier) != 0u)) {
             int numDegrees = e->delta() / 8;
             int numTicks = numDegrees / 15;
 
@@ -1128,31 +1127,31 @@ bool SKGTreeView::eventFilter(QObject* object, QEvent* iEvent)
             return true;
         }
     }
-    if (object == this && iEvent != nullptr && iEvent->type() == QEvent::KeyPress) {
-        QKeyEvent* kevent = static_cast<QKeyEvent*>(iEvent);
-        if (kevent) {
+    if (iObject == this && iEvent != nullptr && iEvent->type() == QEvent::KeyPress) {
+        auto* kevent = dynamic_cast<QKeyEvent*>(iEvent);
+        if (kevent != nullptr) {
             if (kevent->matches(QKeySequence::Copy) && this->state() != QAbstractItemView::EditingState) {
                 copy();
-                if (iEvent) {
+                if (iEvent != nullptr) {
                     iEvent->accept();
                 }
                 return true;  // stop the process
             }
         }
     }
-    return QTreeView::eventFilter(object, iEvent);
+    return QTreeView::eventFilter(iObject, iEvent);
 }
 
 void SKGTreeView::mousePressEvent(QMouseEvent* iEvent)
 {
-    if (iEvent && iEvent->button() == Qt::LeftButton && !(this->indexAt(iEvent->pos()).isValid())) {
+    if ((iEvent != nullptr) && iEvent->button() == Qt::LeftButton && !(this->indexAt(iEvent->pos()).isValid())) {
         Q_EMIT clickEmptyArea();
         clearSelection();
     }
 
-    if (iEvent && iEvent->button() == Qt::LeftButton && m_proxyModel && m_model) {
+    if ((iEvent != nullptr) && iEvent->button() == Qt::LeftButton && (m_proxyModel != nullptr) && (m_model != nullptr)) {
         int propertyUUID = m_proxyModel->data(indexAt(iEvent->pos()), 101).toInt();
-        if (propertyUUID) {
+        if (propertyUUID != 0) {
             SKGPropertyObject prop(m_model->getDocument(), propertyUUID);
             QDesktopServices::openUrl(prop.getUrl(true));
         }
@@ -1212,7 +1211,7 @@ QTextBrowser* SKGTreeView::getTextBrowser() const
 
     // Create header
     for (int r = 0; r < nbRows; ++r) {
-        QStringList line = table.at(r);
+        const QStringList& line = table.at(r);
         for (int c = 0 ; c < nbCol ; ++c) {
             QTextCursor cellCursor = tableau->cellAt(r, c).firstCursorPosition();
             cellCursor.insertText(line.at(c), (r == 0 ? headerFormat : textFormat));
@@ -1231,7 +1230,7 @@ SKGStringListList SKGTreeView::getTable(const QModelIndex& iIndex) const
     SKGStringListList table;
 
     // Get header names
-    if (m_model) {
+    if (m_model != nullptr) {
         // Header
         int nb = m_model->columnCount();
         int nb2 = m_model->rowCount(iIndex);
@@ -1336,7 +1335,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
             QTextStream out(&file);
             out.setCodec(codec.toLatin1().constData());
             QTextBrowser* tb = getTextBrowser();
-            if (tb) {
+            if (tb != nullptr) {
                 out << tb->toHtml().replace(QStringLiteral("<meta name=\"qrichtext\" content=\"1\" />"), QStringLiteral("<meta http-equiv=\"content-type\" content=\"text/html; charset=utf-8\" />")) << endl;
 
                 delete tb;
@@ -1347,7 +1346,7 @@ SKGError SKGTreeView::exportInFile(const QString& iFileName)
         }
     } else if (extension == QStringLiteral("ODT")) {
         QTextBrowser* tb = getTextBrowser();
-        if (tb) {
+        if (tb != nullptr) {
             QTextDocument doc;
             doc.setHtml(tb->toHtml());
 
@@ -1392,15 +1391,15 @@ void SKGTreeView::onExport()
 void SKGTreeView::setModel(QAbstractItemModel* iModel)
 {
     if (iModel != this->model()) {
-        m_model = static_cast<SKGObjectModelBase*>(iModel);
+        m_model = qobject_cast<SKGObjectModelBase*>(iModel);
         m_proxyModel = qobject_cast<SKGSortFilterProxyModel*> (iModel);
-        if (m_proxyModel) {
-            m_model = static_cast<SKGObjectModelBase*>(m_proxyModel->sourceModel());
+        if (m_proxyModel != nullptr) {
+            m_model = qobject_cast<SKGObjectModelBase*>(m_proxyModel->sourceModel());
         }
 
-        if (m_model) {
+        if (m_model != nullptr) {
             connect(m_model, &SKGObjectModelBase::afterReset, this, &SKGTreeView::setupHeaderMenu);
-            //connect(m_model, &SKGObjectModelBase::afterReset, this, &SKGTreeView::onSelectionChanged);
+            // connect(m_model, &SKGObjectModelBase::afterReset, this, &SKGTreeView::onSelectionChanged);
             connect(m_model, &SKGObjectModelBase::afterReset, this, &SKGTreeView::respanFirstColumns, Qt::QueuedConnection);
         }
         QTreeView::setModel(iModel);
@@ -1429,7 +1428,7 @@ void SKGTreeView::rebuildContextualMenu()
         this->insertAction(nullptr, m_actExpandAll);
         this->insertAction(nullptr, m_actCollapseAll);
 
-        if (m_model && SKGMainPanel::getMainPanel()) {
+        if ((m_model != nullptr) && (SKGMainPanel::getMainPanel() != nullptr)) {
             const auto list = SKGMainPanel::getMainPanel()->getActionsForContextualMenu(m_model->getRealTable());
             for (const auto& act : list) {
                 if (act == nullptr) {
