@@ -21,15 +21,15 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
+#include <qmenu.h>
 #include <qstringlist.h>
 #include <qtreeview.h>
-#include <qmenu.h>
 
-#include "skgtraces.h"
-#include "skgservices.h"
-#include "skgobjectbase.h"
 #include "skgbasegui_export.h"
 #include "skgmainpanel.h"
+#include "skgobjectbase.h"
+#include "skgservices.h"
+#include "skgtraces.h"
 
 class SKGObjectModelBase;
 class SKGDocument;
@@ -304,15 +304,15 @@ private Q_SLOTS:
     void onExport();
     void setupHeaderMenu();
     void showHeaderMenu();
-    void showHeaderMenu(const QPoint iPos);
+    void showHeaderMenu(QPoint iPos);
     void showHideColumn();
     void respanFirstColumns();
     void refreshExpandCollapse();
     void changeSchema();
     void saveDefaultClicked();
-    void groupByChanged(QAction*);
+    void groupByChanged(QAction* /*iAction*/);
 
-    void onSortChanged(int, Qt::SortOrder);
+    void onSortChanged(int /*iIndex*/, Qt::SortOrder /*iOrder*/);
 
     void onExpand(const QModelIndex& index);
     void onCollapse(const QModelIndex& index);
