@@ -61,7 +61,7 @@ void SKGWidgetSelector::addButton(const QIcon& iIcon, const QString& iTitle, con
     // Hide widgets
     SKGWidgetSelector::SKGListQWidget list;
     for (auto w : qAsConst(iListOfShownWidgets)) {
-        if (w) {
+        if (w != nullptr) {
             // Addition of an intermediate widget
             /*auto widget = new QWidget(w->parentWidget());
                 widget->setObjectName(w->objectName()+"_intermediate");
@@ -93,7 +93,7 @@ void SKGWidgetSelector::setSelectedMode(int iMode)
             SKGListQWidget list = m_listWidgets.at(m_currentMode);
 
             for (auto w : qAsConst(list)) {
-                if (w) {
+                if (w != nullptr) {
                     /*if (iMode == -1) {
                         auto anim1 = new QPropertyAnimation(w, "geometry");
                     QRect r=w->geometry();
@@ -124,7 +124,7 @@ void SKGWidgetSelector::setSelectedMode(int iMode)
         if (m_currentMode >= 0) {
             m_listButton.at(m_currentMode)->setChecked(true);
             for (auto w : qAsConst(m_listWidgets.at(m_currentMode))) {
-                if (w) {
+                if (w != nullptr) {
                     w->show();
                     /*if (previousmode == -1) {
                         auto anim1 = new QPropertyAnimation(w, "geometry");
@@ -155,7 +155,7 @@ void SKGWidgetSelector::setEnabledMode(int iMode, bool iEnabled)
 
 void SKGWidgetSelector::onButtonClicked()
 {
-    QToolButton* clickedButton = qobject_cast<QToolButton*>(sender());
+    auto* clickedButton = qobject_cast<QToolButton*>(sender());
     int newMode = m_listButton.indexOf(clickedButton);
     if (m_currentMode == newMode) {
         if (getAlwaysOneOpen()) {
