@@ -49,7 +49,7 @@ void SKGZoomSelector::setValue(int iValue, bool iEmitEvent)
 {
     bool previous = ui.kZoomSlider->blockSignals(!iEmitEvent);
     ui.kZoomSlider->setValue(iValue);
-    if (ui.kZoomOriginal) {
+    if (ui.kZoomOriginal != nullptr) {
         ui.kZoomOriginal->setChecked(iValue == m_resetValue);
     }
     ui.kZoomSlider->blockSignals(previous);
@@ -93,13 +93,13 @@ void SKGZoomSelector::onZoomChangedDelayed()
 void SKGZoomSelector::onZoomChanged()
 {
     int val = ui.kZoomSlider->value();
-    if (ui.kZoomIn) {
+    if (ui.kZoomIn != nullptr) {
         ui.kZoomIn->setEnabled(val < 10);
     }
-    if (ui.kZoomOut) {
+    if (ui.kZoomOut != nullptr) {
         ui.kZoomOut->setEnabled(val > -10);
     }
-    if (ui.kZoomOriginal) {
+    if (ui.kZoomOriginal != nullptr) {
         ui.kZoomOriginal->setChecked(val == m_resetValue);
     }
 
