@@ -22,13 +22,13 @@
 #include "skgadvice.h"
 #include "skgdefine.h"
 
-SKGAdvice::SKGAdvice() : QObject(), m_priority(1)
+SKGAdvice::SKGAdvice() :  QObject()
 {}
 
 SKGAdvice::SKGAdvice(const SKGAdvice& iAdvice)
-    : QObject(), m_uuid(iAdvice.m_uuid), m_priority(iAdvice.m_priority),
-      m_shortMessage(iAdvice.m_shortMessage), m_longMessage(iAdvice.m_longMessage),
-      m_autoCorrections(iAdvice.m_autoCorrections)
+    :  QObject(), m_uuid(iAdvice.m_uuid), m_priority(iAdvice.m_priority),
+       m_shortMessage(iAdvice.m_shortMessage), m_longMessage(iAdvice.m_longMessage),
+       m_autoCorrections(iAdvice.m_autoCorrections)
 
 {}
 
