@@ -21,11 +21,11 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include <qstring.h>
-#include <qobject.h>
-#include <qvector.h>
-#include <qstringlist.h>
 #include <qmetatype.h>
+#include <qobject.h>
+#include <qstring.h>
+#include <qstringlist.h>
+#include <qvector.h>
 
 #include "skgbasemodeler_export.h"
 
@@ -50,13 +50,13 @@ public:
         QString IconName;
 
         /** To know if this action is recommended*/
-        bool IsRecommended;
+        bool IsRecommended{};
     };
 
     /**
      * List of advice action
      */
-    typedef QVector<SKGAdvice::SKGAdviceAction> SKGAdviceActionList;
+    using SKGAdviceActionList = QVector<SKGAdvice::SKGAdviceAction>;
 
     /**
      * Priotity
@@ -184,7 +184,7 @@ private:
     /**
     * the priority
     */
-    int m_priority;
+    int m_priority{1};
 
     /**
      * the short message
@@ -214,7 +214,7 @@ Q_DECLARE_TYPEINFO(SKGAdvice, Q_MOVABLE_TYPE);
 /**
  * the SKGAdviceList
  */
-typedef QVector<SKGAdvice> SKGAdviceList;
+using SKGAdviceList = QVector<SKGAdvice>;
 
 /**
  * Declare the meta type
