@@ -29,16 +29,6 @@
 #include "skgbasemodeler_export.h"
 
 
-template <typename T> struct QAddConst {
-    typedef const T Type;
-};
-
-#if QT_VERSION < 0x050700
-// this adds const to non-const objects (like std::as_const)
-template <typename T>
-Q_DECL_CONSTEXPR typename QAddConst<T>::Type& qAsConst(T& t) Q_DECL_NOTHROW { return t; }
-#endif
-
 /**
  * @var OBJECTSEPARATOR
  * Define the separator between object and subobject
