@@ -103,7 +103,7 @@ SKGError SKGDocument::refreshViewsIndexesAndTriggers(bool iForce) const
         err = this->getDistinctValues(QStringLiteral("sqlite_master"), QStringLiteral("name"), QStringLiteral("type='table'"), dbTables);
         int nb = dbTables.count();
         for (int i = 0; !err && i < nb; ++i) {
-            QString table = dbTables.at(i);
+            const QString& table = dbTables.at(i);
             SKGStringListList attributes;
             err = executeSelectSqliteOrder("PRAGMA table_info(" % table % ");", attributes);
             int nb2 = attributes.count();
