@@ -22,11 +22,11 @@
 #include "skgerror.h"
 
 SKGError::SKGError()
-    : QObject(), m_rc(0), m_message(QLatin1String("")), m_previousError(nullptr)
+    : QObject(), m_message(QLatin1String(""))
 {}
 
-SKGError::SKGError(int iRc, const QString& iMessage, const QString& iAction)
-    : QObject(), m_rc(iRc), m_message(iMessage), m_action(iAction), m_previousError(nullptr)
+SKGError::SKGError(int iRc, QString  iMessage, QString  iAction)
+    : QObject(), m_rc(iRc), m_message(std::move(iMessage)), m_action(std::move(iAction)), m_previousError(nullptr)
 {}
 
 SKGError::SKGError(const SKGError& iError)
