@@ -22,9 +22,9 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgobjectbase.h"
-#include "skgerror.h"
 #include "skgdefine.h"
+#include "skgerror.h"
+#include "skgobjectbase.h"
 
 /**
  * This class is a named object base.
@@ -82,7 +82,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGNamedObject& operator= (const SKGObjectBase& iObject) override;
+    SKGNamedObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
