@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include "skgnamedobject.h"
 #include "skgdefine.h"
+#include "skgnamedobject.h"
 
 class SKGDocument;
 /**
@@ -69,7 +69,7 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    const SKGPropertyObject& operator= (const SKGObjectBase& iObject) override;
+    SKGPropertyObject& operator= (const SKGObjectBase& iObject);
 
     /**
      * Destructor
