@@ -226,6 +226,11 @@ void SKGReport::cleanCache(bool iEmitSignal)
     }
 }
 
+void SKGReport::addParameter(const QString& iName, const QVariant& ivalue)
+{
+    m_parameters[iName] = ivalue;
+}
+
 void SKGReport::setPointSize(int iPointSize)
 {
     m_pointSize = iPointSize;
