@@ -23,14 +23,14 @@
  */
 #include <qurl.h>
 
-#include <qstringlist.h>
-#include <qhash.h>
 #include <qdatetime.h>
+#include <qhash.h>
 #include <qicon.h>
+#include <qstringlist.h>
 
-#include "skgerror.h"
-#include "skgdefine.h"
 #include "skgbasemodeler_export.h"
+#include "skgdefine.h"
+#include "skgerror.h"
 
 /**
  * @var SQLLITEERROR
@@ -53,17 +53,17 @@ class SKGDocument;
 /**
  * A map of strings ==> SKGQStringQStringMap
  */
-typedef QHash<QString, QString> SKGQStringQStringMap;
+using SKGQStringQStringMap = QHash<QString, QString>;
 
 /**
  * A list of QStringList ==> SKGStringListList
  */
-typedef QList<QStringList> SKGStringListList;
+using SKGStringListList = QList<QStringList>;
 
 /**
  * A list of int ==> SKGIntList
  */
-typedef QList<int> SKGIntList;
+using SKGIntList = QList<int>;
 
 /**
 * This class containing various static services
@@ -128,7 +128,7 @@ public:
         QString display;        /**< The name for display of the attribute */
         QIcon icon;                 /**< The icon for display of the attribute */
         AttributeType type;         /**< The type of the attribute */
-        bool notnull;           /**< To know if the attribute can be null or not */
+        bool notnull{};           /**< To know if the attribute can be null or not */
         QString defaultvalue;       /**< The default value of the attribute */
     };
 
@@ -143,12 +143,12 @@ public:
     /**
      * A list of SKGSearchCriteria ==> SKGAttributesList
      */
-    typedef QVector<SKGSearchCriteria> SKGSearchCriteriaList;
+    using SKGSearchCriteriaList = QVector<SKGSearchCriteria>;
 
     /**
      * A list of SKGAttributeInfo ==> SKGAttributesList
      */
-    typedef QVector<SKGAttributeInfo> SKGAttributesList;
+    using SKGAttributesList = QVector<SKGAttributeInfo>;
 
     /**
      * This enumerate defines dump modes
@@ -217,7 +217,7 @@ public:
      * @param iSeparator the separator
      * @return the converted csv string
      */
-    static QString stringsToCsv(const QStringList& iList, const QChar iSeparator = QLatin1Char(';'));
+    static QString stringsToCsv(const QStringList& iList, QChar iSeparator = QLatin1Char(';'));
 
     /**
      * Convert a QString to a html QString
@@ -268,7 +268,7 @@ public:
      * @return the period string
      */
     // cppcheck-suppress passedByValue
-    static QString dateToPeriod(const QDate iDate, const QString& iPeriod);
+    static QString dateToPeriod(QDate iDate, const QString& iPeriod);
 
     /**
      * Compute the number of working days between two dates.
@@ -277,7 +277,7 @@ public:
      * @return the number of working days.
      */
     // cppcheck-suppress passedByValue
-    static int nbWorkingDays(const QDate iFrom, const QDate iTo);
+    static int nbWorkingDays(QDate iFrom, QDate iTo);
 
     /**
      * Convert a QString to QDateTime.
@@ -309,7 +309,7 @@ public:
      * @return the converted QString
      */
     // cppcheck-suppress passedByValue
-    static QString dateToSqlString(const QDate iDate);
+    static QString dateToSqlString(QDate iDate);
 
     /**
      * Format a date.
@@ -387,7 +387,7 @@ public:
      * @param oRealSeparator the real csv separator. If the csv string is strictly all enclosed then oRealSeparator will contain the real separator. Can be nullptr
      * @return the list of all values in this csv line. Return an empty list if some cote are opened and not closed
      */
-    static QStringList splitCSVLine(const QString& iString, const QChar iSeparator, bool iCoteDefineBlock, QChar* oRealSeparator);
+    static QStringList splitCSVLine(const QString& iString, QChar iSeparator, bool iCoteDefineBlock, QChar* oRealSeparator);
 
     /**
      * Split a csv line
@@ -396,7 +396,7 @@ public:
      * @param iCoteDefineBlock to indicate if the character double cote define a block
      * @return the list of all values in this csv line. Return an empty list if some cote are opened and not closed
      */
-    static QStringList splitCSVLine(const QString& iString, const QChar iSeparator = QLatin1Char(';'), bool iCoteDefineBlock = true);
+    static QStringList splitCSVLine(const QString& iString, QChar iSeparator = QLatin1Char(';'), bool iCoteDefineBlock = true);
 
     /**
      * To dump a table
