@@ -42,7 +42,7 @@
 
 // ===================================================================
 int SKGTraces::SKGLevelTrace = SKGServices::stringToInt(SKGServices::getEnvVariable(QStringLiteral("SKGTRACE")));
-bool SKGTraces::SKGPerfo = (!SKGServices::getEnvVariable(QStringLiteral("SKGTRACEPERFO")).isEmpty() ? true : false);
+bool SKGTraces::SKGPerfo = !SKGServices::getEnvVariable(QStringLiteral("SKGTRACEPERFO")).isEmpty();
 QString SKGTraces::SKGIndentTrace = QStringLiteral("##");
 SKGPerfoMap     SKGTraces::m_SKGPerfoMethode;
 SKGQStringStack     SKGTraces::m_SKGPerfoPathMethode;
@@ -84,8 +84,8 @@ void SKGTraces::init(int iLevel, const QString& iName, SKGError* iRC)
 #ifdef Q_OS_WIN
         m_elapse = static_cast<double>(GetTickCount());
 #else
-        struct timeval tv;
-        struct timezone tz;
+        struct timeval tv {};
+        struct timezone tz {};
         gettimeofday(&tv, &tz);
         m_elapse = (static_cast<double>(1000.0 * tv.tv_sec)) + (static_cast<double>(tv.tv_usec / 1000.0));
 #endif
@@ -94,7 +94,7 @@ void SKGTraces::init(int iLevel, const QString& iName, SKGError* iRC)
         m_it = SKGTraces::m_SKGPerfoMethode.find(m_mame);
         if (m_it == SKGTraces::m_SKGPerfoMethode.end()) {
             // Not found ==> initialisation
-            SKGPerfoInfo init;
+            SKGPerfoInfo init{};
             init.NbCall = 0;
             init.Time = 0;
             init.TimePropre = 0;
@@ -120,8 +120,8 @@ SKGTraces::~SKGTraces()
 #ifdef Q_OS_WIN
         m_elapse = static_cast<double>(GetTickCount());
 #else
-        struct timeval tv;
-        struct timezone tz;
+        struct timeval tv {};
+        struct timezone tz {};
         gettimeofday(&tv, &tz);
         m_elapse = (static_cast<double>(1000.0 * tv.tv_sec)) + (static_cast<double>(tv.tv_usec / 1000.0)) - m_elapse;
 #endif
@@ -129,7 +129,7 @@ SKGTraces::~SKGTraces()
 
     if (m_output) {
         SKGTRACESUITE << SKGTraces::SKGIndentTrace << COLORED('<' % m_mame);
-        if (m_rc) {
+        if (m_rc != nullptr) {
             SKGTRACESUITE << (m_rc->isSucceeded() ? QString(COLORED(" RC=" % m_rc->getFullMessage())) : QString(COLOREDRED(" RC=" % m_rc->getFullMessage())));
         }
         if (m_profiling) {
