@@ -21,10 +21,10 @@
  *
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
-#include <qtextstream.h>
-#include <qstringlist.h>
 #include <qmap.h>
 #include <qstack.h>
+#include <qstringlist.h>
+#include <qtextstream.h>
 
 #include "skgdefine.h"
 
@@ -82,18 +82,18 @@ struct SKGPerfoInfo {
  * A map of strings ==> SKGPerfoInfo
  * @see SKGPerfoMapIterator
  */
-typedef QMap<QString, SKGPerfoInfo> SKGPerfoMap;
+using SKGPerfoMap = QMap<QString, SKGPerfoInfo>;
 
 /**
  * A iterator for SKGPerfoMap ==> SKGPerfoInfo
  * @see SKGPerfoMap
  */
-typedef QMap<QString, SKGPerfoInfo>::Iterator SKGPerfoMapIterator;
+using SKGPerfoMapIterator = QMap<QString, SKGPerfoInfo>::Iterator;
 
 /**
  * A stack of strings
  */
-typedef QStack<QString> SKGQStringStack;
+using SKGQStringStack = QStack<QString>;
 
 class SKGError;
 
