@@ -41,18 +41,18 @@
 
 #include "qsql_sqlite_p.h"
 
+#include <QtSql/private/qsqlcachedresult_p.h>
+#include <QtSql/private/qsqldriver_p.h>
 #include <qcoreapplication.h>
 #include <qdatetime.h>
-#include <qvariant.h>
+#include <qdebug.h>
 #include <qsqlerror.h>
 #include <qsqlfield.h>
 #include <qsqlindex.h>
 #include <qsqlquery.h>
-#include <QtSql/private/qsqlcachedresult_p.h>
-#include <QtSql/private/qsqldriver_p.h>
 #include <qstringlist.h>
+#include <qvariant.h>
 #include <qvector.h>
-#include <qdebug.h>
 
 #if defined Q_OS_WIN
 # include <qt_windows.h>
@@ -143,11 +143,11 @@ class QSQLiteDriverPrivate : public QSqlDriverPrivate
     Q_DECLARE_PUBLIC(QSQLiteDriver)
 
 public:
-    inline QSQLiteDriverPrivate() : QSqlDriverPrivate(), access(nullptr)
+    inline QSQLiteDriverPrivate()
     {
         dbmsType = QSqlDriver::SQLite;
     }
-    sqlite3* access;
+    sqlite3* access{nullptr};
     QList <QSQLiteResult*> results;
 };
 
@@ -195,7 +195,7 @@ void QSQLiteResultPrivate::cleanup()
 
 void QSQLiteResultPrivate::finalize()
 {
-    if (!stmt) {
+    if (stmt == nullptr) {
         return;
     }
 
@@ -278,7 +278,7 @@ bool QSQLiteResultPrivate::fetchNext(QSqlCachedResult::ValueCache& values, int i
         firstRow.resize(sqlite3_column_count(stmt));
     }
 
-    if (!stmt) {
+    if (stmt == nullptr) {
         q->setLastError(QSqlError(QCoreApplication::translate("QSQLiteResult", "Unable to fetch row"),
                                   QCoreApplication::translate("QSQLiteResult", "No query"), QSqlError::ConnectionError));
         q->setAt(QSql::AfterLastRow);
@@ -374,7 +374,7 @@ QSQLiteResult::QSQLiteResult(const QSQLiteDriver* db)
 QSQLiteResult::~QSQLiteResult()
 {
     Q_D(QSQLiteResult);
-    if (d->drv_d_func()) {
+    if (d->drv_d_func() != nullptr) {
         const_cast<QSQLiteDriverPrivate*>(d->drv_d_func())->results.removeOne(this);
     }
     d->cleanup();
@@ -396,7 +396,7 @@ bool QSQLiteResult::reset(const QString& query)
 bool QSQLiteResult::prepare(const QString& query)
 {
     Q_D(QSQLiteResult);
-    if (!driver() || !driver()->isOpen() || driver()->isOpenError()) {
+    if ((driver() == nullptr) || !driver()->isOpen() || driver()->isOpenError()) {
         return false;
     }
 
@@ -419,7 +419,8 @@ bool QSQLiteResult::prepare(const QString& query)
                                 "Unable to execute statement"), QSqlError::StatementError, res));
         d->finalize();
         return false;
-    } else if (pzTail && !QString(reinterpret_cast<const QChar*>(pzTail)).trimmed().isEmpty()) {
+    }
+    if ((pzTail != nullptr) && !QString(reinterpret_cast<const QChar*>(pzTail)).trimmed().isEmpty()) {
         setLastError(qMakeError(d->drv_d_func()->access, QCoreApplication::translate("QSQLiteResult",
                                 "Unable to execute multiple statements at a time"), QSqlError::StatementError, SQLITE_MISUSE));
         d->finalize();
@@ -450,14 +451,14 @@ bool QSQLiteResult::exec()
     if (paramCount == values.count()) {
         for (int i = 0; i < paramCount; ++i) {
             res = SQLITE_OK;
-            const QVariant value = values.at(i);
+            const QVariant& value = values.at(i);
 
             if (value.isNull()) {
                 res = sqlite3_bind_null(d->stmt, i + 1);
             } else {
                 switch (value.type()) {
                 case QVariant::ByteArray: {
-                    const QByteArray* ba = static_cast<const QByteArray*>(value.constData());
+                    const auto* ba = static_cast<const QByteArray*>(value.constData());
                     res = sqlite3_bind_blob(d->stmt, i + 1, ba->constData(),
                                             ba->size(), SQLITE_STATIC);
                     break;
@@ -489,7 +490,7 @@ bool QSQLiteResult::exec()
                 }
                 case QVariant::String: {
                     // lifetime of string == lifetime of its qvariant
-                    const QString* str = static_cast<const QString*>(value.constData());
+                    const auto* str = static_cast<const QString*>(value.constData());
                     res = sqlite3_bind_text16(d->stmt, i + 1, str->utf16(),
                                               (str->size()) * sizeof(QChar), SQLITE_STATIC);
                     break;
@@ -548,7 +549,7 @@ QVariant QSQLiteResult::lastInsertId() const
     Q_D(const QSQLiteResult);
     if (isActive()) {
         qint64 id = sqlite3_last_insert_rowid(d->drv_d_func()->access);
-        if (id) {
+        if (id != 0) {
             return id;
         }
     }
@@ -567,7 +568,7 @@ QSqlRecord QSQLiteResult::record() const
 void QSQLiteResult::detachFromResultSet()
 {
     Q_D(QSQLiteResult);
-    if (d->stmt) {
+    if (d->stmt != nullptr) {
         sqlite3_reset(d->stmt);
     }
 }
@@ -626,7 +627,7 @@ bool QSQLiteDriver::hasFeature(DriverFeature f) const
    SQLite dbs have no user name, passwords, hosts or ports.
    just file names.
 */
-bool QSQLiteDriver::open(const QString& db, const QString&, const QString&, const QString&, int, const QString& conOpts)
+bool QSQLiteDriver::open(const QString& db, const QString& /*user*/, const QString& /*password*/, const QString& /*host*/, int /*port*/, const QString& conOpts)
 {
     Q_D(QSQLiteDriver);
     if (isOpen()) {
@@ -665,24 +666,24 @@ bool QSQLiteDriver::open(const QString& db, const QString&, const QString&, cons
         openMode |= SQLITE_OPEN_URI;
     }
 
-    sqlite3_enable_shared_cache(sharedCache);
+    sqlite3_enable_shared_cache(static_cast<int>(sharedCache));
 
     if (sqlite3_open_v2(db.toUtf8().constData(), &d->access, openMode, nullptr) == SQLITE_OK) {
         sqlite3_busy_timeout(d->access, timeOut);
         setOpen(true);
         setOpenError(false);
         return true;
-    } else {
-        if (d->access) {
-            sqlite3_close(d->access);
-            d->access = nullptr;
-        }
-
-        setLastError(qMakeError(d->access, tr("Error opening database"),
-                                QSqlError::ConnectionError));
-        setOpenError(true);
-        return false;
     }
+    if (d->access != nullptr) {
+        sqlite3_close(d->access);
+        d->access = nullptr;
+    }
+
+    setLastError(qMakeError(d->access, tr("Error opening database"),
+                            QSqlError::ConnectionError));
+    setOpenError(true);
+    return false;
+
 }
 
 void QSQLiteDriver::close()
@@ -768,11 +769,11 @@ QStringList QSQLiteDriver::tables(QSql::TableType type) const
 
     QString sql = QStringLiteral("SELECT name FROM sqlite_master WHERE %1 "
                                  "UNION ALL SELECT name FROM sqlite_temp_master WHERE %1");
-    if ((type & QSql::Tables) && (type & QSql::Views)) {
+    if (((type & QSql::Tables) != 0) && ((type & QSql::Views) != 0)) {
         sql = sql.arg(QStringLiteral("type='table' OR type='view'"));
-    } else if (type & QSql::Tables) {
+    } else if ((type & QSql::Tables) != 0) {
         sql = sql.arg(QStringLiteral("type='table'"));
-    } else if (type & QSql::Views) {
+    } else if ((type & QSql::Views) != 0) {
         sql = sql.arg(QStringLiteral("type='view'"));
     } else {
         sql.clear();
@@ -784,7 +785,7 @@ QStringList QSQLiteDriver::tables(QSql::TableType type) const
         }
     }
 
-    if (type & QSql::SystemTables) {
+    if ((type & QSql::SystemTables) != 0) {
         // there are no internal tables beside this one:
         res.append(QStringLiteral("sqlite_master"));
     }
@@ -805,7 +806,7 @@ static QSqlIndex qGetTableInfo(QSqlQuery& q, const QString& tableName, bool only
 
     QSqlIndex ind;
     while (q.next()) {
-        bool isPk = q.value(5).toInt();
+        bool isPk = q.value(5).toInt() != 0;
         if (onlyPIndex && !isPk) {
             continue;
         }
