@@ -20,13 +20,9 @@
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
 
+#include "qsql_sqlite_p.h"
 #include <qsqldriverplugin.h>
 #include <qstringlist.h>
-#if QT_VERSION < 0x050700
-#include "old-qsql_sqlite_p.h"
-#else
-#include "qsql_sqlite_p.h"
-#endif
 
 QT_BEGIN_NAMESPACE
 
@@ -36,8 +32,8 @@ class SKGSQLCipherDriverPlugin : public QSqlDriverPlugin
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QSqlDriverFactoryInterface" FILE "skgsqlcipherdriverplugin.json")
 
 public:
-    SKGSQLCipherDriverPlugin() : QSqlDriverPlugin()
-    {}
+    SKGSQLCipherDriverPlugin()
+        = default;
 
     QSqlDriver* create(const QString& iName) override
     {
@@ -45,7 +41,7 @@ public:
             auto driver = new QSQLiteDriver();
             return driver;
         }
-        return 0;
+        return nullptr;
     }
 };
 
