@@ -23,8 +23,8 @@
 
 #include <qdbusconnection.h>
 
-#include <klocalizedstring.h>
 #include <kdirwatch.h>
+#include <klocalizedstring.h>
 
 #include <akonadicore/entitydisplayattribute.h>
 #include <kcalcore/todo.h>
@@ -33,10 +33,10 @@
 
 #include "settings.h"
 #include "settingsadaptor.h"
-#include "skgdocumentbank.h"
-#include "skgrecurrentoperationobject.h"
-#include "skgoperationobject.h"
 #include "skgcategoryobject.h"
+#include "skgdocumentbank.h"
+#include "skgoperationobject.h"
+#include "skgrecurrentoperationobject.h"
 
 skroogeakonadiResource::skroogeakonadiResource(const QString& id) : ResourceBase(id)
 {
@@ -55,7 +55,7 @@ skroogeakonadiResource::skroogeakonadiResource(const QString& id) : ResourceBase
     synchronize();
 }
 
-skroogeakonadiResource::~skroogeakonadiResource() {}
+skroogeakonadiResource::~skroogeakonadiResource() = default;
 
 void skroogeakonadiResource::retrieveCollections()
 {
