@@ -47,20 +47,20 @@ public:
     /**
      * To know if import is possible with this plugin
      */
-    virtual bool isImportPossible() Q_DECL_OVERRIDE;
+    virtual bool isImportPossible() override;
 
     /**
      * Import a file
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError importFile() Q_DECL_OVERRIDE;
+    virtual SKGError importFile() override;
 
     /**
      * To know if export is possible with this plugin
      * @return true or false
      */
-    virtual bool isExportPossible() Q_DECL_OVERRIDE;
+    virtual bool isExportPossible() override;
 
 
     /**
@@ -68,13 +68,13 @@ public:
      * @return an object managing the error.
      *   @see SKGError
      */
-    virtual SKGError exportFile() Q_DECL_OVERRIDE;
+    virtual SKGError exportFile() override;
 
     /**
      * Return the mime type filter
      * @return the mime type filter. Example: "*.csv|CSV file"
      */
-    virtual QString getMimeTypeFilter() const Q_DECL_OVERRIDE;
+    virtual QString getMimeTypeFilter() const override;
 
 
 private:
