@@ -20,11 +20,11 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtestactions.h"
-#include "skgmainpanel.h"
 #include "skgboardwidget.h"
 #include "skgdocumentbank.h"
-#include "skgtraces.h"
+#include "skgmainpanel.h"
 #include "skgtestmacro.h"
+#include "skgtraces.h"
 
 void SKGTESTActions::Test()
 {
@@ -37,6 +37,12 @@ void SKGTESTActions::Test()
 
     QVERIFY2(!doc.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/advice.skg"), "Load document failed");
 
+    {
+        SKGError err;
+        SKGBEGINTRANSACTION(doc, QStringLiteral("DELETE"), err);
+        doc.executeSqliteOrder(QStringLiteral("DELETE FROM operation WHERE d_date<'") + SKGServices::dateToSqlString(QDate::currentDate().addMonths(-2)) + '\'');
+    }
+
     // Scenario
     QStringList actionsToExecute;
     actionsToExecute
@@ -124,7 +130,7 @@ void SKGTESTActions::Test()
         }
         SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyy-MM-dd hh:mm:ss")) << "  [" << key << "]: ";
         QAction* act = mainpanel.getGlobalAction(key);
-        if (act) {
+        if (act != nullptr) {
             act->trigger();
             SKGTRACESUITE << "DONE" << endl;
         } else {
@@ -133,7 +139,7 @@ void SKGTESTActions::Test()
 
         if (key == QStringLiteral("edit_select_all")) {
             SKGTabPage* page = mainpanel.currentPage();
-            if (page) {
+            if (page != nullptr) {
                 SKGTRACE << "      Current page:" << page->objectName() << endl;
             }
             SKGTRACE << "      Nb objects selected:" << mainpanel.getNbSelectedObjects() << endl;
