@@ -20,11 +20,11 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtestmainpanel.h"
-#include "skgmainpanel.h"
 #include "skgboardwidget.h"
 #include "skgdocumentbank.h"
-#include "skgtraces.h"
+#include "skgmainpanel.h"
 #include "skgtestmacro.h"
+#include "skgtraces.h"
 
 void SKGTESTMainPanel::Test()
 {
@@ -49,7 +49,7 @@ void SKGTESTMainPanel::Test()
         SKGInterfacePlugin* plugin = nullptr;
         do {
             plugin = mainpanel.getPluginByIndex(i);
-            if (plugin) {
+            if (plugin != nullptr) {
                 SKGTRACE << i << ": " << plugin->title() << "(" << plugin->icon() << ")" << endl;
                 plugin->statusTip();
                 plugin->toolTip();
@@ -59,7 +59,7 @@ void SKGTESTMainPanel::Test()
                 plugin->isEnabled();
 
                 SKGTabPage* tab = plugin->getWidget();
-                if (tab) {
+                if (tab != nullptr) {
                     tab->printableWidgets();
                     tab->activateEditor();
                     tab->getBookmarkID();
@@ -76,7 +76,7 @@ void SKGTESTMainPanel::Test()
                 for (int j = 0; j < nbd + 1; ++j) {
                     SKGTRACE << "    Dashboard " << j << "/" << nbd + 1 << ": " << plugin->getDashboardWidgetTitle(j) << endl;
                     SKGBoardWidget* bw = plugin->getDashboardWidget(j);
-                    if (bw) {
+                    if (bw != nullptr) {
                         bw->setState(bw->getState());
                         bw->getDefaultStateAttribute();
                         bw->getFirstSelectedObject();
