@@ -44,7 +44,7 @@ void SKGTESTModel::Test()
     }
 
     for (const auto& table : qAsConst(tables)) {
-        SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "..:: " << table << " ::.." << endl;
+        SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "..:: " << table << " ::.." << endl;
 
         // Initilialization  model
         auto model = new SKGObjectModel(&doc,
@@ -80,76 +80,76 @@ void SKGTESTModel::Test()
         QTest::qWait(wait);
 
         int nbCols = model->columnCount();
-        SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "     Nb rows=" << model->rowCount() << endl;
-        SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "     Nb Cols=" << nbCols  << endl;
+        SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "     Nb rows=" << model->rowCount() << endl;
+        SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "     Nb Cols=" << nbCols  << endl;
         for (int i = 0; i < nbCols; ++i) {
             SKGTRACE << "         " << model->getAttribute(i)  << endl;
         }
 
         // Set Data
         if (table == QStringLiteral("v_account_display")) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(t_close, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(t_close, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("t_close"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
         }
         if (table == QStringLiteral("v_refund_display")) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(t_close, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(t_close, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("t_close"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
         }
         if (table == QStringLiteral("v_operation_display")) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(t_status, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(t_status, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("t_status"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
         }
         if (table == QStringLiteral("v_recurrentoperation_display")) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(i_warn_days, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(i_warn_days, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("i_warn_days"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
 
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(i_auto_write_days, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(i_auto_write_days, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("i_auto_write_days"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
 
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(i_nb_times, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(i_nb_times, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("i_nb_times"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
         }
         if (table == QStringLiteral("v_budgetrule_display")) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(i_year, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(i_year, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("i_year"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
 
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(i_month, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(i_month, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("i_month"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
 
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(t_CATEGORYCONDITION, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(t_CATEGORYCONDITION, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("t_CATEGORYCONDITION"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
 
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(t_CATEGORY, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(t_CATEGORY, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("t_CATEGORY"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
         }
         if (table == QStringLiteral("v_budget_display")) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(t_CATEGORY, Checked)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(t_CATEGORY, Checked)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("t_CATEGORY"))), QVariant(static_cast<unsigned int>(Qt::Checked)), Qt::CheckStateRole);
         }
         if (table == QStringLiteral("node")) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(t_name, new name)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(t_name, new name)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("t_name"))), QVariant("new name"), Qt::EditRole);
         }
         if (table == QStringLiteral("v_unit_display")) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             setData(t_name, new name)" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             setData(t_name, new name)" << endl;
             model->setData(model->index(1, model->getIndexAttribute(QStringLiteral("t_name"))), QVariant("new name"), Qt::EditRole);
         }
 
         if ((table == QStringLiteral("v_node") || table.endsWith(QLatin1String("_display"))) && (model->supportedDragActions()&Qt::MoveAction) != 0u && (model->supportedDropActions()&Qt::MoveAction) != 0u) {
-            SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             Drag & Drop" << endl;
+            SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             Drag & Drop" << endl;
             model->mimeTypes();
             QMimeData* md = model->mimeData(QModelIndexList() << model->index(0, 0));
             QCOMPARE(model->dropMimeData(md, Qt::MoveAction, 1, 0, model->index(1, 0)), true);
         }
 
         // test
-        SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             new ModelTest" << endl;
+        SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             new ModelTest" << endl;
         auto modeltest = new ModelTest(model);
         QTest::qWait(wait);
 
         delete modeltest;
         delete model;
-        SKGTRACE << QDateTime::currentDateTime().toString("yyyyMMdd-HHmmss-zzz") << "             end" << endl;
+        SKGTRACE << QDateTime::currentDateTime().toString(QStringLiteral("yyyyMMdd-HHmmss-zzz")) << "             end" << endl;
     }
 }
 
