@@ -83,9 +83,9 @@ int main(int argc, char** argv)
             QString f = SKGTest::getTestPath(QStringLiteral("OUT")) % QStringLiteral("/skgtestimportafb120/anonymize.skg");
             QFile(f).remove();
             SKGImportExportManager imp1(&document1);
-            SKGTESTERROR(QStringLiteral("AFB120:anonymize"), imp1.anonymize(), false);
+            SKGTESTERROR(QStringLiteral("AFB120:anonymize"), imp1.anonymize(QLatin1String("")), false);
             SKGTESTERROR(QStringLiteral("AFB120.saveAs"), document1.saveAs(f), true);
-            SKGTESTERROR(QStringLiteral("AFB120:anonymize"), imp1.anonymize(), true);
+            SKGTESTERROR(QStringLiteral("AFB120:anonymize"), imp1.anonymize(QLatin1String("")), true);
             fano = document1.getCurrentFileName();
             SKGTEST(QStringLiteral("AFB120:getCurrentFileName"), static_cast<unsigned int>(fano != f), static_cast<unsigned int>(true));
 
@@ -96,6 +96,9 @@ int main(int argc, char** argv)
             // Load anonymized file
             SKGDocumentBank document2;
             SKGTESTERROR(QStringLiteral("DOC:load"), document2.load(fano), true);
+
+            SKGImportExportManager imp1(&document2);
+            SKGTESTERROR(QStringLiteral("AFB120:anonymize"), imp1.anonymize(QLatin1String("KEY")), true);
         }
     }
     // End test
