@@ -54,7 +54,7 @@ int main(int argc, char** argv)
             SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportcsv/skrooge_partial.csv"));
             SKGImportExportManager::getImportMimeTypeFilter();
             SKGImportExportManager::getExportMimeTypeFilter();
-            imp1.setCodec(QString(""));
+            imp1.setCodec(QLatin1String(""));
             SKGTESTERROR(QStringLiteral("imp1.importFile"), imp1.importFile(), true);
         }
         SKGAccountObject account;
@@ -62,7 +62,7 @@ int main(int argc, char** argv)
         SKGTESTERROR(QStringLiteral("ACCOUNT.load"), account.load(), true);
         SKGTEST(QStringLiteral("ACCOUNT:getCurrentAmount"), SKGServices::doubleToString(account.getCurrentAmount()), QStringLiteral("-935"));
         SKGTEST(QStringLiteral("document1:getCategoryForPayee"), document1.getCategoryForPayee(QStringLiteral("Anthony Hopkins"), false), QStringLiteral("Entertain > Movie"));
-        SKGTEST(QStringLiteral("document1:getCategoryForPayee"), document1.getCategoryForPayee(QStringLiteral("NOT FOUND")), QString(""));
+        SKGTEST(QStringLiteral("document1:getCategoryForPayee"), document1.getCategoryForPayee(QStringLiteral("NOT FOUND")), QLatin1String(""));
     }
 
     {
@@ -184,7 +184,7 @@ int main(int argc, char** argv)
 
         {
             SKGStringListList oTable;
-            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEMONTH"), QStringLiteral("t_CATEGORY"), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QString(""), oTable), true);
+            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEMONTH"), QStringLiteral("t_CATEGORY"), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QLatin1String(""), oTable), true);
             QStringList dump = SKGServices::tableToDump(oTable, SKGServices::DUMP_TEXT);
             int nbl = dump.count();
             for (int i = 0; i < nbl; ++i) {
@@ -193,7 +193,7 @@ int main(int argc, char** argv)
         }
         {
             SKGStringListList oTable;
-            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QString(""), QStringLiteral("t_CATEGORY"), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QString(""), oTable), true);
+            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QLatin1String(""), QStringLiteral("t_CATEGORY"), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QLatin1String(""), oTable), true);
             QStringList dump = SKGServices::tableToDump(oTable, SKGServices::DUMP_TEXT);
             int nbl = dump.count();
             for (int i = 0; i < nbl; ++i) {
@@ -202,12 +202,12 @@ int main(int argc, char** argv)
         }
         {
             SKGStringListList oTable;
-            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEWEEK"), QString(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QString(""), oTable), true);
-            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEQUARTER"), QString(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QString(""), oTable), true);
-            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATESEMESTER"), QString(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QString(""), oTable), true);
-            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEYEAR"), QString(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QString(""), oTable), true);
-            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_date"), QString(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QString(""), oTable), true);
-            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEMONTH"), QString(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QString(""), oTable), true);
+            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEWEEK"), QLatin1String(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QLatin1String(""), oTable), true);
+            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEQUARTER"), QLatin1String(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QLatin1String(""), oTable), true);
+            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATESEMESTER"), QLatin1String(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QLatin1String(""), oTable), true);
+            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEYEAR"), QLatin1String(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QLatin1String(""), oTable), true);
+            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_date"), QLatin1String(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QLatin1String(""), oTable), true);
+            SKGTESTERROR(QStringLiteral("SKGImportExportManager::CSV.exportFile"), document1.getConsolidatedView(QStringLiteral("v_operation_display"), QStringLiteral("d_DATEMONTH"), QLatin1String(""), QStringLiteral("f_CURRENTAMOUNT"), QStringLiteral("SUM"), QLatin1String(""), oTable), true);
             QStringList dump = SKGServices::tableToDump(oTable, SKGServices::DUMP_TEXT);
             int nbl = dump.count();
             for (int i = 0; i < nbl; ++i) {
@@ -385,14 +385,14 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true);
 
             SKGObjectBase::SKGListSKGObjectBase banks;
-            SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getObjects(QStringLiteral("bank"), QString(""), banks), true);
+            SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getObjects(QStringLiteral("bank"), QLatin1String(""), banks), true);
             SKGBankObject bank(banks.at(0));
             bank.setName(QStringLiteral("bp"));
             bank.save();
         }
 
         SKGObjectBase::SKGListSKGObjectBase grouped;
-        SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getObjects(QStringLiteral("operation"), QString(""), grouped), true);
+        SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getObjects(QStringLiteral("operation"), QLatin1String(""), grouped), true);
         SKGTEST(QStringLiteral("CSV:grouped.count"), grouped.count(), 4);
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getObjects(QStringLiteral("operation"), QStringLiteral("i_group_id!=0"), grouped), true);
         SKGTEST(QStringLiteral("CSV:grouped.count"), grouped.count(), 2);
@@ -639,7 +639,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("CSV.importFile"), imp1.importFile(), true);
         }
         int nb = 0;
-        SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("operation"), QString(""), nb), true);
+        SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("operation"), QLatin1String(""), nb), true);
         SKGTEST(QStringLiteral("CSV:nb operations"), nb, 1);
         SKGTESTERROR(QStringLiteral("CSV.getObjects"), document1.getNbObjects(QStringLiteral("suboperation"), QStringLiteral("d_date='2015-07-07'"), nb), true);
         SKGTEST(QStringLiteral("CSV:nb suboperations 2015-07-07"), nb, 1);
