@@ -60,7 +60,7 @@ int main(int argc, char** argv)
         }
 
         int nb = 0;
-        SKGTESTERROR(QStringLiteral("imp1.getNbObjects"), document1.getNbObjects(QStringLiteral("rule"), QString(""), nb), true);
+        SKGTESTERROR(QStringLiteral("imp1.getNbObjects"), document1.getNbObjects(QStringLiteral("rule"), QLatin1String(""), nb), true);
         SKGTEST(QStringLiteral("imp1.nb"), nb, 3);
     }
 
