@@ -164,7 +164,7 @@ int main(int argc, char** argv)
 
         {
             int nb = 0;
-            SKGTESTERROR(QStringLiteral("GNUCASH:getNbObjects"), document1.getNbObjects(QStringLiteral("category"), QString(""), nb), true);
+            SKGTESTERROR(QStringLiteral("GNUCASH:getNbObjects"), document1.getNbObjects(QStringLiteral("category"), QLatin1String(""), nb), true);
             SKGTEST(QStringLiteral("GNUCASH:getNbObjects"), nb, 27);
         }
     }
@@ -316,7 +316,7 @@ int main(int argc, char** argv)
 
         {
             SKGObjectBase::SKGListSKGObjectBase recurrentoperations;
-            SKGTESTERROR(QStringLiteral("GNUCASH:SKGListSKGObjectBase"), document1.getObjects(QStringLiteral("recurrentoperation"), QString(""), recurrentoperations), true);
+            SKGTESTERROR(QStringLiteral("GNUCASH:SKGListSKGObjectBase"), document1.getObjects(QStringLiteral("recurrentoperation"), QLatin1String(""), recurrentoperations), true);
             SKGTEST(QStringLiteral("GNUCASH:nb"), recurrentoperations.count(), 1);
             if (recurrentoperations.count() == 1) {
                 SKGRecurrentOperationObject recu(recurrentoperations.at(0));
@@ -442,7 +442,7 @@ int main(int argc, char** argv)
         }
         {
             int nb = 0;
-            SKGTESTERROR(QStringLiteral("GNUCASH:getNbObjects"), document1.getNbObjects(QStringLiteral("account"), QString(""), nb), true);
+            SKGTESTERROR(QStringLiteral("GNUCASH:getNbObjects"), document1.getNbObjects(QStringLiteral("account"), QLatin1String(""), nb), true);
             SKGTEST(QStringLiteral("GNUCASH:getNbObjects"), nb, 3);
         }
         {
@@ -521,7 +521,7 @@ int main(int argc, char** argv)
         }
 
         int nb = 0;
-        SKGTESTERROR(QStringLiteral("GNUCASH:getNbObjects(account)"), document1.getNbObjects(QStringLiteral("account"), QString(""), nb), true);
+        SKGTESTERROR(QStringLiteral("GNUCASH:getNbObjects(account)"), document1.getNbObjects(QStringLiteral("account"), QLatin1String(""), nb), true);
         SKGTEST(QStringLiteral("GNUCASH:getNbObjects(account)"), nb, 11);
     }
 
@@ -544,7 +544,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("GNUCASH.load"), account.load(), true);
             SKGBankObject bank;
             SKGTESTERROR(QStringLiteral("GNUCASH.load"), account.getBank(bank), true);
-            SKGTEST(QStringLiteral("GNUCASH:getName"), bank.getName(), QString(""));
+            SKGTEST(QStringLiteral("GNUCASH:getName"), bank.getName(), QLatin1String(""));
         }
         {
             SKGAccountObject account(&document1);
