@@ -87,7 +87,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("KMY.load"), account.load(), true);
             SKGBankObject bank;
             SKGTESTERROR(QStringLiteral("KMY.load"), account.getBank(bank), true);
-            SKGTEST(QStringLiteral("KMY:getName"), bank.getName(), QString(""));
+            SKGTEST(QStringLiteral("KMY:getName"), bank.getName(), QLatin1String(""));
         }
         {
             SKGAccountObject account(&document1);
