@@ -40,7 +40,7 @@ int main(int argc, char** argv)
         // Test export 320066
         SKGDocumentBank document1;
         SKGTESTERROR(QStringLiteral("document1.load()"), document1.load(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportkmy4/320066.skg"), true);
-        SKGTESTERROR(QStringLiteral("document1.getNbObjects()"), document1.getNbObjects(QStringLiteral("v_operation_display"), QString(""), nboperation), true);
+        SKGTESTERROR(QStringLiteral("document1.getNbObjects()"), document1.getNbObjects(QStringLiteral("v_operation_display"), QLatin1String(""), nboperation), true);
         SKGError err;
         {
             // Scope of the transaction
@@ -63,7 +63,7 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("KMY.importFile"), imp1.importFile(), true);
 
             int nboperation2 = 0;
-            SKGTESTERROR(QStringLiteral("document1.getNbObjects()"), document1.getNbObjects(QStringLiteral("v_operation_display"), QString(""), nboperation2), true);
+            SKGTESTERROR(QStringLiteral("document1.getNbObjects()"), document1.getNbObjects(QStringLiteral("v_operation_display"), QLatin1String(""), nboperation2), true);
 
             SKGTEST(QStringLiteral("document1:nb operations"), nboperation2, nboperation);
         }
