@@ -222,12 +222,12 @@ int main(int argc, char** argv)
         {
             // Create an account without number
             SKGBEGINTRANSACTION(document1, QStringLiteral("CREATE_ACCOUNT"), err);
-            SKGTESTERROR(QStringLiteral("DOC.addOrModifyAccount"), document1.addOrModifyAccount(QStringLiteral("COURANT"), QString(""), QStringLiteral("BANK")), true);
+            SKGTESTERROR(QStringLiteral("DOC.addOrModifyAccount"), document1.addOrModifyAccount(QStringLiteral("COURANT"), QLatin1String(""), QStringLiteral("BANK")), true);
         }
         {
             // Create an account without number
             SKGBEGINTRANSACTION(document1, QStringLiteral("CREATE_ACCOUNT"), err);
-            SKGTESTERROR(QStringLiteral("DOC.addOrModifyAccount"), document1.addOrModifyAccount(QStringLiteral("COURANT2"), QString(""), QStringLiteral("BANK")), true);
+            SKGTESTERROR(QStringLiteral("DOC.addOrModifyAccount"), document1.addOrModifyAccount(QStringLiteral("COURANT2"), QLatin1String(""), QStringLiteral("BANK")), true);
         }
         {
             // Scope of the transaction
@@ -331,7 +331,7 @@ int main(int argc, char** argv)
         }
 
         int nb1 = 0;
-        SKGTESTERROR(QStringLiteral("PAYEE.getNbObjects"), document1.getNbObjects(QStringLiteral("operation"), QString(""), nb1), true);
+        SKGTESTERROR(QStringLiteral("PAYEE.getNbObjects"), document1.getNbObjects(QStringLiteral("operation"), QLatin1String(""), nb1), true);
 
         {
             // Scope of the transaction
@@ -341,7 +341,7 @@ int main(int argc, char** argv)
         }
 
         int nb2 = 0;
-        SKGTESTERROR(QStringLiteral("PAYEE.getNbObjects"), document1.getNbObjects(QStringLiteral("operation"), QString(""), nb2), true);
+        SKGTESTERROR(QStringLiteral("PAYEE.getNbObjects"), document1.getNbObjects(QStringLiteral("operation"), QLatin1String(""), nb2), true);
 
         SKGTEST(QStringLiteral("PAYEE.getNbObjects"), nb1, nb2);
     }
