@@ -338,6 +338,39 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("QIF.importFile"), imp1.importFile(), true);
         }
     }
+
+    {
+        // 402330
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err);
+
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif2/402330.qif"));
+            SKGTESTERROR(QStringLiteral("QIF.importFile"), imp1.importFile(), true);
+        }
+    }
+
+    {
+        // 403725
+        SKGDocumentBank document1;
+        SKGTESTERROR(QStringLiteral("document1.initialize()"), document1.initialize(), true);
+        SKGError err;
+        {
+            // Scope of the transaction
+            SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT"), err);
+
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportqif2/403725.qif"));
+            SKGTESTERROR(QStringLiteral("QIF.importFile"), imp1.importFile(), true);
+        }
+
+        SKGObjectBase::SKGListSKGObjectBase result;
+        SKGTESTERROR(QStringLiteral("DOC.getObjects"), document1.getObjects(QStringLiteral("refund"), QStringLiteral(""), result), true);
+        SKGTEST(QStringLiteral("DOC.getObjects.count"), result.count(), 1);
+    }
+
     // End test
     SKGENDTEST();
 }
