@@ -85,7 +85,7 @@ int main(int argc, char** argv)
             SKGAccountObject account(&document1);
             SKGTESTERROR(QStringLiteral("QIF.setName"), account.setName(QStringLiteral("BNP CC")), true);
             SKGTESTERROR(QStringLiteral("QIF.load"), account.load(), true);
-            SKGTEST(QStringLiteral("QIF:getValue"), SKGServices::toCurrencyString(account.getCurrentAmount(), QString(""), 2), QStringLiteral("-520.00"));
+            SKGTEST(QStringLiteral("QIF:getValue"), SKGServices::toCurrencyString(account.getCurrentAmount(), QLatin1String(""), 2), QStringLiteral("-520.00"));
         }
         {
             SKGAccountObject account(&document1);
