@@ -20,8 +20,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtestmacro.h"
-#include "skgimportexportmanager.h"
 #include "skgbankincludes.h"
+#include "skgimportexportmanager.h"
 
 /**
  * The main function of the unit test
@@ -41,7 +41,7 @@ int main(int argc, char** argv)
 
     int nb = extensions.count();
     for (int i = 0; i < nb; ++i) {
-        QString ext = extensions.at(i);
+        const QString& ext = extensions.at(i);
         QString filename = "http://skrooge.org/files/skgtestimporturl/test." % ext;
         SKGTRACE << i + 1 << "/" << nb << ": Import " << filename << endl;
 
@@ -68,7 +68,7 @@ int main(int argc, char** argv)
 
             int nb2 = extensionsExport.count();
             for (int j = 0; j < nb2; ++j) {
-                QString ext2 = extensionsExport.at(j);
+                const QString& ext2 = extensionsExport.at(j);
                 QString filename2 = "ftp://skrooge.org/files/skgtestimporturl/output/test." % ext2;
                 SKGTRACE << "    " << j + 1 << "/" << nb2 << ": Export " << filename2 << endl;
 
