@@ -200,3 +200,51 @@ public:
         }\
     }
 #endif
+
+/**
+ * @def SKGTESTTRIGGERACTION(PLUGIN)
+ * To trigger an action
+ */
+#define SKGTESTTRIGGERACTION(NAME) \
+    { \
+        QAction* act = plugin.action(NAME); \
+        QVERIFY(act!=nullptr); \
+        act->trigger(); \
+    }
+
+/**
+ * @def SKGTESTPLUGIN(PLUGIN)
+ * To do common checks on a plugin
+ */
+#define SKGTESTPLUGIN(PLUGIN, DOC) \
+    { \
+        QVERIFY(!PLUGIN.setupActions(nullptr)); \
+        QVERIFY(PLUGIN.setupActions(&DOC)); \
+        QVERIFY(!PLUGIN.title().isEmpty()); \
+        QVERIFY(!PLUGIN.icon().isEmpty()); \
+        QVERIFY(!PLUGIN.toolTip().isEmpty()); \
+        QVERIFY(!PLUGIN.statusTip().isEmpty()); \
+        QVERIFY(PLUGIN.getOrder()>0); \
+        SKGTabPage* page = plugin.getWidget(); \
+        plugin.getPreferenceWidget(); \
+        plugin.getPreferenceSkeleton(); \
+        plugin.savePreferences(); \
+        if(page) page->setState(page->getState()); \
+        int nb = PLUGIN.getNbDashboardWidgets(); \
+        for (int i=0; i<nb; ++i) { \
+            QVERIFY(!PLUGIN.getDashboardWidgetTitle(i).isEmpty()); \
+        } \
+        auto tips = PLUGIN.tips(); \
+        for (int i=0; i<tips.count(); ++i) { \
+            QVERIFY(!tips.at(i).isEmpty()); \
+        } \
+        auto subplugins = PLUGIN.subPlugins(); \
+        for (int i=0; i<subplugins.count(); ++i) { \
+            QVERIFY(!tips.at(i).isEmpty()); \
+        } \
+        QStringList iIgnoredAdvice; \
+        SKGAdviceList adv = PLUGIN.advice(iIgnoredAdvice); \
+        for (int i=0; i<adv.count(); ++i) { \
+            QVERIFY(!adv.at(i).getUUID().isEmpty()); \
+        } \
+    }
