@@ -22,9 +22,9 @@
 #include "skgtestmacro.h"
 #include <qsqldatabase.h>
 #include <qthread.h>
+#include <quuid.h>
 #include <unistd.h>
 
-
 void dumpConnections()
 {
     const auto conNames = QSqlDatabase::connectionNames();
@@ -165,6 +165,19 @@ int main(int argc, char** argv)
     SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSingleSelectSqliteOrder(QStringLiteral("SELECT NEXT('ABC')"), result), true);
     SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-NEXT"), result, QLatin1String(""));
 
+    SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSingleSelectSqliteOrder(QStringLiteral("SELECT XOR('HELLO WORLD!', 'KEY')"), result), true);
+    SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-XOR"), result, QLatin1String("# 030015070a791c0a0b070178"));
+    for (int i = 1; i < 100; ++i) {
+        auto string = QUuid::createUuid().toString();
+        SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSingleSelectSqliteOrder(QStringLiteral("SELECT XOR(XOR('") + string + "', 'KEY'), 'KEY')", result), true);
+        SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-XOR"), result, string);
+    }
+    for (double i = -1200.53; i < 5023.25; i = i + 125.54) {
+        auto string = SKGServices::doubleToString(i);
+        SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSingleSelectSqliteOrder(QStringLiteral("SELECT XORD(XORD(") + string + ", 'KEY'), 'KEY')", result), true);
+        SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-XORD"), result, string);
+    }
+
     SKGTRACE << "####### Before concurrent calls" << endl;
     dumpConnections();
     int nb = 5;
